Module Atomics

Module Atomics 

The Atomics object provides atomic operations as static methods. They are used with SharedArrayBuffer objects.

The Atomic operations are installed on an Atomics module. Unlike the other global objects, Atomics is not a constructor. You cannot use it with a new operator or invoke the Atomics object as a function. All properties and methods of Atomics are static (as is the case with the Math object, for example). MDN documentation

Functions

add
add_bigint
and
and_bigint
compare_exchange
compare_exchange_bigint
exchange
exchange_bigint
is_lock_free
load
load_bigint
notify
notify_bigint
notify_bigint_with_count
notify_with_count
or
or_bigint
pause
pause_with_hint
store
store_bigint
sub
sub_bigint
wait
wait_async
wait_async_bigint
wait_async_with_timeout
wait_async_with_timeout_bigint
wait_bigint
wait_with_timeout
wait_with_timeout_bigint
xor
xor_bigint