UseGrouping

Enum UseGrouping 

#[non_exhaustive]
pub enum UseGrouping { Always = 0, Auto = 1, Min2 = 2, True = 3, False = 4, }
Use grouping option for Intl.NumberFormat.

Determines whether to use grouping separators, such as thousands separators or thousand/lakh/crore separators.

The default is Min2 if notation is “compact”, and Auto otherwise.

Note: The string values "true" and "false" are accepted by JavaScript but are always converted to the default value. Use True and False variants for the boolean behavior.

MDN documentation

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Always = 0



Auto = 1



Min2 = 2



True = 3



False = 4

Implementations

Source

impl UseGrouping

pub fn from_str(s: &str) -> Option<UseGrouping>

Convert a string to this enum variant.

pub fn to_str(&self) -> &'static str

Convert this enum variant to its string representation.

pub fn from_js_value(obj: &JsValue) -> Option<UseGrouping>

Convert a JsValue (if it’s a string) to this enum variant.