pub struct DurationFormatOptions { /* private fields */ }Expand description
Options for Intl.DurationFormat constructor.
Implementations
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn get_locale_matcher(&self) -> Option<LocaleMatcher>
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn set_locale_matcher(&self, value: LocaleMatcher)
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn get_style(&self) -> Option<DurationFormatStyle>
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn set_style(&self, value: DurationFormatStyle)
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn get_years(&self) -> Option<DurationUnitStyle>
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn set_years(&self, value: DurationUnitStyle)
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn get_years_display(&self) -> Option<DurationUnitDisplay>
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn set_years_display(&self, value: DurationUnitDisplay)
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn get_months(&self) -> Option<DurationUnitStyle>
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn set_months(&self, value: DurationUnitStyle)
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn get_months_display(&self) -> Option<DurationUnitDisplay>
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn set_months_display(&self, value: DurationUnitDisplay)
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn get_weeks(&self) -> Option<DurationUnitStyle>
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn set_weeks(&self, value: DurationUnitStyle)
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn get_weeks_display(&self) -> Option<DurationUnitDisplay>
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn set_weeks_display(&self, value: DurationUnitDisplay)
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn get_days(&self) -> Option<DurationUnitStyle>
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn set_days(&self, value: DurationUnitStyle)
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn get_days_display(&self) -> Option<DurationUnitDisplay>
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn set_days_display(&self, value: DurationUnitDisplay)
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn get_hours(&self) -> Option<DurationTimeUnitStyle>
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn set_hours(&self, value: DurationTimeUnitStyle)
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn get_hours_display(&self) -> Option<DurationUnitDisplay>
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn set_hours_display(&self, value: DurationUnitDisplay)
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn get_minutes(&self) -> Option<DurationTimeUnitStyle>
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn set_minutes(&self, value: DurationTimeUnitStyle)
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn get_minutes_display(&self) -> Option<DurationUnitDisplay>
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn set_minutes_display(&self, value: DurationUnitDisplay)
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn get_seconds(&self) -> Option<DurationTimeUnitStyle>
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn set_seconds(&self, value: DurationTimeUnitStyle)
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn get_seconds_display(&self) -> Option<DurationUnitDisplay>
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn set_seconds_display(&self, value: DurationUnitDisplay)
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn get_milliseconds(&self) -> Option<DurationUnitStyle>
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn set_milliseconds(&self, value: DurationUnitStyle)
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn get_milliseconds_display(&self) -> Option<DurationUnitDisplay>
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn set_milliseconds_display(&self, value: DurationUnitDisplay)
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn get_microseconds(&self) -> Option<DurationUnitStyle>
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn set_microseconds(&self, value: DurationUnitStyle)
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn get_microseconds_display(&self) -> Option<DurationUnitDisplay>
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn set_microseconds_display(&self, value: DurationUnitDisplay)
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn get_nanoseconds(&self) -> Option<DurationUnitStyle>
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn set_nanoseconds(&self, value: DurationUnitStyle)
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn get_nanoseconds_display(&self) -> Option<DurationUnitDisplay>
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn set_nanoseconds_display(&self, value: DurationUnitDisplay)
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn get_fractional_digits(&self) -> Option<u8>
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn set_fractional_digits(&self, value: u8)
Sourceimpl DurationFormatOptions
impl DurationFormatOptions
pub fn new() -> DurationFormatOptions
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
👎Deprecated:
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.