construct

Function construct 

pub fn construct<T: JsFunction>(
    target: &Function<T>,
    arguments_list: &Array,
) -> Result<JsValue, JsValue>
where Function<T>: ErasableGenericBorrow<Function<fn() -> JsValue>> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Function<T>: BinaryEncode,
The static Reflect.construct() method acts like the new operator, but as a function. It is equivalent to calling new target(...args). It gives also the added option to specify a different prototype.

MDN documentation