Module WebAssembly

Module WebAssembly 

Structs

CompileError
The WebAssembly.CompileError() constructor creates a new WebAssembly CompileError object, which indicates an error during WebAssembly decoding or validation.
Exception
The WebAssembly.Exception() constructor creates a new Exception object
Global
The WebAssembly.Global() constructor creates a new Global object of the given type and value.
Instance
A WebAssembly.Instance object is a stateful, executable instance of a WebAssembly.Module. Instance objects contain all the exported WebAssembly functions that allow calling into WebAssembly code from JavaScript.
LinkError
The WebAssembly.LinkError() constructor creates a new WebAssembly LinkError object, which indicates an error during module instantiation (besides traps from the start function).
Memory
MDN documentation
Module
A WebAssembly.Module object contains stateless WebAssembly code that has already been compiled by the browser and can be efficiently shared with Workers, and instantiated multiple times.
RuntimeError
The WebAssembly.RuntimeError() constructor creates a new WebAssembly RuntimeError object — the type that is thrown whenever WebAssembly specifies a trap.
Table
The WebAssembly.Table() constructor creates a new Table object of the given size and element type.
Tag
The WebAssembly.Tag() constructor creates a new Tag object

Functions

compile
compile_streaming
instantiate_buffer
instantiate_module
instantiate_streaming
validate