ArrayTuple

Struct ArrayTuple 

#[repr(transparent)]
pub struct ArrayTuple<T: JsTuple = (JsValue,)> { pub obj: Object, pub generics: PhantomData<fn() -> (T,)>, }

Fields

obj: Objectgenerics: PhantomData<fn() -> (T,)>

Implementations

Source

impl<T1> ArrayTuple<(T1,)>

pub fn new1(t1: &T1) -> ArrayTuple<(T1,)>
where T1: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T1: BinaryEncode, ArrayTuple<(T1,)>: ErasableGenericOwn<ArrayTuple<(JsValue,)>> + EncodeTypeDef + BatchableResult,

Creates a new JS array typed as a 1-tuple.

Source

impl<T1, T2> ArrayTuple<(T1, T2)>

pub fn new2(t1: &T1, t2: &T2) -> ArrayTuple<(T1, T2)>
where T1: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T1: BinaryEncode, T2: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T2: BinaryEncode, ArrayTuple<(T1, T2)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue)>> + EncodeTypeDef + BatchableResult,

Creates a new JS array typed as a 2-tuple.

Source

impl<T1, T2, T3> ArrayTuple<(T1, T2, T3)>

pub fn new3(t1: &T1, t2: &T2, t3: &T3) -> ArrayTuple<(T1, T2, T3)>
where T1: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T1: BinaryEncode, T2: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T2: BinaryEncode, T3: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T3: BinaryEncode, ArrayTuple<(T1, T2, T3)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue, JsValue)>> + EncodeTypeDef + BatchableResult,

Creates a new JS array typed as a 3-tuple.

Source

impl<T1, T2, T3, T4> ArrayTuple<(T1, T2, T3, T4)>

pub fn new4(t1: &T1, t2: &T2, t3: &T3, t4: &T4) -> ArrayTuple<(T1, T2, T3, T4)>
where T1: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T1: BinaryEncode, T2: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T2: BinaryEncode, T3: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T3: BinaryEncode, T4: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T4: BinaryEncode, ArrayTuple<(T1, T2, T3, T4)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue, JsValue, JsValue)>> + EncodeTypeDef + BatchableResult,

Creates a new JS array typed as a 4-tuple.

Source

impl<T1, T2, T3, T4, T5> ArrayTuple<(T1, T2, T3, T4, T5)>

pub fn new5( t1: &T1, t2: &T2, t3: &T3, t4: &T4, t5: &T5, ) -> ArrayTuple<(T1, T2, T3, T4, T5)>
where T1: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T1: BinaryEncode, T2: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T2: BinaryEncode, T3: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T3: BinaryEncode, T4: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T4: BinaryEncode, T5: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T5: BinaryEncode, ArrayTuple<(T1, T2, T3, T4, T5)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue, JsValue, JsValue, JsValue)>> + EncodeTypeDef + BatchableResult,

Creates a new JS array typed as a 5-tuple.

Source

impl<T1, T2, T3, T4, T5, T6> ArrayTuple<(T1, T2, T3, T4, T5, T6)>

pub fn new6( t1: &T1, t2: &T2, t3: &T3, t4: &T4, t5: &T5, t6: &T6, ) -> ArrayTuple<(T1, T2, T3, T4, T5, T6)>
where T1: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T1: BinaryEncode, T2: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T2: BinaryEncode, T3: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T3: BinaryEncode, T4: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T4: BinaryEncode, T5: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T5: BinaryEncode, T6: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T6: BinaryEncode, ArrayTuple<(T1, T2, T3, T4, T5, T6)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue)>> + EncodeTypeDef + BatchableResult,

Creates a new JS array typed as a 6-tuple.

Source

impl<T1, T2, T3, T4, T5, T6, T7> ArrayTuple<(T1, T2, T3, T4, T5, T6, T7)>

pub fn new7( t1: &T1, t2: &T2, t3: &T3, t4: &T4, t5: &T5, t6: &T6, t7: &T7, ) -> ArrayTuple<(T1, T2, T3, T4, T5, T6, T7)>
where T1: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T1: BinaryEncode, T2: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T2: BinaryEncode, T3: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T3: BinaryEncode, T4: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T4: BinaryEncode, T5: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T5: BinaryEncode, T6: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T6: BinaryEncode, T7: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T7: BinaryEncode, ArrayTuple<(T1, T2, T3, T4, T5, T6, T7)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue)>> + EncodeTypeDef + BatchableResult,

Creates a new JS array typed as a 7-tuple.

Source

impl<T1, T2, T3, T4, T5, T6, T7, T8> ArrayTuple<(T1, T2, T3, T4, T5, T6, T7, T8)>

pub fn new8( t1: &T1, t2: &T2, t3: &T3, t4: &T4, t5: &T5, t6: &T6, t7: &T7, t8: &T8, ) -> ArrayTuple<(T1, T2, T3, T4, T5, T6, T7, T8)>
where T1: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T1: BinaryEncode, T2: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T2: BinaryEncode, T3: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T3: BinaryEncode, T4: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T4: BinaryEncode, T5: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T5: BinaryEncode, T6: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T6: BinaryEncode, T7: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T7: BinaryEncode, T8: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T8: BinaryEncode, ArrayTuple<(T1, T2, T3, T4, T5, T6, T7, T8)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue)>> + EncodeTypeDef + BatchableResult,

Creates a new JS array typed as a 8-tuple.

Source

impl<T: JsTuple1> ArrayTuple<T>

pub fn get0(&self) -> <T as JsTuple1>::T1
where <T as JsTuple1>::T1: ErasableGenericOwn<<(JsValue,) as JsTuple1>::T1> + EncodeTypeDef + BatchableResult,

Gets the 1st item

Source

impl<T: JsTuple2> ArrayTuple<T>

pub fn get1(&self) -> <T as JsTuple2>::T2
where <T as JsTuple2>::T2: ErasableGenericOwn<<(JsValue, JsValue) as JsTuple2>::T2> + EncodeTypeDef + BatchableResult,

Gets the 2nd item

Source

impl<T: JsTuple3> ArrayTuple<T>

pub fn get2(&self) -> <T as JsTuple3>::T3
where <T as JsTuple3>::T3: ErasableGenericOwn<<(JsValue, JsValue, JsValue) as JsTuple3>::T3> + EncodeTypeDef + BatchableResult,

Gets the 3rd item

Source

impl<T: JsTuple4> ArrayTuple<T>

pub fn get3(&self) -> <T as JsTuple4>::T4
where <T as JsTuple4>::T4: ErasableGenericOwn<<(JsValue, JsValue, JsValue, JsValue) as JsTuple4>::T4> + EncodeTypeDef + BatchableResult,

Gets the 4th item

Source

impl<T: JsTuple5> ArrayTuple<T>

pub fn get4(&self) -> <T as JsTuple5>::T5
where <T as JsTuple5>::T5: ErasableGenericOwn<<(JsValue, JsValue, JsValue, JsValue, JsValue) as JsTuple5>::T5> + EncodeTypeDef + BatchableResult,

Gets the 5th item

Source

impl<T: JsTuple6> ArrayTuple<T>

pub fn get5(&self) -> <T as JsTuple6>::T6
where <T as JsTuple6>::T6: ErasableGenericOwn<<(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue) as JsTuple6>::T6> + EncodeTypeDef + BatchableResult,

Gets the 6th item

Source

impl<T: JsTuple7> ArrayTuple<T>

pub fn get6(&self) -> <T as JsTuple7>::T7
where <T as JsTuple7>::T7: ErasableGenericOwn<<(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue) as JsTuple7>::T7> + EncodeTypeDef + BatchableResult,

Gets the 7th item

Source

impl<T: JsTuple8> ArrayTuple<T>

pub fn get7(&self) -> <T as JsTuple8>::T8

Gets the 8th item

Source

impl<T: JsTuple1> ArrayTuple<T>

pub fn set0(&self, value: &<T as JsTuple1>::T1)
where <T as JsTuple1>::T1: ErasableGenericBorrow<<(JsValue,) as JsTuple1>::T1>, for<'__wry_bindgen> &'__wry_bindgen <T as JsTuple1>::T1: EncodeTypeDef + BinaryEncode,

Sets the 1st item

Source

impl<T: JsTuple2> ArrayTuple<T>

pub fn set1(&self, value: &<T as JsTuple2>::T2)
where <T as JsTuple2>::T2: ErasableGenericBorrow<<(JsValue, JsValue) as JsTuple2>::T2>, for<'__wry_bindgen> &'__wry_bindgen <T as JsTuple2>::T2: EncodeTypeDef + BinaryEncode,

Sets the 2nd item

Source

impl<T: JsTuple3> ArrayTuple<T>

pub fn set2(&self, value: &<T as JsTuple3>::T3)
where <T as JsTuple3>::T3: ErasableGenericBorrow<<(JsValue, JsValue, JsValue) as JsTuple3>::T3>, for<'__wry_bindgen> &'__wry_bindgen <T as JsTuple3>::T3: EncodeTypeDef + BinaryEncode,

Sets the 3rd item

Source

impl<T: JsTuple4> ArrayTuple<T>

pub fn set3(&self, value: &<T as JsTuple4>::T4)
where <T as JsTuple4>::T4: ErasableGenericBorrow<<(JsValue, JsValue, JsValue, JsValue) as JsTuple4>::T4>, for<'__wry_bindgen> &'__wry_bindgen <T as JsTuple4>::T4: EncodeTypeDef + BinaryEncode,

Sets the 4th item

Source

impl<T: JsTuple5> ArrayTuple<T>

pub fn set4(&self, value: &<T as JsTuple5>::T5)
where <T as JsTuple5>::T5: ErasableGenericBorrow<<(JsValue, JsValue, JsValue, JsValue, JsValue) as JsTuple5>::T5>, for<'__wry_bindgen> &'__wry_bindgen <T as JsTuple5>::T5: EncodeTypeDef + BinaryEncode,

Sets the 5th item

Source

impl<T: JsTuple6> ArrayTuple<T>

pub fn set5(&self, value: &<T as JsTuple6>::T6)
where <T as JsTuple6>::T6: ErasableGenericBorrow<<(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue) as JsTuple6>::T6>, for<'__wry_bindgen> &'__wry_bindgen <T as JsTuple6>::T6: EncodeTypeDef + BinaryEncode,

Sets the 6th item

Source

impl<T: JsTuple7> ArrayTuple<T>

pub fn set6(&self, value: &<T as JsTuple7>::T7)
where <T as JsTuple7>::T7: ErasableGenericBorrow<<(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue) as JsTuple7>::T7>, for<'__wry_bindgen> &'__wry_bindgen <T as JsTuple7>::T7: EncodeTypeDef + BinaryEncode,

Sets the 7th item

Source

impl<T: JsTuple8> ArrayTuple<T>

pub fn set7(&self, value: &<T as JsTuple8>::T8)
where <T as JsTuple8>::T8: ErasableGenericBorrow<<(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue) as JsTuple8>::T8>, for<'__wry_bindgen> &'__wry_bindgen <T as JsTuple8>::T8: EncodeTypeDef + BinaryEncode,

Sets the 8th item

Source

impl<T: JsTuple> ArrayTuple<T>

pub fn len(&self) -> usize

Get the static arity of the ArrayTuple type.

Source

impl<T1: JsGeneric> ArrayTuple<(T1,)>

pub fn first(&self) -> T1

Get the first element of the ArrayTuple

pub fn last(&self) -> T1

Get the last element of the ArrayTuple

pub fn into_tuple(self) -> (T1,)

Convert the ArrayTuple into its corresponding Rust tuple.

pub fn into_parts(self) -> (T1,)

👎Deprecated:

renamed to into_tuple

Deprecated alias for ArrayTuple::into_tuple.

pub fn new(get0: &T1) -> ArrayTuple<(T1,)>

Create a new ArrayTuple from the corresponding parts.

Example
use js_sys::{ArrayTuple, JsString};

let tuple = ArrayTuple::<JsString, JsString>::new(&"a".into(), &"b".into());

Note: You must specify the T using ::<...> syntax on ArrayTuple. Alternatively, use new1, new2, etc. for type inference from the left-hand side.

Source

impl<T1: JsGeneric, T2: JsGeneric> ArrayTuple<(T1, T2)>

pub fn first(&self) -> T1

Get the first element of the ArrayTuple

pub fn last(&self) -> T2

Get the last element of the ArrayTuple

pub fn into_tuple(self) -> (T1, T2)

Convert the ArrayTuple into its corresponding Rust tuple.

pub fn into_parts(self) -> (T1, T2)

👎Deprecated:

renamed to into_tuple

Deprecated alias for ArrayTuple::into_tuple.

pub fn new(get0: &T1, get1: &T2) -> ArrayTuple<(T1, T2)>

Create a new ArrayTuple from the corresponding parts.

Example
use js_sys::{ArrayTuple, JsString};

let tuple = ArrayTuple::<JsString, JsString>::new(&"a".into(), &"b".into());

Note: You must specify the T using ::<...> syntax on ArrayTuple. Alternatively, use new1, new2, etc. for type inference from the left-hand side.

Source

impl<T1: JsGeneric, T2: JsGeneric, T3: JsGeneric> ArrayTuple<(T1, T2, T3)>

pub fn first(&self) -> T1

Get the first element of the ArrayTuple

pub fn last(&self) -> T3

Get the last element of the ArrayTuple

pub fn into_tuple(self) -> (T1, T2, T3)

Convert the ArrayTuple into its corresponding Rust tuple.

pub fn into_parts(self) -> (T1, T2, T3)

👎Deprecated:

renamed to into_tuple

Deprecated alias for ArrayTuple::into_tuple.

pub fn new(get0: &T1, get1: &T2, get2: &T3) -> ArrayTuple<(T1, T2, T3)>

Create a new ArrayTuple from the corresponding parts.

Example
use js_sys::{ArrayTuple, JsString};

let tuple = ArrayTuple::<JsString, JsString>::new(&"a".into(), &"b".into());

Note: You must specify the T using ::<...> syntax on ArrayTuple. Alternatively, use new1, new2, etc. for type inference from the left-hand side.

Source

impl<T1: JsGeneric, T2: JsGeneric, T3: JsGeneric, T4: JsGeneric> ArrayTuple<(T1, T2, T3, T4)>

pub fn first(&self) -> T1

Get the first element of the ArrayTuple

pub fn last(&self) -> T4

Get the last element of the ArrayTuple

pub fn into_tuple(self) -> (T1, T2, T3, T4)

Convert the ArrayTuple into its corresponding Rust tuple.

pub fn into_parts(self) -> (T1, T2, T3, T4)

👎Deprecated:

renamed to into_tuple

Deprecated alias for ArrayTuple::into_tuple.

pub fn new( get0: &T1, get1: &T2, get2: &T3, get3: &T4, ) -> ArrayTuple<(T1, T2, T3, T4)>

Create a new ArrayTuple from the corresponding parts.

Example
use js_sys::{ArrayTuple, JsString};

let tuple = ArrayTuple::<JsString, JsString>::new(&"a".into(), &"b".into());

Note: You must specify the T using ::<...> syntax on ArrayTuple. Alternatively, use new1, new2, etc. for type inference from the left-hand side.

Source

impl<T1: JsGeneric, T2: JsGeneric, T3: JsGeneric, T4: JsGeneric, T5: JsGeneric> ArrayTuple<(T1, T2, T3, T4, T5)>

pub fn first(&self) -> T1

Get the first element of the ArrayTuple

pub fn last(&self) -> T5

Get the last element of the ArrayTuple

pub fn into_tuple(self) -> (T1, T2, T3, T4, T5)

Convert the ArrayTuple into its corresponding Rust tuple.

pub fn into_parts(self) -> (T1, T2, T3, T4, T5)

👎Deprecated:

renamed to into_tuple

Deprecated alias for ArrayTuple::into_tuple.

pub fn new( get0: &T1, get1: &T2, get2: &T3, get3: &T4, get4: &T5, ) -> ArrayTuple<(T1, T2, T3, T4, T5)>

Create a new ArrayTuple from the corresponding parts.

Example
use js_sys::{ArrayTuple, JsString};

let tuple = ArrayTuple::<JsString, JsString>::new(&"a".into(), &"b".into());

Note: You must specify the T using ::<...> syntax on ArrayTuple. Alternatively, use new1, new2, etc. for type inference from the left-hand side.

Source

impl<T1: JsGeneric, T2: JsGeneric, T3: JsGeneric, T4: JsGeneric, T5: JsGeneric, T6: JsGeneric> ArrayTuple<(T1, T2, T3, T4, T5, T6)>

pub fn first(&self) -> T1

Get the first element of the ArrayTuple

pub fn last(&self) -> T6

Get the last element of the ArrayTuple

pub fn into_tuple(self) -> (T1, T2, T3, T4, T5, T6)

Convert the ArrayTuple into its corresponding Rust tuple.

pub fn into_parts(self) -> (T1, T2, T3, T4, T5, T6)

👎Deprecated:

renamed to into_tuple

Deprecated alias for ArrayTuple::into_tuple.

pub fn new( get0: &T1, get1: &T2, get2: &T3, get3: &T4, get4: &T5, get5: &T6, ) -> ArrayTuple<(T1, T2, T3, T4, T5, T6)>

Create a new ArrayTuple from the corresponding parts.

Example
use js_sys::{ArrayTuple, JsString};

let tuple = ArrayTuple::<JsString, JsString>::new(&"a".into(), &"b".into());

Note: You must specify the T using ::<...> syntax on ArrayTuple. Alternatively, use new1, new2, etc. for type inference from the left-hand side.

Source

impl<T1: JsGeneric, T2: JsGeneric, T3: JsGeneric, T4: JsGeneric, T5: JsGeneric, T6: JsGeneric, T7: JsGeneric> ArrayTuple<(T1, T2, T3, T4, T5, T6, T7)>

pub fn first(&self) -> T1

Get the first element of the ArrayTuple

pub fn last(&self) -> T7

Get the last element of the ArrayTuple

pub fn into_tuple(self) -> (T1, T2, T3, T4, T5, T6, T7)

Convert the ArrayTuple into its corresponding Rust tuple.

pub fn into_parts(self) -> (T1, T2, T3, T4, T5, T6, T7)

👎Deprecated:

renamed to into_tuple

Deprecated alias for ArrayTuple::into_tuple.

pub fn new( get0: &T1, get1: &T2, get2: &T3, get3: &T4, get4: &T5, get5: &T6, get6: &T7, ) -> ArrayTuple<(T1, T2, T3, T4, T5, T6, T7)>

Create a new ArrayTuple from the corresponding parts.

Example
use js_sys::{ArrayTuple, JsString};

let tuple = ArrayTuple::<JsString, JsString>::new(&"a".into(), &"b".into());

Note: You must specify the T using ::<...> syntax on ArrayTuple. Alternatively, use new1, new2, etc. for type inference from the left-hand side.

Source

impl<T1: JsGeneric, T2: JsGeneric, T3: JsGeneric, T4: JsGeneric, T5: JsGeneric, T6: JsGeneric, T7: JsGeneric, T8: JsGeneric> ArrayTuple<(T1, T2, T3, T4, T5, T6, T7, T8)>

pub fn first(&self) -> T1

Get the first element of the ArrayTuple

pub fn last(&self) -> T8

Get the last element of the ArrayTuple

pub fn into_tuple(self) -> (T1, T2, T3, T4, T5, T6, T7, T8)

Convert the ArrayTuple into its corresponding Rust tuple.

pub fn into_parts(self) -> (T1, T2, T3, T4, T5, T6, T7, T8)

👎Deprecated:

renamed to into_tuple

Deprecated alias for ArrayTuple::into_tuple.

pub fn new( get0: &T1, get1: &T2, get2: &T3, get3: &T4, get4: &T5, get5: &T6, get6: &T7, get7: &T8, ) -> ArrayTuple<(T1, T2, T3, T4, T5, T6, T7, T8)>

Create a new ArrayTuple from the corresponding parts.

Example
use js_sys::{ArrayTuple, JsString};

let tuple = ArrayTuple::<JsString, JsString>::new(&"a".into(), &"b".into());

Note: You must specify the T using ::<...> syntax on ArrayTuple. Alternatively, use new1, new2, etc. for type inference from the left-hand side.

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

The constructor property returns a reference to the Object constructor function that created the instance object.

MDN documentation

pub fn has_own_property(&self, property: &JsValue) -> bool

👎Deprecated:

Use Object::hasOwn instead.

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

pub fn is_prototype_of(&self, value: &JsValue) -> bool

The isPrototypeOf() method checks if an object exists in another object’s prototype chain.

MDN documentation

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

pub fn to_locale_string(&self) -> JsString

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn to_js_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn value_of(&self) -> Object

The valueOf() method returns the primitive value of the specified object.

MDN documentation

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn id(&self) -> u64

Get the heap ID for this value.

This is used internally for encoding values to send to JS.

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, other: &JsValue) -> bool

Less than comparison.

pub fn le(&self, other: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, other: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, other: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, other: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_array(&self) -> bool

Check if this value is an Array.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn is_null_or_undefined(&self) -> bool

Check if this value is null or undefined.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.