#[repr(transparent)]pub struct AsyncIterator<T = JsValue> {
pub obj: JsValue,
pub generics: PhantomData<fn() -> (T,)>,
}Expand description
Any object that conforms to the JS async iterator protocol. For example,
something returned by myObject[Symbol.asyncIterator]().
Fields
obj: JsValuegenerics: PhantomData<fn() -> (T,)>Implementations
Sourceimpl<T> AsyncIterator<T>
impl<T> AsyncIterator<T>
Sourcepub fn next(&self) -> Result<Promise, JsValue>
pub fn next(&self) -> Result<Promise, JsValue>
The next() method always has to return a Promise which resolves to an object
with appropriate properties including done and value. If a non-object value
gets returned (such as false or undefined), a TypeError (“iterator.next()
returned a non-object value”) will be thrown.
Sourceimpl<T: FromWasmAbi> AsyncIterator<T>
impl<T: FromWasmAbi> AsyncIterator<T>
Sourcepub fn next_iterator(&self) -> Result<Promise<IteratorNext<T>>, JsValue>where
Result<Promise<IteratorNext<T>>, JsValue>: ErasableGenericOwn<Result<Promise<IteratorNext<JsValue>>, JsValue>> + EncodeTypeDef + BatchableResult,
pub fn next_iterator(&self) -> Result<Promise<IteratorNext<T>>, JsValue>where
Result<Promise<IteratorNext<T>>, JsValue>: ErasableGenericOwn<Result<Promise<IteratorNext<JsValue>>, JsValue>> + EncodeTypeDef + BatchableResult,
The next() method always has to return a Promise which resolves to an object
with appropriate properties including done and value. If a non-object value
gets returned (such as false or undefined), a TypeError (“iterator.next()
returned a non-object value”) will be thrown.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.