#[repr(transparent)]pub struct Generator<T = JsValue> {
pub obj: Object,
pub generics: PhantomData<fn() -> (T,)>,
}Fields
obj: Objectgenerics: PhantomData<fn() -> (T,)>Implementations
Sourceimpl<T> Generator<T>
impl<T> Generator<T>
Sourcepub fn next(&self, value: &T) -> Result<JsValue, JsValue>where
T: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,
pub fn next(&self, value: &T) -> Result<JsValue, JsValue>where
T: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,
The next() method returns an object with two properties done and value.
You can also provide a parameter to the next method to send a value to the generator.
Sourceimpl<T: FromWasmAbi> Generator<T>
impl<T: FromWasmAbi> Generator<T>
Sourcepub fn next_iterator(&self, value: &T) -> Result<IteratorNext<T>, JsValue>where
T: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,
Result<IteratorNext<T>, JsValue>: ErasableGenericOwn<Result<IteratorNext<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
pub fn next_iterator(&self, value: &T) -> Result<IteratorNext<T>, JsValue>where
T: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,
Result<IteratorNext<T>, JsValue>: ErasableGenericOwn<Result<IteratorNext<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
The next() method returns an object with two properties done and value.
You can also provide a parameter to the next method to send a value to the generator.
Sourceimpl<T> Generator<T>
impl<T> Generator<T>
Sourcepub fn return_(&self, value: &T) -> JsValuewhere
T: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,
pub fn return_(&self, value: &T) -> JsValuewhere
T: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,
The return() method returns the given value and finishes the generator.
Sourceimpl<T: FromWasmAbi> Generator<T>
impl<T: FromWasmAbi> Generator<T>
Sourcepub fn try_return(&self, value: &T) -> Result<IteratorNext<T>, JsValue>where
T: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,
Result<IteratorNext<T>, JsValue>: ErasableGenericOwn<Result<IteratorNext<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
pub fn try_return(&self, value: &T) -> Result<IteratorNext<T>, JsValue>where
T: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,
Result<IteratorNext<T>, JsValue>: ErasableGenericOwn<Result<IteratorNext<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
The return() method returns the given value and finishes the generator.
Sourceimpl<T: FromWasmAbi> Generator<T>
impl<T: FromWasmAbi> Generator<T>
Sourcepub fn throw_value(&self, error: &JsValue) -> Result<IteratorNext<T>, JsValue>where
Result<IteratorNext<T>, JsValue>: ErasableGenericOwn<Result<IteratorNext<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
pub fn throw_value(&self, error: &JsValue) -> Result<IteratorNext<T>, JsValue>where
Result<IteratorNext<T>, JsValue>: ErasableGenericOwn<Result<IteratorNext<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
The throw() method resumes the execution of a generator by throwing an error into it
and returns an object with two properties done and value.
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
👎Deprecated: Use Object::hasOwn instead.
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Sourcepub fn to_js_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.