Int16Array

Struct Int16Array 

pub struct Int16Array { /* private fields */ }

Implementations

Source

impl Int16Array

pub fn new(constructor_arg: &JsValue) -> Int16Array

Source

impl Int16Array

Source

impl Int16Array

pub fn new_from_slice(slice: &[i16]) -> Int16Array

Source

impl Int16Array

pub fn new_with_byte_offset(buffer: &JsValue, byte_offset: u32) -> Int16Array

Source

impl Int16Array

pub fn new_with_byte_offset_and_length( buffer: &JsValue, byte_offset: u32, length: u32, ) -> Int16Array

Source

impl Int16Array

pub fn fill(&self, value: i16, start: u32, end: u32) -> Int16Array

Source

impl Int16Array

pub fn buffer(&self) -> ArrayBuffer

Source

impl Int16Array

pub fn subarray(&self, begin: u32, end: u32) -> Int16Array

Source

impl Int16Array

pub fn slice(&self, begin: u32, end: u32) -> Int16Array

Source

impl Int16Array

pub fn for_each(&self, callback: &mut dyn FnMut(i16, u32, Int16Array))

Source

impl Int16Array

pub fn try_for_each( &self, callback: &mut dyn FnMut(i16, u32, Int16Array) -> Result<(), JsError>, ) -> Result<(), JsValue>

Source

impl Int16Array

pub fn length(&self) -> u32

Source

impl Int16Array

pub fn byte_length(&self) -> u32

Source

impl Int16Array

pub fn byte_offset(&self) -> u32

Source

impl Int16Array

pub fn set(&self, src: &JsValue, offset: u32)

Source

impl Int16Array

pub fn at(&self, idx: i32) -> Option<i16>

Source

impl Int16Array

pub fn copy_within(&self, target: i32, start: i32, end: i32) -> Int16Array

Source

impl Int16Array

pub fn get_index(&self, idx: u32) -> i16

Source

impl Int16Array

pub fn set_index(&self, idx: u32, value: i16)

Source

impl Int16Array

pub unsafe fn view(rust: &[i16]) -> Int16Array

Creates a JS typed array which is a view into wasm’s linear memory at the slice specified.

This function returns a new typed array which is a view into wasm’s memory. This view does not copy the underlying data.

Safety

Views into WebAssembly memory are only valid so long as the backing buffer isn’t resized in JS. Once this function is called any future calls to Box::new (or malloc of any form) may cause the returned value here to be invalidated. Use with caution!

Additionally the returned object can be safely mutated but the input slice isn’t guaranteed to be mutable.

Finally, the returned object is disconnected from the input slice’s lifetime, so there’s no guarantee that the data is read at the right time.

pub unsafe fn view_mut_raw(ptr: *mut i16, length: usize) -> Int16Array

Creates a JS typed array which is a view into wasm’s linear memory at the specified pointer with specified length.

This function returns a new typed array which is a view into wasm’s memory. This view does not copy the underlying data.

Safety

Views into WebAssembly memory are only valid so long as the backing buffer isn’t resized in JS. Once this function is called any future calls to Box::new (or malloc of any form) may cause the returned value here to be invalidated. Use with caution!

Additionally the returned object can be safely mutated, the changes are guaranteed to be reflected in the input array.

pub unsafe fn raw_copy_to_ptr(&self, dst: *mut i16)

Copy the contents of this JS typed array into the destination Rust pointer.

This function will efficiently copy the memory from a typed array into this Wasm module’s own linear memory, initializing the memory destination provided.

Safety

This function requires dst to point to a buffer large enough to fit this array’s contents.

pub fn copy_to(&self, dst: &mut [i16])

Copy the contents of this JS typed array into the destination Rust slice.

This function will efficiently copy the memory from a typed array into this Wasm module’s own linear memory, initializing the memory destination provided.

Panics

This function will panic if this typed array’s length is different than the length of the provided dst array.

pub fn copy_to_uninit<'dst>( &self, dst: &'dst mut [MaybeUninit<i16>], ) -> &'dst mut [i16]

Copy the contents of this JS typed array into the destination Rust slice.

This function will efficiently copy the memory from a typed array into this Wasm module’s own linear memory, initializing the memory destination provided.

Panics

This function will panic if this typed array’s length is different than the length of the provided dst array.

pub fn copy_from(&self, src: &[i16])

Copy the contents of the source Rust slice into this JS typed array.

This function will efficiently copy the memory from within the Wasm module’s own linear memory to this typed array.

Panics

This function will panic if this typed array’s length is different than the length of the provided src array.

pub fn to_vec(&self) -> Vec<i16>

Efficiently copies the contents of this JS typed array into a new Vec.

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

pub fn has_own_property(&self, property: &JsValue) -> bool

👎Deprecated:

Use Object::hasOwn instead.

pub fn is_prototype_of(&self, value: &JsValue) -> bool

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

pub fn to_locale_string(&self) -> JsString

pub fn to_string(&self) -> JsString

pub fn to_js_string(&self) -> JsString

pub fn value_of(&self) -> Object

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, other: &JsValue) -> bool

Less than comparison.

pub fn le(&self, other: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, other: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, other: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, other: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_array(&self) -> bool

Check if this value is an Array.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn is_null_or_undefined(&self) -> bool

Check if this value is null or undefined.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.