pub struct Int8Array { /* private fields */ }Implementations
Sourceimpl Int8Array
impl Int8Array
pub fn new_with_byte_offset(buffer: &JsValue, byte_offset: u32) -> Int8Array
Sourceimpl Int8Array
impl Int8Array
Sourcepub unsafe fn view(rust: &[i8]) -> Int8Array
pub unsafe fn view(rust: &[i8]) -> Int8Array
Creates a JS typed array which is a view into wasm’s linear memory at the slice specified.
This function returns a new typed array which is a view into wasm’s memory. This view does not copy the underlying data.
Safety
Views into WebAssembly memory are only valid so long as the
backing buffer isn’t resized in JS. Once this function is called
any future calls to Box::new (or malloc of any form) may cause
the returned value here to be invalidated. Use with caution!
Additionally the returned object can be safely mutated but the input slice isn’t guaranteed to be mutable.
Finally, the returned object is disconnected from the input slice’s lifetime, so there’s no guarantee that the data is read at the right time.
Sourcepub unsafe fn view_mut_raw(ptr: *mut i8, length: usize) -> Int8Array
pub unsafe fn view_mut_raw(ptr: *mut i8, length: usize) -> Int8Array
Creates a JS typed array which is a view into wasm’s linear memory at the specified pointer with specified length.
This function returns a new typed array which is a view into wasm’s memory. This view does not copy the underlying data.
Safety
Views into WebAssembly memory are only valid so long as the
backing buffer isn’t resized in JS. Once this function is called
any future calls to Box::new (or malloc of any form) may cause
the returned value here to be invalidated. Use with caution!
Additionally the returned object can be safely mutated, the changes are guaranteed to be reflected in the input array.
Sourcepub unsafe fn raw_copy_to_ptr(&self, dst: *mut i8)
pub unsafe fn raw_copy_to_ptr(&self, dst: *mut i8)
Copy the contents of this JS typed array into the destination Rust pointer.
This function will efficiently copy the memory from a typed array into this Wasm module’s own linear memory, initializing the memory destination provided.
Safety
This function requires dst to point to a buffer
large enough to fit this array’s contents.
Sourcepub fn copy_to(&self, dst: &mut [i8])
pub fn copy_to(&self, dst: &mut [i8])
Copy the contents of this JS typed array into the destination Rust slice.
This function will efficiently copy the memory from a typed array into this Wasm module’s own linear memory, initializing the memory destination provided.
Panics
This function will panic if this typed array’s length is
different than the length of the provided dst array.
Sourcepub fn copy_to_uninit<'dst>(
&self,
dst: &'dst mut [MaybeUninit<i8>],
) -> &'dst mut [i8]
pub fn copy_to_uninit<'dst>( &self, dst: &'dst mut [MaybeUninit<i8>], ) -> &'dst mut [i8]
Copy the contents of this JS typed array into the destination Rust slice.
This function will efficiently copy the memory from a typed array into this Wasm module’s own linear memory, initializing the memory destination provided.
Panics
This function will panic if this typed array’s length is
different than the length of the provided dst array.
Sourcepub fn copy_from(&self, src: &[i8])
pub fn copy_from(&self, src: &[i8])
Copy the contents of the source Rust slice into this JS typed array.
This function will efficiently copy the memory from within the Wasm module’s own linear memory to this typed array.
Panics
This function will panic if this typed array’s length is
different than the length of the provided src array.
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.