Map

Struct Map 

#[repr(transparent)]
pub struct Map<K = JsValue, V = JsValue> { pub obj: Object, pub generics: PhantomData<fn() -> (K, V)>, }

Fields

obj: Objectgenerics: PhantomData<fn() -> (K, V)>

Implementations

Source

impl Map

pub fn new() -> Map

The Map object holds key-value pairs. Any value (both objects and primitive values) maybe used as either a key or a value.

Note: Consider using Map::new_typed for typing support.

MDN documentation

Source

impl<K, V> Map<K, V>

pub fn new_typed() -> Map<K, V>
where Map<K, V>: ErasableGenericOwn<Map<JsValue, JsValue>> + EncodeTypeDef + BatchableResult,

The Map object holds key-value pairs. Any value (both objects and primitive values) maybe used as either a key or a value.

MDN documentation

Source

impl<K, V> Map<K, V>

pub fn new_from_entries<I>(entries: &I) -> Map<K, V>
where I: ErasableGenericBorrow<JsValue> + EncodeTypeDef + Iterable<Item = ArrayTuple<(K, V)>>, for<'__wry_bindgen> &'__wry_bindgen I: BinaryEncode, Map<K, V>: ErasableGenericOwn<Map<JsValue, JsValue>> + EncodeTypeDef + BatchableResult,

The Map object holds key-value pairs. Any value (both objects and primitive values) maybe used as either a key or a value.

MDN documentation

Source

impl<K, V> Map<K, V>

pub fn clear(&self)

The clear() method removes all elements from a Map object.

MDN documentation

Source

impl<K, V> Map<K, V>

pub fn delete(&self, key: &K) -> bool
where K: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen K: BinaryEncode,

The delete() method removes the specified element from a Map object.

MDN documentation

Source

impl<K, V> Map<K, V>

pub fn for_each(&self, callback: &mut dyn FnMut(V, K))
where dyn FnMut(V, K): ErasableGenericBorrowMut<dyn FnMut(JsValue, JsValue)>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(V, K): EncodeTypeDef + BinaryEncode,

The forEach() method executes a provided function once per each key/value pair in the Map object, in insertion order. Note that in Javascript land the Key and Value are reversed compared to normal expectations:

Examples
let js_map = Map::new();
js_map.for_each(&mut |value, key| {
    // Do something here...
})

MDN documentation

Source

impl<K, V> Map<K, V>

pub fn try_for_each( &self, callback: &mut dyn FnMut(V, K) -> Result<(), JsError>, ) -> Result<(), JsValue>
where dyn FnMut(V, K) -> Result<(), JsError>: ErasableGenericBorrowMut<dyn FnMut(JsValue, JsValue) -> Result<(), JsError>>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(V, K) -> Result<(), JsError>: EncodeTypeDef + BinaryEncode,

The forEach() method executes a provided function once per each key/value pair in the Map object, in insertion order. (Fallible variation) Note that in Javascript land the Key and Value are reversed compared to normal expectations:

Examples
let js_map = Map::new();
js_map.for_each(&mut |value, key| {
    // Do something here...
})

Note: Consider using Map::try_for_each if the callback might throw an error.

MDN documentation

Source

impl<K, V> Map<K, V>

pub fn get(&self, key: &K) -> V
where K: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen K: BinaryEncode, V: ErasableGenericOwn<JsValue> + EncodeTypeDef + BatchableResult,

The get() method returns a specified element from a Map object. Returns undefined if the key is not found.

Note: Consider using Map::get_checked to get an Option<V> instead.

MDN documentation

Source

impl<K, V> Map<K, V>

pub fn get_checked(&self, key: &K) -> Option<V>
where K: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen K: BinaryEncode, Option<V>: ErasableGenericOwn<Option<JsValue>> + EncodeTypeDef + BatchableResult,

The get() method returns a specified element from a Map object. Returns None if the key is not found.

MDN documentation

Source

impl<K, V> Map<K, V>

pub fn has(&self, key: &K) -> bool
where K: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen K: BinaryEncode,

The has() method returns a boolean indicating whether an element with the specified key exists or not.

MDN documentation

Source

impl<K, V> Map<K, V>

pub fn set(&self, key: &K, value: &V) -> Map<K, V>
where K: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen K: BinaryEncode, V: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen V: BinaryEncode, Map<K, V>: ErasableGenericOwn<Map<JsValue, JsValue>> + EncodeTypeDef + BatchableResult,

The set() method adds or updates an element with a specified key and value to a Map object.

MDN documentation

Source

impl<K, V> Map<K, V>

pub fn size(&self) -> u32

The value of size is an integer representing how many entries the Map object has. A set accessor function for size is undefined; you can not change this property.

MDN documentation

Source

impl<K, V: FromWasmAbi> Map<K, V>

pub fn entries(&self) -> Iterator

The entries() method returns a new Iterator object that contains the [key, value] pairs for each element in the Map object in insertion order.

MDN documentation

Source

impl<K: JsGeneric, V: FromWasmAbi + JsGeneric> Map<K, V>

pub fn entries_typed(&self) -> Iterator<ArrayTuple<(K, V)>>

The entries() method returns a new Iterator object that contains the [key, value] pairs for each element in the Map object in insertion order.

MDN documentation

Source

impl<K: FromWasmAbi, V: FromWasmAbi> Map<K, V>

pub fn keys(&self) -> Iterator<K>
where Iterator<K>: ErasableGenericOwn<Iterator<JsValue>> + EncodeTypeDef + BatchableResult,

The keys() method returns a new Iterator object that contains the keys for each element in the Map object in insertion order.

MDN documentation

Source

impl<K, V: FromWasmAbi> Map<K, V>

pub fn values(&self) -> Iterator<V>
where Iterator<V>: ErasableGenericOwn<Iterator<JsValue>> + EncodeTypeDef + BatchableResult,

The values() method returns a new Iterator object that contains the values for each element in the Map object in insertion order.

MDN documentation

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

The constructor property returns a reference to the Object constructor function that created the instance object.

MDN documentation

pub fn has_own_property(&self, property: &JsValue) -> bool

👎Deprecated:

Use Object::hasOwn instead.

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

pub fn is_prototype_of(&self, value: &JsValue) -> bool

The isPrototypeOf() method checks if an object exists in another object’s prototype chain.

MDN documentation

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

pub fn to_locale_string(&self) -> JsString

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn to_js_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn value_of(&self) -> Object

The valueOf() method returns the primitive value of the specified object.

MDN documentation

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn id(&self) -> u64

Get the heap ID for this value.

This is used internally for encoding values to send to JS.

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, other: &JsValue) -> bool

Less than comparison.

pub fn le(&self, other: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, other: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, other: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, other: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_array(&self) -> bool

Check if this value is an Array.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn is_null_or_undefined(&self) -> bool

Check if this value is null or undefined.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.