Number

Struct Number 

#[repr(transparent)]
pub struct Number { pub obj: Object, }

Fields

obj: Object

Implementations

Source

impl Number

pub fn is_finite(value: &JsValue) -> bool

The Number.isFinite() method determines whether the passed value is a finite number.

MDN documentation

Source

impl Number

pub fn is_integer(value: &JsValue) -> bool

The Number.isInteger() method determines whether the passed value is an integer.

MDN documentation

Source

impl Number

pub fn is_nan(value: &JsValue) -> bool

The Number.isNaN() method determines whether the passed value is NaN and its type is Number. It is a more robust version of the original, global isNaN().

MDN documentation

Source

impl Number

pub fn is_safe_integer(value: &JsValue) -> bool

The Number.isSafeInteger() method determines whether the provided value is a number that is a safe integer.

MDN documentation

Source

impl Number

pub fn new(value: &JsValue) -> Number

👎Deprecated:

recommended to use Number::from instead

The Number JavaScript object is a wrapper object allowing you to work with numerical values. A Number object is created using the Number() constructor.

MDN documentation

Source

impl Number

pub fn parse_int(text: &str, radix: u8) -> f64

The Number.parseInt() method parses a string argument and returns an integer of the specified radix or base.

MDN documentation

Source

impl Number

pub fn parse_float(text: &str) -> f64

The Number.parseFloat() method parses a string argument and returns a floating point number.

MDN documentation

Source

impl Number

pub fn to_locale_string(&self, locale: &str) -> JsString

The toLocaleString() method returns a string with a language sensitive representation of this number.

MDN documentation

Source

impl Number

pub fn to_precision(&self, precision: u8) -> Result<JsString, JsValue>

The toPrecision() method returns a string representing the Number object to the specified precision.

MDN documentation

Source

impl Number

pub fn to_fixed(&self, digits: u8) -> Result<JsString, JsValue>

The toFixed() method returns a string representing the Number object using fixed-point notation.

MDN documentation

Source

impl Number

pub fn to_exponential(&self, fraction_digits: u8) -> Result<JsString, JsValue>

The toExponential() method returns a string representing the Number object in exponential notation.

MDN documentation

Source

impl Number

pub fn to_string(&self, radix: u8) -> Result<JsString, JsValue>

👎Deprecated:

Use Number::to_string_with_radix instead.

The toString() method returns a string representing the specified Number object.

MDN documentation

Source

impl Number

pub fn to_string_with_radix(&self, radix: u8) -> Result<JsString, JsValue>

The toString() method returns a string representing the specified Number object.

MDN documentation

Source

impl Number

pub fn value_of(&self) -> f64

The valueOf() method returns the wrapped primitive value of a Number object.

MDN documentation

Source

impl Number

pub const EPSILON: f64 = f64::EPSILON

The smallest interval between two representable numbers.

MDN Documentation

pub const MAX_SAFE_INTEGER: f64 = 9007199254740991.0

The maximum safe integer in JavaScript (2^53 - 1).

MDN Documentation

pub const MAX_VALUE: f64 = f64::MAX

The largest positive representable number.

MDN Documentation

pub const MIN_SAFE_INTEGER: f64 = -9007199254740991.0

The minimum safe integer in JavaScript (-(2^53 - 1)).

MDN Documentation

pub const MIN_VALUE: f64 = 5E-324

The smallest positive representable number—that is, the positive number closest to zero (without actually being zero).

MDN Documentation

pub const NAN: f64 = f64::NAN

Special “Not a Number” value.

MDN Documentation

pub const NEGATIVE_INFINITY: f64 = f64::NEG_INFINITY

Special value representing negative infinity. Returned on overflow.

MDN Documentation

pub const POSITIVE_INFINITY: f64 = f64::INFINITY

Special value representing infinity. Returned on overflow.

MDN Documentation

pub fn pow(&self, rhs: &Self) -> Self

Applies the binary ** JS operator on the two Numbers.

MDN documentation

pub fn unsigned_shr(&self, rhs: &Self) -> Self

Applies the binary >>> JS operator on the two Numbers.

MDN documentation

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

The constructor property returns a reference to the Object constructor function that created the instance object.

MDN documentation

pub fn has_own_property(&self, property: &JsValue) -> bool

👎Deprecated:

Use Object::hasOwn instead.

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

pub fn is_prototype_of(&self, value: &JsValue) -> bool

The isPrototypeOf() method checks if an object exists in another object’s prototype chain.

MDN documentation

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

pub fn to_locale_string(&self) -> JsString

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn to_js_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn value_of(&self) -> Object

The valueOf() method returns the primitive value of the specified object.

MDN documentation

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn id(&self) -> u64

Get the heap ID for this value.

This is used internally for encoding values to send to JS.

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, other: &JsValue) -> bool

Less than comparison.

pub fn le(&self, other: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, other: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, other: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, other: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_array(&self) -> bool

Check if this value is an Array.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn is_null_or_undefined(&self) -> bool

Check if this value is null or undefined.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.