#[repr(transparent)]pub struct WeakMap<K = Object, V = JsValue> {
pub obj: Object,
pub generics: PhantomData<fn() -> (K, V)>,
}Fields
obj: Objectgenerics: PhantomData<fn() -> (K, V)>Implementations
Sourceimpl WeakMap
impl WeakMap
Sourcepub fn new() -> WeakMap
pub fn new() -> WeakMap
The WeakMap object is a collection of key/value pairs in which the
keys are weakly referenced. The keys must be objects and the values can
be arbitrary values.
Note: Consider using WeakMap::new_typed to support typing.
Sourceimpl<K: JsGeneric, V: JsGeneric> WeakMap<K, V>
impl<K: JsGeneric, V: JsGeneric> WeakMap<K, V>
Sourceimpl<K, V> WeakMap<K, V>
impl<K, V> WeakMap<K, V>
Sourcepub fn set(&self, key: &K, value: &V) -> WeakMap<K, V>where
K: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen K: BinaryEncode,
V: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen V: BinaryEncode,
WeakMap<K, V>: ErasableGenericOwn<WeakMap<JsValue, JsValue>> + EncodeTypeDef + BatchableResult,
pub fn set(&self, key: &K, value: &V) -> WeakMap<K, V>where
K: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen K: BinaryEncode,
V: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen V: BinaryEncode,
WeakMap<K, V>: ErasableGenericOwn<WeakMap<JsValue, JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl<K, V> WeakMap<K, V>
impl<K, V> WeakMap<K, V>
Sourcepub fn get(&self, key: &K) -> Vwhere
K: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen K: BinaryEncode,
V: ErasableGenericOwn<JsValue> + EncodeTypeDef + BatchableResult,
pub fn get(&self, key: &K) -> Vwhere
K: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen K: BinaryEncode,
V: ErasableGenericOwn<JsValue> + EncodeTypeDef + BatchableResult,
The get() method returns a specified by key element
from a WeakMap object. Returns undefined if the key is not found.
Note: Consider using WeakMap::get_checked to get an Option<V> instead.
Sourceimpl<K, V> WeakMap<K, V>
impl<K, V> WeakMap<K, V>
Sourcepub fn get_checked(&self, key: &K) -> Option<V>where
K: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen K: BinaryEncode,
Option<V>: ErasableGenericOwn<Option<JsValue>> + EncodeTypeDef + BatchableResult,
pub fn get_checked(&self, key: &K) -> Option<V>where
K: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen K: BinaryEncode,
Option<V>: ErasableGenericOwn<Option<JsValue>> + EncodeTypeDef + BatchableResult,
The get() method returns a specified by key element
from a WeakMap object. Returns None if the key is not found.
Sourceimpl<K, V> WeakMap<K, V>
impl<K, V> WeakMap<K, V>
Sourcepub fn has(&self, key: &K) -> boolwhere
K: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen K: BinaryEncode,
pub fn has(&self, key: &K) -> boolwhere
K: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen K: BinaryEncode,
The has() method returns a boolean indicating whether an element with
the specified key exists in the WeakMap object or not.
Sourceimpl<K, V> WeakMap<K, V>
impl<K, V> WeakMap<K, V>
Sourcepub fn delete(&self, key: &K) -> boolwhere
K: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen K: BinaryEncode,
pub fn delete(&self, key: &K) -> boolwhere
K: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen K: BinaryEncode,
The delete() method removes the specified element from a WeakMap
object.
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
👎Deprecated: Use Object::hasOwn instead.
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Sourcepub fn to_js_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.