The Atomics object provides atomic operations as static methods.
They are used with SharedArrayBuffer objects.
The Atomic operations are installed on an Atomics module. Unlike
the other global objects, Atomics is not a constructor. You cannot
use it with a new operator or invoke the Atomics object as a
function. All properties and methods of Atomics are static
(as is the case with the Math object, for example).
MDN documentation
Functions
- add
- add_
bigint - and
- and_
bigint - compare_
exchange - compare_
exchange_ bigint - exchange
- exchange_
bigint - is_
lock_ free - load
- load_
bigint - notify
- notify_
bigint - notify_
bigint_ with_ count - notify_
with_ count - or
- or_
bigint - pause
- pause_
with_ hint - store
- store_
bigint - sub
- sub_
bigint - wait
- wait_
async - wait_
async_ bigint - wait_
async_ with_ timeout - wait_
async_ with_ timeout_ bigint - wait_
bigint - wait_
with_ timeout - wait_
with_ timeout_ bigint - xor
- xor_
bigint