#[repr(transparent)]pub struct DateTimeFormatOptions {
pub obj: Object,
}Expand description
Options for Intl.DateTimeFormat constructor.
Fields
obj: ObjectImplementations
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn get_locale_matcher(&self) -> Option<LocaleMatcher>
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn set_locale_matcher(&self, value: LocaleMatcher)
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn get_calendar(&self) -> Option<JsString>
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn set_calendar(&self, value: &str)
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn get_numbering_system(&self) -> Option<JsString>
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn set_numbering_system(&self, value: &str)
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn get_time_zone(&self) -> Option<JsString>
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn set_time_zone(&self, value: &str)
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn get_hour12(&self) -> Option<bool>
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn set_hour12(&self, value: bool)
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn get_hour_cycle(&self) -> Option<HourCycle>
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn set_hour_cycle(&self, value: HourCycle)
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn get_date_style(&self) -> Option<DateTimeStyle>
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn set_date_style(&self, value: DateTimeStyle)
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn get_time_style(&self) -> Option<DateTimeStyle>
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn set_time_style(&self, value: DateTimeStyle)
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn get_weekday(&self) -> Option<WeekdayFormat>
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn set_weekday(&self, value: WeekdayFormat)
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn get_year(&self) -> Option<YearFormat>
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn set_year(&self, value: YearFormat)
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn get_month(&self) -> Option<MonthFormat>
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn set_month(&self, value: MonthFormat)
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn get_hour(&self) -> Option<NumericFormat>
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn set_hour(&self, value: NumericFormat)
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn get_minute(&self) -> Option<NumericFormat>
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn set_minute(&self, value: NumericFormat)
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn get_second(&self) -> Option<NumericFormat>
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn set_second(&self, value: NumericFormat)
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn get_fractional_second_digits(&self) -> Option<u8>
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn set_fractional_second_digits(&self, value: u8)
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn get_time_zone_name(&self) -> Option<TimeZoneNameFormat>
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn set_time_zone_name(&self, value: TimeZoneNameFormat)
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn get_day_period(&self) -> Option<DayPeriodFormat>
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn set_day_period(&self, value: DayPeriodFormat)
Sourceimpl DateTimeFormatOptions
impl DateTimeFormatOptions
pub fn new() -> DateTimeFormatOptions
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
👎Deprecated: Use Object::hasOwn instead.
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Sourcepub fn to_js_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.