#[repr(transparent)]pub struct DurationFormat {
pub obj: Object,
}Expand description
The Intl.DurationFormat object enables language-sensitive duration formatting.
Fields
obj: ObjectImplementations
Sourceimpl DurationFormat
impl DurationFormat
Sourcepub fn new(
locales: &[JsString],
options: &DurationFormatOptions,
) -> Result<DurationFormat, JsValue>
pub fn new( locales: &[JsString], options: &DurationFormatOptions, ) -> Result<DurationFormat, JsValue>
Creates a new Intl.DurationFormat object.
Throws a RangeError if locales or options contain invalid values.
Sourceimpl DurationFormat
impl DurationFormat
Sourceimpl DurationFormat
impl DurationFormat
Sourcepub fn format_to_parts(&self, duration: &Duration) -> Array<DurationFormatPart>
pub fn format_to_parts(&self, duration: &Duration) -> Array<DurationFormatPart>
Returns an array of objects representing the formatted duration in parts.
Sourceimpl DurationFormat
impl DurationFormat
Sourcepub fn resolved_options(&self) -> ResolvedDurationFormatOptions
pub fn resolved_options(&self) -> ResolvedDurationFormatOptions
Returns an object with properties reflecting the options used.
Sourceimpl DurationFormat
impl DurationFormat
Sourcepub fn supported_locales_of(
locales: &[JsString],
options: &LocaleMatcherOptions,
) -> Result<Array<JsString>, JsValue>
pub fn supported_locales_of( locales: &[JsString], options: &LocaleMatcherOptions, ) -> Result<Array<JsString>, JsValue>
Returns an array of supported locales.
Throws a RangeError if locales contain invalid values.
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
👎Deprecated: Use Object::hasOwn instead.
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Sourcepub fn to_js_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.