pub struct ResolvedDateTimeFormatOptions { /* private fields */ }Expand description
Resolved options returned by Intl.DateTimeFormat.prototype.resolvedOptions().
Implementations
Sourceimpl ResolvedDateTimeFormatOptions
impl ResolvedDateTimeFormatOptions
pub fn get_locale(&self) -> JsString
Methods from Deref<Target = DateTimeFormatOptions>
pub fn get_locale_matcher(&self) -> Option<LocaleMatcher>
pub fn set_locale_matcher(&self, value: LocaleMatcher)
pub fn get_calendar(&self) -> Option<JsString>
pub fn set_calendar(&self, value: &str)
pub fn get_numbering_system(&self) -> Option<JsString>
pub fn set_numbering_system(&self, value: &str)
pub fn get_time_zone(&self) -> Option<JsString>
pub fn set_time_zone(&self, value: &str)
pub fn get_hour12(&self) -> Option<bool>
pub fn set_hour12(&self, value: bool)
pub fn get_hour_cycle(&self) -> Option<HourCycle>
pub fn set_hour_cycle(&self, value: HourCycle)
pub fn get_date_style(&self) -> Option<DateTimeStyle>
pub fn set_date_style(&self, value: DateTimeStyle)
pub fn get_time_style(&self) -> Option<DateTimeStyle>
pub fn set_time_style(&self, value: DateTimeStyle)
pub fn get_weekday(&self) -> Option<WeekdayFormat>
pub fn set_weekday(&self, value: WeekdayFormat)
pub fn get_era(&self) -> Option<EraFormat>
pub fn set_era(&self, value: EraFormat)
pub fn get_year(&self) -> Option<YearFormat>
pub fn set_year(&self, value: YearFormat)
pub fn get_month(&self) -> Option<MonthFormat>
pub fn set_month(&self, value: MonthFormat)
pub fn get_day(&self) -> Option<DayFormat>
pub fn set_day(&self, value: DayFormat)
pub fn get_hour(&self) -> Option<NumericFormat>
pub fn set_hour(&self, value: NumericFormat)
pub fn get_minute(&self) -> Option<NumericFormat>
pub fn set_minute(&self, value: NumericFormat)
pub fn get_second(&self) -> Option<NumericFormat>
pub fn set_second(&self, value: NumericFormat)
pub fn get_fractional_second_digits(&self) -> Option<u8>
pub fn set_fractional_second_digits(&self, value: u8)
pub fn get_time_zone_name(&self) -> Option<TimeZoneNameFormat>
pub fn set_time_zone_name(&self, value: TimeZoneNameFormat)
pub fn get_day_period(&self) -> Option<DayPeriodFormat>
pub fn set_day_period(&self, value: DayPeriodFormat)
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
👎Deprecated:
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.