ResolvedNumberFormatOptions

Struct ResolvedNumberFormatOptions 

pub struct ResolvedNumberFormatOptions { /* private fields */ }
Resolved options returned by Intl.NumberFormat.prototype.resolvedOptions().

MDN documentation

Implementations

Methods from Deref<Target = NumberFormatOptions>

pub fn get_locale_matcher(&self) -> Option<LocaleMatcher>

pub fn set_locale_matcher(&self, value: LocaleMatcher)

pub fn get_numbering_system(&self) -> Option<JsString>

pub fn set_numbering_system(&self, value: &str)

pub fn get_style(&self) -> Option<NumberFormatStyle>

pub fn set_style(&self, value: NumberFormatStyle)

pub fn get_currency(&self) -> Option<JsString>

pub fn set_currency(&self, value: &str)

pub fn get_currency_display(&self) -> Option<CurrencyDisplay>

pub fn set_currency_display(&self, value: CurrencyDisplay)

pub fn get_currency_sign(&self) -> Option<CurrencySign>

pub fn set_currency_sign(&self, value: CurrencySign)

pub fn get_unit(&self) -> Option<JsString>

pub fn set_unit(&self, value: &str)

pub fn get_unit_display(&self) -> Option<UnitDisplay>

pub fn set_unit_display(&self, value: UnitDisplay)

pub fn get_notation(&self) -> Option<NumberFormatNotation>

pub fn set_notation(&self, value: NumberFormatNotation)

pub fn get_compact_display(&self) -> Option<CompactDisplay>

pub fn set_compact_display(&self, value: CompactDisplay)

pub fn get_sign_display(&self) -> Option<SignDisplay>

pub fn set_sign_display(&self, value: SignDisplay)

pub fn get_minimum_integer_digits(&self) -> Option<u8>

pub fn set_minimum_integer_digits(&self, value: u8)

pub fn get_minimum_fraction_digits(&self) -> Option<u8>

pub fn set_minimum_fraction_digits(&self, value: u8)

pub fn get_maximum_fraction_digits(&self) -> Option<u8>

pub fn set_maximum_fraction_digits(&self, value: u8)

pub fn get_minimum_significant_digits(&self) -> Option<u8>

pub fn set_minimum_significant_digits(&self, value: u8)

pub fn get_maximum_significant_digits(&self) -> Option<u8>

pub fn set_maximum_significant_digits(&self, value: u8)

pub fn get_use_grouping(&self) -> Option<UseGrouping>

pub fn set_use_grouping(&self, value: UseGrouping)

pub fn get_rounding_mode(&self) -> Option<RoundingMode>

pub fn set_rounding_mode(&self, value: RoundingMode)

pub fn get_rounding_priority(&self) -> Option<RoundingPriority>

pub fn set_rounding_priority(&self, value: RoundingPriority)

pub fn get_rounding_increment(&self) -> Option<u32>

pub fn set_rounding_increment(&self, value: u32)

pub fn get_trailing_zero_display(&self) -> Option<TrailingZeroDisplay>

pub fn set_trailing_zero_display(&self, value: TrailingZeroDisplay)

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

pub fn has_own_property(&self, property: &JsValue) -> bool

👎Deprecated:

Use Object::hasOwn instead.

pub fn is_prototype_of(&self, value: &JsValue) -> bool

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

pub fn to_locale_string(&self) -> JsString

pub fn to_string(&self) -> JsString

pub fn to_js_string(&self) -> JsString

pub fn value_of(&self) -> Object

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, other: &JsValue) -> bool

Less than comparison.

pub fn le(&self, other: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, other: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, other: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, other: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_array(&self) -> bool

Check if this value is an Array.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn is_null_or_undefined(&self) -> bool

Check if this value is null or undefined.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.