pub struct ResolvedNumberFormatOptions { /* private fields */ }Expand description
Resolved options returned by Intl.NumberFormat.prototype.resolvedOptions().
Implementations
Sourceimpl ResolvedNumberFormatOptions
impl ResolvedNumberFormatOptions
pub fn get_locale(&self) -> JsString
Methods from Deref<Target = NumberFormatOptions>
pub fn get_locale_matcher(&self) -> Option<LocaleMatcher>
pub fn set_locale_matcher(&self, value: LocaleMatcher)
pub fn get_numbering_system(&self) -> Option<JsString>
pub fn set_numbering_system(&self, value: &str)
pub fn get_style(&self) -> Option<NumberFormatStyle>
pub fn set_style(&self, value: NumberFormatStyle)
pub fn get_currency(&self) -> Option<JsString>
pub fn set_currency(&self, value: &str)
pub fn get_currency_display(&self) -> Option<CurrencyDisplay>
pub fn set_currency_display(&self, value: CurrencyDisplay)
pub fn get_currency_sign(&self) -> Option<CurrencySign>
pub fn set_currency_sign(&self, value: CurrencySign)
pub fn get_unit(&self) -> Option<JsString>
pub fn set_unit(&self, value: &str)
pub fn get_unit_display(&self) -> Option<UnitDisplay>
pub fn set_unit_display(&self, value: UnitDisplay)
pub fn get_notation(&self) -> Option<NumberFormatNotation>
pub fn set_notation(&self, value: NumberFormatNotation)
pub fn get_compact_display(&self) -> Option<CompactDisplay>
pub fn set_compact_display(&self, value: CompactDisplay)
pub fn get_sign_display(&self) -> Option<SignDisplay>
pub fn set_sign_display(&self, value: SignDisplay)
pub fn get_minimum_integer_digits(&self) -> Option<u8>
pub fn set_minimum_integer_digits(&self, value: u8)
pub fn get_minimum_fraction_digits(&self) -> Option<u8>
pub fn set_minimum_fraction_digits(&self, value: u8)
pub fn get_maximum_fraction_digits(&self) -> Option<u8>
pub fn set_maximum_fraction_digits(&self, value: u8)
pub fn get_minimum_significant_digits(&self) -> Option<u8>
pub fn set_minimum_significant_digits(&self, value: u8)
pub fn get_maximum_significant_digits(&self) -> Option<u8>
pub fn set_maximum_significant_digits(&self, value: u8)
pub fn get_use_grouping(&self) -> Option<UseGrouping>
pub fn set_use_grouping(&self, value: UseGrouping)
pub fn get_rounding_mode(&self) -> Option<RoundingMode>
pub fn set_rounding_mode(&self, value: RoundingMode)
pub fn get_rounding_priority(&self) -> Option<RoundingPriority>
pub fn set_rounding_priority(&self, value: RoundingPriority)
pub fn get_rounding_increment(&self) -> Option<u32>
pub fn set_rounding_increment(&self, value: u32)
pub fn get_trailing_zero_display(&self) -> Option<TrailingZeroDisplay>
pub fn set_trailing_zero_display(&self, value: TrailingZeroDisplay)
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
👎Deprecated:
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.