Module futures

Module futures 

Bridging between JavaScript Promises and Rust Futures.

Enables promise.await directly on any Promise. This module is also re-exported by wasm-bindgen-futures for backwards compatibility. Converting between JavaScript Promises to Rust Futures.

This module provides a bridge for working with JavaScript Promise types as a Rust Future, and similarly contains utilities to turn a rust Future into a JavaScript Promise. This can be useful when working with asynchronous or otherwise blocking work in Rust (wasm), and provides the ability to interoperate with JavaScript events and JavaScript I/O primitives.

There are three main interfaces in this module currently:

  1. JsFuture

    A type that is constructed with a Promise and can then be used as a Future<Output = Result<JsValue, JsValue>>. This Rust future will resolve or reject with the value coming out of the Promise.

  2. future_to_promise

    Converts a Rust Future<Output = Result<JsValue, JsValue>> into a JavaScript Promise. The future’s result will translate to either a resolved or rejected Promise in JavaScript.

  3. spawn_local

    Spawns a Future<Output = ()> on the current thread. This is the best way to run a Future in Rust without sending it to JavaScript.

These three items should provide enough of a bridge to interoperate the two systems and make sure that Rust/JavaScript can work together with asynchronous and I/O work.

Structs

JsFuture
A Rust Future backed by a JavaScript Promise.

Functions

future_to_promise
Converts a Rust Future into a JavaScript Promise.
future_to_promise_typed
Converts a Rust Future into a corresponding typed JavaScript Promise<T>.
spawn_local
Runs a Rust Future on the current thread.