Array

Struct Array 

pub struct Array<T = JsValue> { /* private fields */ }

Implementations

Source

impl Array

pub fn new() -> Array

Source

impl<T> Array<T>

pub fn new_typed() -> Array<T>
where Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl Array

Source

impl<T> Array<T>

pub fn new_with_length_typed(len: u32) -> Array<T>
where Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn at(&self, index: i32) -> T
where T: ErasableGenericOwn<JsValue> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn get(&self, index: u32) -> T
where T: ErasableGenericOwn<JsValue> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn get_unchecked(&self, index: u32) -> T
where T: ErasableGenericOwn<JsValue> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn get_checked(&self, index: u32) -> Option<T>
where Option<T>: ErasableGenericOwn<Option<JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn set(&self, index: u32, value: T)
where T: ErasableGenericOwn<JsValue> + EncodeTypeDef + BinaryEncode,

Source

impl<T> Array<T>

pub fn set_ref(&self, index: u32, value: &T)
where T: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,

Source

impl<T> Array<T>

pub fn delete(&self, index: u32)

Source

impl Array

pub fn from(val: &JsValue) -> Array

Source

impl Array

pub fn from_iterable<I>(val: &I) -> Result<Array<I::Item>, JsValue>
where I: ErasableGenericBorrow<JsValue> + EncodeTypeDef + Iterable, for<'__wry_bindgen> &'__wry_bindgen I: BinaryEncode, Result<Array<I::Item>, JsValue>: ErasableGenericOwn<Result<Array<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl Array

pub fn from_iterable_map<I, U>( val: &I, map: &mut dyn FnMut(I::Item, u32) -> Result<U, JsError>, ) -> Result<Array<U>, JsValue>
where I: ErasableGenericBorrow<JsValue> + EncodeTypeDef + Iterable, for<'__wry_bindgen> &'__wry_bindgen I: BinaryEncode, dyn FnMut(I::Item, u32) -> Result<U, JsError>: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32) -> Result<JsValue, JsError>>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(I::Item, u32) -> Result<U, JsError>: EncodeTypeDef + BinaryEncode, Result<Array<U>, JsValue>: ErasableGenericOwn<Result<Array<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl Array

pub fn from_async<I>(val: &I) -> Result<Promise<Array<I::Item>>, JsValue>
where I: ErasableGenericBorrow<JsValue> + EncodeTypeDef + AsyncIterable, for<'__wry_bindgen> &'__wry_bindgen I: BinaryEncode, Result<Promise<Array<I::Item>>, JsValue>: ErasableGenericOwn<Result<Promise<Array<JsValue>>, JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl Array

pub fn from_async_map<'a, I, R: Promising>( val: &I, map: &ScopedClosure<'a, dyn FnMut(I::Item, u32) -> Result<R, JsError>>, ) -> Result<Promise<Array<R::Resolution>>, JsValue>
where I: ErasableGenericBorrow<JsValue> + EncodeTypeDef + AsyncIterable, for<'__wry_bindgen> &'__wry_bindgen I: BinaryEncode, ScopedClosure<'a, dyn FnMut(I::Item, u32) -> Result<R, JsError>>: ErasableGenericBorrow<ScopedClosure<'static, dyn FnMut(JsValue, u32) -> Result<JsValue, JsError>>>, Result<Promise<Array<R::Resolution>>, JsValue>: ErasableGenericOwn<Result<Promise<Array<JsValue>>, JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn copy_within(&self, target: i32, start: i32, end: i32) -> Array<T>
where Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn concat<U: Upcast<T>>(&self, array: &Array<U>) -> Array<T>
where Array<U>: ErasableGenericBorrow<Array<JsValue>> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Array<U>: BinaryEncode, Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn concat_many<U: Upcast<T>>(&self, array: &[Array<U>]) -> Array<T>
where [Array<U>]: ErasableGenericBorrow<[Array<JsValue>]>, Array<U>: EncodeTypeDef + JsGeneric, Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn every(&self, predicate: &mut dyn FnMut(T, u32, Array<T>) -> bool) -> bool
where dyn FnMut(T, u32, Array<T>) -> bool: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32, Array<JsValue>) -> bool>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32, Array<T>) -> bool: EncodeTypeDef + BinaryEncode,

Source

impl<T> Array<T>

pub fn try_every( &self, predicate: &mut dyn FnMut(T, u32) -> Result<bool, JsError>, ) -> Result<bool, JsValue>
where dyn FnMut(T, u32) -> Result<bool, JsError>: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32) -> Result<bool, JsError>>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32) -> Result<bool, JsError>: EncodeTypeDef + BinaryEncode,

Source

impl<T> Array<T>

pub fn fill(&self, value: &T, start: u32, end: u32) -> Array<T>
where T: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode, Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn filter( &self, predicate: &mut dyn FnMut(T, u32, Array<T>) -> bool, ) -> Array<T>
where dyn FnMut(T, u32, Array<T>) -> bool: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32, Array<JsValue>) -> bool>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32, Array<T>) -> bool: EncodeTypeDef + BinaryEncode, Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn try_filter( &self, predicate: &mut dyn FnMut(T, u32) -> Result<bool, JsError>, ) -> Result<Array<T>, JsValue>
where dyn FnMut(T, u32) -> Result<bool, JsError>: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32) -> Result<bool, JsError>>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32) -> Result<bool, JsError>: EncodeTypeDef + BinaryEncode, Result<Array<T>, JsValue>: ErasableGenericOwn<Result<Array<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn find(&self, predicate: &mut dyn FnMut(T, u32, Array<T>) -> bool) -> T
where dyn FnMut(T, u32, Array<T>) -> bool: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32, Array<JsValue>) -> bool>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32, Array<T>) -> bool: EncodeTypeDef + BinaryEncode, T: ErasableGenericOwn<JsValue> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn try_find( &self, predicate: &mut dyn FnMut(T, u32) -> Result<bool, JsError>, ) -> Result<Option<T>, JsValue>
where dyn FnMut(T, u32) -> Result<bool, JsError>: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32) -> Result<bool, JsError>>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32) -> Result<bool, JsError>: EncodeTypeDef + BinaryEncode, Result<Option<T>, JsValue>: ErasableGenericOwn<Result<Option<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn find_index( &self, predicate: &mut dyn FnMut(T, u32, Array<T>) -> bool, ) -> i32
where dyn FnMut(T, u32, Array<T>) -> bool: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32, Array<JsValue>) -> bool>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32, Array<T>) -> bool: EncodeTypeDef + BinaryEncode,

Source

impl<T> Array<T>

pub fn try_find_index( &self, predicate: &mut dyn FnMut(T, u32) -> Result<bool, JsError>, ) -> Result<i32, JsValue>
where dyn FnMut(T, u32) -> Result<bool, JsError>: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32) -> Result<bool, JsError>>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32) -> Result<bool, JsError>: EncodeTypeDef + BinaryEncode,

Source

impl<T> Array<T>

pub fn find_last( &self, predicate: &mut dyn FnMut(T, u32, Array<T>) -> bool, ) -> T
where dyn FnMut(T, u32, Array<T>) -> bool: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32, Array<JsValue>) -> bool>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32, Array<T>) -> bool: EncodeTypeDef + BinaryEncode, T: ErasableGenericOwn<JsValue> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn try_find_last( &self, predicate: &mut dyn FnMut(T, u32) -> Result<bool, JsError>, ) -> Result<Option<T>, JsValue>
where dyn FnMut(T, u32) -> Result<bool, JsError>: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32) -> Result<bool, JsError>>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32) -> Result<bool, JsError>: EncodeTypeDef + BinaryEncode, Result<Option<T>, JsValue>: ErasableGenericOwn<Result<Option<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn find_last_index( &self, predicate: &mut dyn FnMut(T, u32, Array<T>) -> bool, ) -> i32
where dyn FnMut(T, u32, Array<T>) -> bool: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32, Array<JsValue>) -> bool>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32, Array<T>) -> bool: EncodeTypeDef + BinaryEncode,

Source

impl<T> Array<T>

pub fn try_find_last_index( &self, predicate: &mut dyn FnMut(T, u32) -> Result<bool, JsError>, ) -> Result<i32, JsValue>
where dyn FnMut(T, u32) -> Result<bool, JsError>: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32) -> Result<bool, JsError>>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32) -> Result<bool, JsError>: EncodeTypeDef + BinaryEncode,

Source

impl<T> Array<T>

pub fn flat(&self, depth: i32) -> Array<JsValue>

Source

impl<T> Array<T>

pub fn flat_map<U>( &self, callback: &mut dyn FnMut(T, u32, Array<T>) -> Vec<U>, ) -> Array<U>
where dyn FnMut(T, u32, Array<T>) -> Vec<U>: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32, Array<JsValue>) -> Vec<JsValue>>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32, Array<T>) -> Vec<U>: EncodeTypeDef + BinaryEncode, Array<U>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn try_flat_map<U>( &self, callback: &mut dyn FnMut(T, u32) -> Vec<U>, ) -> Result<Array<U>, JsValue>
where dyn FnMut(T, u32) -> Vec<U>: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32) -> Vec<JsValue>>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32) -> Vec<U>: EncodeTypeDef + BinaryEncode, Result<Array<U>, JsValue>: ErasableGenericOwn<Result<Array<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T: JsGeneric> Array<T>

pub fn for_each(&self, callback: &mut dyn FnMut(T, u32, Array<T>))
where dyn FnMut(T, u32, Array<T>): ErasableGenericBorrowMut<dyn FnMut(JsValue, u32, Array<JsValue>)>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32, Array<T>): EncodeTypeDef + BinaryEncode,

Source

impl<T> Array<T>

pub fn try_for_each( &self, callback: &mut dyn FnMut(T, u32) -> Result<(), JsError>, ) -> Result<(), JsValue>
where dyn FnMut(T, u32) -> Result<(), JsError>: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32) -> Result<(), JsError>>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32) -> Result<(), JsError>: EncodeTypeDef + BinaryEncode,

Source

impl<T> Array<T>

pub fn includes(&self, value: &T, from_index: i32) -> bool
where T: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,

Source

impl<T> Array<T>

pub fn index_of(&self, value: &T, from_index: i32) -> i32
where T: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,

Source

impl Array

pub fn is_array(value: &JsValue) -> bool

Source

impl<T> Array<T>

pub fn join(&self, delimiter: &str) -> JsString

Source

impl<T> Array<T>

pub fn last_index_of(&self, value: &T, from_index: i32) -> i32
where T: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,

Source

impl<T> Array<T>

pub fn length(&self) -> u32

Source

impl<T> Array<T>

pub fn set_length(&self, value: u32)

Source

impl<T> Array<T>

pub fn map<U>( &self, predicate: &mut dyn FnMut(T, u32, Array<T>) -> U, ) -> Array<U>
where dyn FnMut(T, u32, Array<T>) -> U: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32, Array<JsValue>) -> JsValue>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32, Array<T>) -> U: EncodeTypeDef + BinaryEncode, Array<U>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn try_map<U>( &self, predicate: &mut dyn FnMut(T, u32) -> Result<U, JsError>, ) -> Result<Array<U>, JsValue>
where dyn FnMut(T, u32) -> Result<U, JsError>: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32) -> Result<JsValue, JsError>>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32) -> Result<U, JsError>: EncodeTypeDef + BinaryEncode, Result<Array<U>, JsValue>: ErasableGenericOwn<Result<Array<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl Array

pub fn of<T>(values: &[T]) -> Array<T>
where [T]: ErasableGenericBorrow<[JsValue]>, T: EncodeTypeDef + JsGeneric, Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl Array

pub fn of1(a: &JsValue) -> Array

Source

impl Array

pub fn of2(a: &JsValue, b: &JsValue) -> Array

Source

impl Array

pub fn of3(a: &JsValue, b: &JsValue, c: &JsValue) -> Array

Source

impl Array

pub fn of4(a: &JsValue, b: &JsValue, c: &JsValue, d: &JsValue) -> Array

Source

impl Array

pub fn of5( a: &JsValue, b: &JsValue, c: &JsValue, d: &JsValue, e: &JsValue, ) -> Array

Source

impl<T> Array<T>

pub fn pop(&self) -> T
where T: ErasableGenericOwn<JsValue> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn pop_checked(&self) -> Option<T>
where Option<T>: ErasableGenericOwn<Option<JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn push(&self, value: &T) -> u32
where T: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,

Source

impl<T> Array<T>

pub fn push_many(&self, values: &[T]) -> u32
where [T]: ErasableGenericBorrow<[JsValue]>, T: EncodeTypeDef + JsGeneric,

Source

impl<T> Array<T>

pub fn reduce( &self, predicate: &mut dyn FnMut(JsValue, T, u32, Array<T>) -> JsValue, initial_value: &JsValue, ) -> JsValue
where dyn FnMut(JsValue, T, u32, Array<T>) -> JsValue: ErasableGenericBorrowMut<dyn FnMut(JsValue, JsValue, u32, Array<JsValue>) -> JsValue>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(JsValue, T, u32, Array<T>) -> JsValue: EncodeTypeDef + BinaryEncode,

Source

impl<T> Array<T>

pub fn try_reduce<A>( &self, predicate: &mut dyn FnMut(A, T, u32) -> Result<A, JsError>, initial_value: &A, ) -> Result<A, JsValue>
where dyn FnMut(A, T, u32) -> Result<A, JsError>: ErasableGenericBorrowMut<dyn FnMut(JsValue, JsValue, u32) -> Result<JsValue, JsError>>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(A, T, u32) -> Result<A, JsError>: EncodeTypeDef + BinaryEncode, A: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen A: BinaryEncode, Result<A, JsValue>: ErasableGenericOwn<Result<JsValue, JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn reduce_right( &self, predicate: &mut dyn FnMut(JsValue, T, u32, Array<T>) -> JsValue, initial_value: &JsValue, ) -> JsValue
where dyn FnMut(JsValue, T, u32, Array<T>) -> JsValue: ErasableGenericBorrowMut<dyn FnMut(JsValue, JsValue, u32, Array<JsValue>) -> JsValue>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(JsValue, T, u32, Array<T>) -> JsValue: EncodeTypeDef + BinaryEncode,

Source

impl<T> Array<T>

pub fn try_reduce_right<A>( &self, predicate: &mut dyn FnMut(JsValue, T, u32) -> Result<A, JsError>, initial_value: &A, ) -> Result<A, JsValue>
where dyn FnMut(JsValue, T, u32) -> Result<A, JsError>: ErasableGenericBorrowMut<dyn FnMut(JsValue, JsValue, u32) -> Result<JsValue, JsError>>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(JsValue, T, u32) -> Result<A, JsError>: EncodeTypeDef + BinaryEncode, A: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen A: BinaryEncode, Result<A, JsValue>: ErasableGenericOwn<Result<JsValue, JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn reverse(&self) -> Array<T>
where Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn shift(&self) -> T
where T: ErasableGenericOwn<JsValue> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn shift_checked(&self) -> Option<T>
where Option<T>: ErasableGenericOwn<Option<JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn slice(&self, start: u32, end: u32) -> Array<T>
where Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn slice_from(&self, start: u32) -> Array<T>
where Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn some(&self, predicate: &mut dyn FnMut(T) -> bool) -> bool
where dyn FnMut(T) -> bool: ErasableGenericBorrowMut<dyn FnMut(JsValue) -> bool>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T) -> bool: EncodeTypeDef + BinaryEncode,

Source

impl<T> Array<T>

pub fn try_some( &self, predicate: &mut dyn FnMut(T) -> Result<bool, JsError>, ) -> Result<bool, JsValue>
where dyn FnMut(T) -> Result<bool, JsError>: ErasableGenericBorrowMut<dyn FnMut(JsValue) -> Result<bool, JsError>>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T) -> Result<bool, JsError>: EncodeTypeDef + BinaryEncode,

Source

impl<T> Array<T>

pub fn sort(&self) -> Array<T>
where Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn sort_by(&self, compare_fn: &mut dyn FnMut(T, T) -> i32) -> Array<T>
where dyn FnMut(T, T) -> i32: ErasableGenericBorrowMut<dyn FnMut(JsValue, JsValue) -> i32>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, T) -> i32: EncodeTypeDef + BinaryEncode, Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn try_sort_by( &self, compare_fn: &mut dyn FnMut(T, T) -> Result<i32, JsError>, ) -> Result<Array<T>, JsValue>
where dyn FnMut(T, T) -> Result<i32, JsError>: ErasableGenericBorrowMut<dyn FnMut(JsValue, JsValue) -> Result<i32, JsError>>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, T) -> Result<i32, JsError>: EncodeTypeDef + BinaryEncode, Result<Array<T>, JsValue>: ErasableGenericOwn<Result<Array<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn splice(&self, start: u32, delete_count: u32, item: &T) -> Array<T>
where T: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode, Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn splice_many( &self, start: u32, delete_count: u32, items: &[T], ) -> Array<T>
where [T]: ErasableGenericBorrow<[JsValue]>, T: EncodeTypeDef + JsGeneric, Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn to_locale_string(&self, locales: &JsValue, options: &JsValue) -> JsString

Source

impl<T> Array<T>

pub fn to_reversed(&self) -> Array<T>
where Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn to_sorted(&self) -> Array<T>
where Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn to_sorted_by(&self, compare_fn: &mut dyn FnMut(T, T) -> i32) -> Array<T>
where dyn FnMut(T, T) -> i32: ErasableGenericBorrowMut<dyn FnMut(JsValue, JsValue) -> i32>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, T) -> i32: EncodeTypeDef + BinaryEncode, Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn try_to_sorted_by( &self, compare_fn: &mut dyn FnMut(T, T) -> Result<i32, JsError>, ) -> Result<Array<T>, JsValue>
where dyn FnMut(T, T) -> Result<i32, JsError>: ErasableGenericBorrowMut<dyn FnMut(JsValue, JsValue) -> Result<i32, JsError>>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, T) -> Result<i32, JsError>: EncodeTypeDef + BinaryEncode, Result<Array<T>, JsValue>: ErasableGenericOwn<Result<Array<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn to_spliced(&self, start: u32, delete_count: u32, items: &[T]) -> Array<T>
where [T]: ErasableGenericBorrow<[JsValue]>, T: EncodeTypeDef + JsGeneric, Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn to_string(&self) -> JsString

Source

impl<T> Array<T>

pub fn to_vec(&self) -> Vec<T>
where Vec<T>: ErasableGenericOwn<Vec<JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn unshift(&self, value: &T) -> u32
where T: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,

Source

impl<T> Array<T>

pub fn unshift_many(&self, values: &[T]) -> u32
where [T]: ErasableGenericBorrow<[JsValue]>, T: EncodeTypeDef + JsGeneric,

Source

impl<T> Array<T>

pub fn with(&self, index: u32, value: &T) -> Array<T>
where T: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode, Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T: JsGeneric> Array<T>

pub fn iter(&self) -> ArrayIter<'_, T>

Returns an iterator over the values of the JS array.

Source

impl<T: JsGeneric> Array<T>

pub fn from_iter_typed<A, I>(iter: I) -> Array<T>
where A: IntoJsGeneric<JsCanon = T>, I: IntoIterator<Item = A>,

Collect an iterator into a typed Array<T>, projecting each item through its canonical JsGeneric via IntoJsGeneric.

This is the typed counterpart to the stable impl FromIterator<A> for Array where A: AsRef<JsValue>, which always produces an erased Array<JsValue>. Use from_iter_typed when you want the element type inferred from the iterator item:

use js_sys::{Array, Number};

let arr = Array::from_iter_typed((0..10).map(Number::from));
// arr: Array<Number>

Reference iteration (Item = &U) is supported transparently via the &U: IntoJsGeneric blanket in wasm-bindgen core.

pub fn extend_typed<A, I>(&mut self, iter: I)
where A: IntoJsGeneric<JsCanon = T>, I: IntoIterator<Item = A>,

Extend a typed Array<T> with an iterator of items convertible to T via IntoJsGeneric. Companion to Array::from_iter_typed.

Source

impl<T> Array<T>

pub fn keys(&self) -> Iterator<T>
where Iterator<T>: ErasableGenericOwn<Iterator<JsValue>> + EncodeTypeDef + BatchableResult,

Source

impl<T> Array<T>

pub fn entries(&self) -> Iterator<T>
where Iterator<T>: ErasableGenericOwn<Iterator<JsValue>> + EncodeTypeDef + BatchableResult,

👎Deprecated:

recommended to use Array::entries_typed instead for typing

Source

impl<T: JsGeneric> Array<T>

Source

impl<T> Array<T>

pub fn values(&self) -> Iterator<T>
where Iterator<T>: ErasableGenericOwn<Iterator<JsValue>> + EncodeTypeDef + BatchableResult,

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

pub fn has_own_property(&self, property: &JsValue) -> bool

👎Deprecated:

Use Object::hasOwn instead.

pub fn is_prototype_of(&self, value: &JsValue) -> bool

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

pub fn to_locale_string(&self) -> JsString

pub fn to_string(&self) -> JsString

pub fn to_js_string(&self) -> JsString

pub fn value_of(&self) -> Object

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, other: &JsValue) -> bool

Less than comparison.

pub fn le(&self, other: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, other: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, other: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, other: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_array(&self) -> bool

Check if this value is an Array.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn is_null_or_undefined(&self) -> bool

Check if this value is null or undefined.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.