pub struct Array<T = JsValue> { /* private fields */ }Implementations
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn set_ref(&self, index: u32, value: &T)where
T: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,
Sourceimpl Array
impl Array
pub fn from_iterable<I>(val: &I) -> Result<Array<I::Item>, JsValue>where
I: ErasableGenericBorrow<JsValue> + EncodeTypeDef + Iterable,
for<'__wry_bindgen> &'__wry_bindgen I: BinaryEncode,
Result<Array<I::Item>, JsValue>: ErasableGenericOwn<Result<Array<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl Array
impl Array
pub fn from_iterable_map<I, U>(
val: &I,
map: &mut dyn FnMut(I::Item, u32) -> Result<U, JsError>,
) -> Result<Array<U>, JsValue>where
I: ErasableGenericBorrow<JsValue> + EncodeTypeDef + Iterable,
for<'__wry_bindgen> &'__wry_bindgen I: BinaryEncode,
dyn FnMut(I::Item, u32) -> Result<U, JsError>: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32) -> Result<JsValue, JsError>>,
for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(I::Item, u32) -> Result<U, JsError>: EncodeTypeDef + BinaryEncode,
Result<Array<U>, JsValue>: ErasableGenericOwn<Result<Array<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl Array
impl Array
pub fn from_async<I>(val: &I) -> Result<Promise<Array<I::Item>>, JsValue>where
I: ErasableGenericBorrow<JsValue> + EncodeTypeDef + AsyncIterable,
for<'__wry_bindgen> &'__wry_bindgen I: BinaryEncode,
Result<Promise<Array<I::Item>>, JsValue>: ErasableGenericOwn<Result<Promise<Array<JsValue>>, JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl Array
impl Array
pub fn from_async_map<'a, I, R: Promising>(
val: &I,
map: &ScopedClosure<'a, dyn FnMut(I::Item, u32) -> Result<R, JsError>>,
) -> Result<Promise<Array<R::Resolution>>, JsValue>where
I: ErasableGenericBorrow<JsValue> + EncodeTypeDef + AsyncIterable,
for<'__wry_bindgen> &'__wry_bindgen I: BinaryEncode,
ScopedClosure<'a, dyn FnMut(I::Item, u32) -> Result<R, JsError>>: ErasableGenericBorrow<ScopedClosure<'static, dyn FnMut(JsValue, u32) -> Result<JsValue, JsError>>>,
Result<Promise<Array<R::Resolution>>, JsValue>: ErasableGenericOwn<Result<Promise<Array<JsValue>>, JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl<T> Array<T>
impl<T> Array<T>
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn concat<U: Upcast<T>>(&self, array: &Array<U>) -> Array<T>where
Array<U>: ErasableGenericBorrow<Array<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Array<U>: BinaryEncode,
Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn concat_many<U: Upcast<T>>(&self, array: &[Array<U>]) -> Array<T>where
[Array<U>]: ErasableGenericBorrow<[Array<JsValue>]>,
Array<U>: EncodeTypeDef + JsGeneric,
Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl<T> Array<T>
impl<T> Array<T>
Sourceimpl<T> Array<T>
impl<T> Array<T>
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn fill(&self, value: &T, start: u32, end: u32) -> Array<T>where
T: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,
Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn filter(
&self,
predicate: &mut dyn FnMut(T, u32, Array<T>) -> bool,
) -> Array<T>where
dyn FnMut(T, u32, Array<T>) -> bool: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32, Array<JsValue>) -> bool>,
for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32, Array<T>) -> bool: EncodeTypeDef + BinaryEncode,
Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn try_filter(
&self,
predicate: &mut dyn FnMut(T, u32) -> Result<bool, JsError>,
) -> Result<Array<T>, JsValue>where
dyn FnMut(T, u32) -> Result<bool, JsError>: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32) -> Result<bool, JsError>>,
for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32) -> Result<bool, JsError>: EncodeTypeDef + BinaryEncode,
Result<Array<T>, JsValue>: ErasableGenericOwn<Result<Array<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn find(&self, predicate: &mut dyn FnMut(T, u32, Array<T>) -> bool) -> Twhere
dyn FnMut(T, u32, Array<T>) -> bool: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32, Array<JsValue>) -> bool>,
for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32, Array<T>) -> bool: EncodeTypeDef + BinaryEncode,
T: ErasableGenericOwn<JsValue> + EncodeTypeDef + BatchableResult,
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn try_find(
&self,
predicate: &mut dyn FnMut(T, u32) -> Result<bool, JsError>,
) -> Result<Option<T>, JsValue>where
dyn FnMut(T, u32) -> Result<bool, JsError>: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32) -> Result<bool, JsError>>,
for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32) -> Result<bool, JsError>: EncodeTypeDef + BinaryEncode,
Result<Option<T>, JsValue>: ErasableGenericOwn<Result<Option<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl<T> Array<T>
impl<T> Array<T>
Sourceimpl<T> Array<T>
impl<T> Array<T>
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn find_last(
&self,
predicate: &mut dyn FnMut(T, u32, Array<T>) -> bool,
) -> Twhere
dyn FnMut(T, u32, Array<T>) -> bool: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32, Array<JsValue>) -> bool>,
for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32, Array<T>) -> bool: EncodeTypeDef + BinaryEncode,
T: ErasableGenericOwn<JsValue> + EncodeTypeDef + BatchableResult,
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn try_find_last(
&self,
predicate: &mut dyn FnMut(T, u32) -> Result<bool, JsError>,
) -> Result<Option<T>, JsValue>where
dyn FnMut(T, u32) -> Result<bool, JsError>: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32) -> Result<bool, JsError>>,
for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32) -> Result<bool, JsError>: EncodeTypeDef + BinaryEncode,
Result<Option<T>, JsValue>: ErasableGenericOwn<Result<Option<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl<T> Array<T>
impl<T> Array<T>
Sourceimpl<T> Array<T>
impl<T> Array<T>
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn flat_map<U>(
&self,
callback: &mut dyn FnMut(T, u32, Array<T>) -> Vec<U>,
) -> Array<U>where
dyn FnMut(T, u32, Array<T>) -> Vec<U>: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32, Array<JsValue>) -> Vec<JsValue>>,
for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32, Array<T>) -> Vec<U>: EncodeTypeDef + BinaryEncode,
Array<U>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn try_flat_map<U>(
&self,
callback: &mut dyn FnMut(T, u32) -> Vec<U>,
) -> Result<Array<U>, JsValue>where
dyn FnMut(T, u32) -> Vec<U>: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32) -> Vec<JsValue>>,
for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32) -> Vec<U>: EncodeTypeDef + BinaryEncode,
Result<Array<U>, JsValue>: ErasableGenericOwn<Result<Array<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl<T> Array<T>
impl<T> Array<T>
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn includes(&self, value: &T, from_index: i32) -> boolwhere
T: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn index_of(&self, value: &T, from_index: i32) -> i32where
T: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn last_index_of(&self, value: &T, from_index: i32) -> i32where
T: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn map<U>(
&self,
predicate: &mut dyn FnMut(T, u32, Array<T>) -> U,
) -> Array<U>where
dyn FnMut(T, u32, Array<T>) -> U: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32, Array<JsValue>) -> JsValue>,
for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32, Array<T>) -> U: EncodeTypeDef + BinaryEncode,
Array<U>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn try_map<U>(
&self,
predicate: &mut dyn FnMut(T, u32) -> Result<U, JsError>,
) -> Result<Array<U>, JsValue>where
dyn FnMut(T, u32) -> Result<U, JsError>: ErasableGenericBorrowMut<dyn FnMut(JsValue, u32) -> Result<JsValue, JsError>>,
for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, u32) -> Result<U, JsError>: EncodeTypeDef + BinaryEncode,
Result<Array<U>, JsValue>: ErasableGenericOwn<Result<Array<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl Array
impl Array
pub fn of<T>(values: &[T]) -> Array<T>where
[T]: ErasableGenericBorrow<[JsValue]>,
T: EncodeTypeDef + JsGeneric,
Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn push(&self, value: &T) -> u32where
T: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,
Sourceimpl<T> Array<T>
impl<T> Array<T>
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn try_reduce<A>(
&self,
predicate: &mut dyn FnMut(A, T, u32) -> Result<A, JsError>,
initial_value: &A,
) -> Result<A, JsValue>where
dyn FnMut(A, T, u32) -> Result<A, JsError>: ErasableGenericBorrowMut<dyn FnMut(JsValue, JsValue, u32) -> Result<JsValue, JsError>>,
for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(A, T, u32) -> Result<A, JsError>: EncodeTypeDef + BinaryEncode,
A: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen A: BinaryEncode,
Result<A, JsValue>: ErasableGenericOwn<Result<JsValue, JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl<T> Array<T>
impl<T> Array<T>
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn try_reduce_right<A>(
&self,
predicate: &mut dyn FnMut(JsValue, T, u32) -> Result<A, JsError>,
initial_value: &A,
) -> Result<A, JsValue>where
dyn FnMut(JsValue, T, u32) -> Result<A, JsError>: ErasableGenericBorrowMut<dyn FnMut(JsValue, JsValue, u32) -> Result<JsValue, JsError>>,
for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(JsValue, T, u32) -> Result<A, JsError>: EncodeTypeDef + BinaryEncode,
A: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen A: BinaryEncode,
Result<A, JsValue>: ErasableGenericOwn<Result<JsValue, JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl<T> Array<T>
impl<T> Array<T>
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn sort_by(&self, compare_fn: &mut dyn FnMut(T, T) -> i32) -> Array<T>where
dyn FnMut(T, T) -> i32: ErasableGenericBorrowMut<dyn FnMut(JsValue, JsValue) -> i32>,
for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, T) -> i32: EncodeTypeDef + BinaryEncode,
Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn try_sort_by(
&self,
compare_fn: &mut dyn FnMut(T, T) -> Result<i32, JsError>,
) -> Result<Array<T>, JsValue>where
dyn FnMut(T, T) -> Result<i32, JsError>: ErasableGenericBorrowMut<dyn FnMut(JsValue, JsValue) -> Result<i32, JsError>>,
for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, T) -> Result<i32, JsError>: EncodeTypeDef + BinaryEncode,
Result<Array<T>, JsValue>: ErasableGenericOwn<Result<Array<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn splice(&self, start: u32, delete_count: u32, item: &T) -> Array<T>where
T: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,
Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn splice_many(
&self,
start: u32,
delete_count: u32,
items: &[T],
) -> Array<T>where
[T]: ErasableGenericBorrow<[JsValue]>,
T: EncodeTypeDef + JsGeneric,
Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn to_locale_string(&self, locales: &JsValue, options: &JsValue) -> JsString
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn to_sorted_by(&self, compare_fn: &mut dyn FnMut(T, T) -> i32) -> Array<T>where
dyn FnMut(T, T) -> i32: ErasableGenericBorrowMut<dyn FnMut(JsValue, JsValue) -> i32>,
for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, T) -> i32: EncodeTypeDef + BinaryEncode,
Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn try_to_sorted_by(
&self,
compare_fn: &mut dyn FnMut(T, T) -> Result<i32, JsError>,
) -> Result<Array<T>, JsValue>where
dyn FnMut(T, T) -> Result<i32, JsError>: ErasableGenericBorrowMut<dyn FnMut(JsValue, JsValue) -> Result<i32, JsError>>,
for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, T) -> Result<i32, JsError>: EncodeTypeDef + BinaryEncode,
Result<Array<T>, JsValue>: ErasableGenericOwn<Result<Array<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn to_spliced(&self, start: u32, delete_count: u32, items: &[T]) -> Array<T>where
[T]: ErasableGenericBorrow<[JsValue]>,
T: EncodeTypeDef + JsGeneric,
Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn unshift(&self, value: &T) -> u32where
T: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,
Sourceimpl<T> Array<T>
impl<T> Array<T>
pub fn with(&self, index: u32, value: &T) -> Array<T>where
T: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,
Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl<T: JsGeneric> Array<T>
impl<T: JsGeneric> Array<T>
Sourcepub fn from_iter_typed<A, I>(iter: I) -> Array<T>where
A: IntoJsGeneric<JsCanon = T>,
I: IntoIterator<Item = A>,
pub fn from_iter_typed<A, I>(iter: I) -> Array<T>where
A: IntoJsGeneric<JsCanon = T>,
I: IntoIterator<Item = A>,
Collect an iterator into a typed Array<T>, projecting each item
through its canonical JsGeneric via IntoJsGeneric.
This is the typed counterpart to the stable
impl FromIterator<A> for Array where A: AsRef<JsValue>, which always
produces an erased Array<JsValue>. Use from_iter_typed when you
want the element type inferred from the iterator item:
use js_sys::{Array, Number};
let arr = Array::from_iter_typed((0..10).map(Number::from));
// arr: Array<Number>Reference iteration (Item = &U) is supported transparently via the
&U: IntoJsGeneric blanket in wasm-bindgen core.
Sourcepub fn extend_typed<A, I>(&mut self, iter: I)where
A: IntoJsGeneric<JsCanon = T>,
I: IntoIterator<Item = A>,
pub fn extend_typed<A, I>(&mut self, iter: I)where
A: IntoJsGeneric<JsCanon = T>,
I: IntoIterator<Item = A>,
Extend a typed Array<T> with an iterator of items convertible to
T via IntoJsGeneric. Companion to Array::from_iter_typed.
Sourceimpl<T> Array<T>
impl<T> Array<T>
Sourceimpl<T: JsGeneric> Array<T>
impl<T: JsGeneric> Array<T>
pub fn entries_typed(&self) -> Iterator<ArrayTuple<(Number, T)>>where
Iterator<ArrayTuple<(Number, T)>>: ErasableGenericOwn<Iterator<ArrayTuple<(Number, JsValue)>>> + EncodeTypeDef + BatchableResult,
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.