BigInt

Struct BigInt 

#[repr(transparent)]
pub struct BigInt { pub obj: Object, }

Fields

obj: Object

Implementations

Source

impl BigInt

pub fn as_int_n(bits: f64, bigint: &BigInt) -> BigInt

Clamps a BigInt value to a signed integer value, and returns that value.

MDN documentation

Source

impl BigInt

pub fn as_uint_n(bits: f64, bigint: &BigInt) -> BigInt

Clamps a BigInt value to an unsigned integer value, and returns that value.

MDN documentation

Source

impl BigInt

pub fn to_locale_string(&self, locales: &JsValue, options: &JsValue) -> JsString

Returns a string with a language-sensitive representation of this BigInt value. Overrides the Object.prototype.toLocaleString() method.

MDN documentation

Source

impl BigInt

pub fn to_string(&self, radix: u8) -> Result<JsString, RangeError>

Returns a string representing this BigInt value in the specified radix (base). Overrides the Object.prototype.toString() method.

MDN documentation

Source

impl BigInt

pub fn value_of(&self, radix: u8) -> BigInt

Returns this BigInt value. Overrides the Object.prototype.valueOf() method.

MDN documentation

Source

impl BigInt

pub fn new(value: &JsValue) -> Result<BigInt, Error>

Creates a new BigInt value.

MDN documentation

pub fn checked_div(&self, rhs: &Self) -> Result<Self, RangeError>

Applies the binary / JS operator on two BigInts, catching and returning any RangeError thrown.

MDN documentation

pub fn pow(&self, rhs: &Self) -> Self

Applies the binary ** JS operator on the two BigInts.

MDN documentation

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

The constructor property returns a reference to the Object constructor function that created the instance object.

MDN documentation

pub fn has_own_property(&self, property: &JsValue) -> bool

👎Deprecated:

Use Object::hasOwn instead.

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

pub fn is_prototype_of(&self, value: &JsValue) -> bool

The isPrototypeOf() method checks if an object exists in another object’s prototype chain.

MDN documentation

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

pub fn to_locale_string(&self) -> JsString

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn to_js_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn value_of(&self) -> Object

The valueOf() method returns the primitive value of the specified object.

MDN documentation

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn id(&self) -> u64

Get the heap ID for this value.

This is used internally for encoding values to send to JS.

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, other: &JsValue) -> bool

Less than comparison.

pub fn le(&self, other: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, other: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, other: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, other: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_array(&self) -> bool

Check if this value is an Array.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn is_null_or_undefined(&self) -> bool

Check if this value is null or undefined.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.