DataView

Struct DataView 

pub struct DataView { /* private fields */ }

Implementations

Source

impl DataView

pub fn new( buffer: &ArrayBuffer, byteOffset: usize, byteLength: usize, ) -> DataView

Source

impl DataView

pub fn new_with_shared_array_buffer( buffer: &SharedArrayBuffer, byteOffset: usize, byteLength: usize, ) -> DataView

Source

impl DataView

pub fn buffer(&self) -> ArrayBuffer

Source

impl DataView

pub fn byte_length(&self) -> usize

Source

impl DataView

pub fn byte_offset(&self) -> usize

Source

impl DataView

pub fn get_int8(&self, byte_offset: usize) -> i8

Source

impl DataView

pub fn get_uint8(&self, byte_offset: usize) -> u8

Source

impl DataView

pub fn get_int16(&self, byte_offset: usize) -> i16

Source

impl DataView

pub fn get_int16_endian(&self, byte_offset: usize, little_endian: bool) -> i16

Source

impl DataView

pub fn get_uint16(&self, byte_offset: usize) -> u16

Source

impl DataView

pub fn get_uint16_endian(&self, byte_offset: usize, little_endian: bool) -> u16

Source

impl DataView

pub fn get_int32(&self, byte_offset: usize) -> i32

Source

impl DataView

pub fn get_int32_endian(&self, byte_offset: usize, little_endian: bool) -> i32

Source

impl DataView

pub fn get_uint32(&self, byte_offset: usize) -> u32

Source

impl DataView

pub fn get_uint32_endian(&self, byte_offset: usize, little_endian: bool) -> u32

Source

impl DataView

pub fn get_float32(&self, byte_offset: usize) -> f32

Source

impl DataView

pub fn get_float32_endian(&self, byte_offset: usize, little_endian: bool) -> f32

Source

impl DataView

pub fn get_float16_as_f32(&self, byte_offset: usize) -> f32

Source

impl DataView

pub fn get_float16_endian_as_f32( &self, byte_offset: usize, little_endian: bool, ) -> f32

Source

impl DataView

pub fn get_float64(&self, byte_offset: usize) -> f64

Source

impl DataView

pub fn get_float64_endian(&self, byte_offset: usize, little_endian: bool) -> f64

Source

impl DataView

pub fn set_int8(&self, byte_offset: usize, value: i8)

Source

impl DataView

pub fn set_uint8(&self, byte_offset: usize, value: u8)

Source

impl DataView

pub fn set_int16(&self, byte_offset: usize, value: i16)

Source

impl DataView

pub fn set_int16_endian( &self, byte_offset: usize, value: i16, little_endian: bool, )

Source

impl DataView

pub fn set_uint16(&self, byte_offset: usize, value: u16)

Source

impl DataView

pub fn set_uint16_endian( &self, byte_offset: usize, value: u16, little_endian: bool, )

Source

impl DataView

pub fn set_int32(&self, byte_offset: usize, value: i32)

Source

impl DataView

pub fn set_int32_endian( &self, byte_offset: usize, value: i32, little_endian: bool, )

Source

impl DataView

pub fn set_uint32(&self, byte_offset: usize, value: u32)

Source

impl DataView

pub fn set_uint32_endian( &self, byte_offset: usize, value: u32, little_endian: bool, )

Source

impl DataView

pub fn set_float32(&self, byte_offset: usize, value: f32)

Source

impl DataView

pub fn set_float32_endian( &self, byte_offset: usize, value: f32, little_endian: bool, )

Source

impl DataView

pub fn set_float16_from_f32(&self, byte_offset: usize, value: f32)

Source

impl DataView

pub fn set_float16_endian_from_f32( &self, byte_offset: usize, value: f32, little_endian: bool, )

Source

impl DataView

pub fn set_float64(&self, byte_offset: usize, value: f64)

Source

impl DataView

pub fn set_float64_endian( &self, byte_offset: usize, value: f64, little_endian: bool, )

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

pub fn has_own_property(&self, property: &JsValue) -> bool

👎Deprecated:

Use Object::hasOwn instead.

pub fn is_prototype_of(&self, value: &JsValue) -> bool

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

pub fn to_locale_string(&self) -> JsString

pub fn to_string(&self) -> JsString

pub fn to_js_string(&self) -> JsString

pub fn value_of(&self) -> Object

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, other: &JsValue) -> bool

Less than comparison.

pub fn le(&self, other: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, other: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, other: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, other: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_array(&self) -> bool

Check if this value is an Array.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn is_null_or_undefined(&self) -> bool

Check if this value is null or undefined.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.