Date

Struct Date 

#[repr(transparent)]
pub struct Date { pub obj: Object, }

Fields

obj: Object

Implementations

Source

impl Date

pub fn get_date(&self) -> u32

The getDate() method returns the day of the month for the specified date according to local time.

MDN documentation

Source

impl Date

pub fn get_day(&self) -> u32

The getDay() method returns the day of the week for the specified date according to local time, where 0 represents Sunday. For the day of the month see getDate().

MDN documentation

Source

impl Date

pub fn get_full_year(&self) -> u32

The getFullYear() method returns the year of the specified date according to local time.

MDN documentation

Source

impl Date

pub fn get_hours(&self) -> u32

The getHours() method returns the hour for the specified date, according to local time.

MDN documentation

Source

impl Date

pub fn get_milliseconds(&self) -> u32

The getMilliseconds() method returns the milliseconds in the specified date according to local time.

MDN documentation

Source

impl Date

pub fn get_minutes(&self) -> u32

The getMinutes() method returns the minutes in the specified date according to local time.

MDN documentation

Source

impl Date

pub fn get_month(&self) -> u32

The getMonth() method returns the month in the specified date according to local time, as a zero-based value (where zero indicates the first month of the year).

MDN documentation

Source

impl Date

pub fn get_seconds(&self) -> u32

The getSeconds() method returns the seconds in the specified date according to local time.

MDN documentation

Source

impl Date

pub fn get_time(&self) -> f64

The getTime() method returns the numeric value corresponding to the time for the specified date according to universal time.

MDN documentation

Source

impl Date

pub fn get_timezone_offset(&self) -> f64

The getTimezoneOffset() method returns the time zone difference, in minutes, from current locale (host system settings) to UTC.

MDN documentation

Source

impl Date

pub fn get_utc_date(&self) -> u32

The getUTCDate() method returns the day (date) of the month in the specified date according to universal time.

MDN documentation

Source

impl Date

pub fn get_utc_day(&self) -> u32

The getUTCDay() method returns the day of the week in the specified date according to universal time, where 0 represents Sunday.

MDN documentation

Source

impl Date

pub fn get_utc_full_year(&self) -> u32

The getUTCFullYear() method returns the year in the specified date according to universal time.

MDN documentation

Source

impl Date

pub fn get_utc_hours(&self) -> u32

The getUTCHours() method returns the hours in the specified date according to universal time.

MDN documentation

Source

impl Date

pub fn get_utc_milliseconds(&self) -> u32

The getUTCMilliseconds() method returns the milliseconds in the specified date according to universal time.

MDN documentation

Source

impl Date

pub fn get_utc_minutes(&self) -> u32

The getUTCMinutes() method returns the minutes in the specified date according to universal time.

MDN documentation

Source

impl Date

pub fn get_utc_month(&self) -> u32

The getUTCMonth() returns the month of the specified date according to universal time, as a zero-based value (where zero indicates the first month of the year).

MDN documentation

Source

impl Date

pub fn get_utc_seconds(&self) -> u32

The getUTCSeconds() method returns the seconds in the specified date according to universal time.

MDN documentation

Source

impl Date

pub fn new(init: &JsValue) -> Date

Creates a JavaScript Date instance that represents a single moment in time. Date objects are based on a time value that is the number of milliseconds since 1 January 1970 UTC.

MDN documentation

Source

impl Date

pub fn new_0() -> Date

Creates a JavaScript Date instance that represents the current moment in time.

MDN documentation

Source

impl Date

pub fn new_with_year_month(year: u32, month: i32) -> Date

Creates a JavaScript Date instance that represents a single moment in time. Date objects are based on a time value that is the number of milliseconds since 1 January 1970 UTC.

MDN documentation

Source

impl Date

pub fn new_with_year_month_day(year: u32, month: i32, day: i32) -> Date

Creates a JavaScript Date instance that represents a single moment in time. Date objects are based on a time value that is the number of milliseconds since 1 January 1970 UTC.

MDN documentation

Source

impl Date

pub fn new_with_year_month_day_hr( year: u32, month: i32, day: i32, hr: i32, ) -> Date

Creates a JavaScript Date instance that represents a single moment in time. Date objects are based on a time value that is the number of milliseconds since 1 January 1970 UTC.

MDN documentation

Source

impl Date

pub fn new_with_year_month_day_hr_min( year: u32, month: i32, day: i32, hr: i32, min: i32, ) -> Date

Creates a JavaScript Date instance that represents a single moment in time. Date objects are based on a time value that is the number of milliseconds since 1 January 1970 UTC.

MDN documentation

Source

impl Date

pub fn new_with_year_month_day_hr_min_sec( year: u32, month: i32, day: i32, hr: i32, min: i32, sec: i32, ) -> Date

Creates a JavaScript Date instance that represents a single moment in time. Date objects are based on a time value that is the number of milliseconds since 1 January 1970 UTC.

MDN documentation

Source

impl Date

pub fn new_with_year_month_day_hr_min_sec_milli( year: u32, month: i32, day: i32, hr: i32, min: i32, sec: i32, milli: i32, ) -> Date

Creates a JavaScript Date instance that represents a single moment in time. Date objects are based on a time value that is the number of milliseconds since 1 January 1970 UTC.

MDN documentation

Source

impl Date

pub fn now() -> f64

The Date.now() method returns the number of milliseconds elapsed since January 1, 1970 00:00:00 UTC.

MDN documentation

Source

impl Date

pub fn parse(date: &str) -> f64

The Date.parse() method parses a string representation of a date, and returns the number of milliseconds since January 1, 1970, 00:00:00 UTC or NaN if the string is unrecognized or, in some cases, contains illegal date values (e.g. 2015-02-31).

MDN documentation

Source

impl Date

pub fn set_date(&self, day: u32) -> f64

The setDate() method sets the day of the Date object relative to the beginning of the currently set month.

MDN documentation

Source

impl Date

pub fn set_full_year(&self, year: u32) -> f64

The setFullYear() method sets the full year for a specified date according to local time. Returns new timestamp.

MDN documentation

Source

impl Date

pub fn set_full_year_with_month(&self, year: u32, month: i32) -> f64

The setFullYear() method sets the full year for a specified date according to local time. Returns new timestamp.

MDN documentation

Source

impl Date

pub fn set_full_year_with_month_date( &self, year: u32, month: i32, date: i32, ) -> f64

The setFullYear() method sets the full year for a specified date according to local time. Returns new timestamp.

MDN documentation

Source

impl Date

pub fn set_hours(&self, hours: u32) -> f64

The setHours() method sets the hours for a specified date according to local time, and returns the number of milliseconds since January 1, 1970 00:00:00 UTC until the time represented by the updated Date instance.

MDN documentation

Source

impl Date

pub fn set_milliseconds(&self, milliseconds: u32) -> f64

The setMilliseconds() method sets the milliseconds for a specified date according to local time.

MDN documentation

Source

impl Date

pub fn set_minutes(&self, minutes: u32) -> f64

The setMinutes() method sets the minutes for a specified date according to local time.

MDN documentation

Source

impl Date

pub fn set_month(&self, month: u32) -> f64

The setMonth() method sets the month for a specified date according to the currently set year.

MDN documentation

Source

impl Date

pub fn set_seconds(&self, seconds: u32) -> f64

The setSeconds() method sets the seconds for a specified date according to local time.

MDN documentation

Source

impl Date

pub fn set_time(&self, time: f64) -> f64

The setTime() method sets the Date object to the time represented by a number of milliseconds since January 1, 1970, 00:00:00 UTC.

MDN documentation

Source

impl Date

pub fn set_utc_date(&self, day: u32) -> f64

The setUTCDate() method sets the day of the month for a specified date according to universal time.

MDN documentation

Source

impl Date

pub fn set_utc_full_year(&self, year: u32) -> f64

The setUTCFullYear() method sets the full year for a specified date according to universal time.

MDN documentation

Source

impl Date

pub fn set_utc_full_year_with_month(&self, year: u32, month: i32) -> f64

The setUTCFullYear() method sets the full year for a specified date according to universal time.

MDN documentation

Source

impl Date

pub fn set_utc_full_year_with_month_date( &self, year: u32, month: i32, date: i32, ) -> f64

The setUTCFullYear() method sets the full year for a specified date according to universal time.

MDN documentation

Source

impl Date

pub fn set_utc_hours(&self, hours: u32) -> f64

The setUTCHours() method sets the hour for a specified date according to universal time, and returns the number of milliseconds since January 1, 1970 00:00:00 UTC until the time represented by the updated Date instance.

MDN documentation

Source

impl Date

pub fn set_utc_milliseconds(&self, milliseconds: u32) -> f64

The setUTCMilliseconds() method sets the milliseconds for a specified date according to universal time.

MDN documentation

Source

impl Date

pub fn set_utc_minutes(&self, minutes: u32) -> f64

The setUTCMinutes() method sets the minutes for a specified date according to universal time.

MDN documentation

Source

impl Date

pub fn set_utc_month(&self, month: u32) -> f64

The setUTCMonth() method sets the month for a specified date according to universal time.

MDN documentation

Source

impl Date

pub fn set_utc_seconds(&self, seconds: u32) -> f64

The setUTCSeconds() method sets the seconds for a specified date according to universal time.

MDN documentation

Source

impl Date

pub fn to_date_string(&self) -> JsString

The toDateString() method returns the date portion of a Date object in human readable form in American English.

MDN documentation

Source

impl Date

pub fn to_iso_string(&self) -> JsString

The toISOString() method returns a string in simplified extended ISO format (ISO 8601), which is always 24 or 27 characters long (YYYY-MM-DDTHH:mm:ss.sssZ or ±YYYYYY-MM-DDTHH:mm:ss.sssZ, respectively). The timezone is always zero UTC offset, as denoted by the suffix “Z”

MDN documentation

Source

impl Date

pub fn to_json(&self) -> JsString

The toJSON() method returns a string representation of the Date object.

MDN documentation

Source

impl Date

pub fn to_locale_date_string(&self, locale: &str, options: &JsValue) -> JsString

The toLocaleDateString() method returns a string with a language sensitive representation of the date portion of this date. The new locales and options arguments let applications specify the language whose formatting conventions should be used and allow to customize the behavior of the function. In older implementations, which ignore the locales and options arguments, the locale used and the form of the string returned are entirely implementation dependent.

MDN documentation

Source

impl Date

pub fn to_locale_string(&self, locale: &str, options: &JsValue) -> JsString

The toLocaleString() method returns a string with a language sensitive representation of this date. The new locales and options arguments let applications specify the language whose formatting conventions should be used and customize the behavior of the function. In older implementations, which ignore the locales and options arguments, the locale used and the form of the string returned are entirely implementation dependent.

MDN documentation

Source

impl Date

pub fn to_locale_time_string(&self, locale: &str) -> JsString

The toLocaleTimeString() method returns a string with a language sensitive representation of the time portion of this date. The new locales and options arguments let applications specify the language whose formatting conventions should be used and customize the behavior of the function. In older implementations, which ignore the locales and options arguments, the locale used and the form of the string returned are entirely implementation dependent.

MDN documentation

Source

impl Date

pub fn to_locale_time_string_with_options( &self, locale: &str, options: &JsValue, ) -> JsString

Source

impl Date

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the specified Date object.

MDN documentation

Source

impl Date

pub fn to_time_string(&self) -> JsString

The toTimeString() method returns the time portion of a Date object in human readable form in American English.

MDN documentation

Source

impl Date

pub fn to_utc_string(&self) -> JsString

The toUTCString() method converts a date to a string, using the UTC time zone.

MDN documentation

Source

impl Date

pub fn utc(year: f64, month: f64) -> f64

The Date.UTC() method accepts the same parameters as the longest form of the constructor, and returns the number of milliseconds in a Date object since January 1, 1970, 00:00:00, universal time.

MDN documentation

Source

impl Date

pub fn value_of(&self) -> f64

The valueOf() method returns the primitive value of a Date object.

MDN documentation

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

The constructor property returns a reference to the Object constructor function that created the instance object.

MDN documentation

pub fn has_own_property(&self, property: &JsValue) -> bool

👎Deprecated:

Use Object::hasOwn instead.

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

pub fn is_prototype_of(&self, value: &JsValue) -> bool

The isPrototypeOf() method checks if an object exists in another object’s prototype chain.

MDN documentation

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

pub fn to_locale_string(&self) -> JsString

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn to_js_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn value_of(&self) -> Object

The valueOf() method returns the primitive value of the specified object.

MDN documentation

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn id(&self) -> u64

Get the heap ID for this value.

This is used internally for encoding values to send to JS.

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, other: &JsValue) -> bool

Less than comparison.

pub fn le(&self, other: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, other: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, other: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, other: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_array(&self) -> bool

Check if this value is an Array.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn is_null_or_undefined(&self) -> bool

Check if this value is null or undefined.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.