#[repr(transparent)]pub struct Float16Array {
pub obj: Object,
}Fields
obj: ObjectImplementations
Sourceimpl Float16Array
impl Float16Array
Sourcepub fn new(constructor_arg: &JsValue) -> Float16Array
pub fn new(constructor_arg: &JsValue) -> Float16Array
The Float16Array() constructor creates a new array.
Sourceimpl Float16Array
impl Float16Array
Sourcepub fn new_with_length(length: u32) -> Float16Array
pub fn new_with_length(length: u32) -> Float16Array
The Float16Array() constructor creates an array with an internal
buffer large enough for length elements.
Sourceimpl Float16Array
impl Float16Array
Sourcepub fn new_with_byte_offset(buffer: &JsValue, byte_offset: u32) -> Float16Array
pub fn new_with_byte_offset(buffer: &JsValue, byte_offset: u32) -> Float16Array
The Float16Array() constructor creates an array with the given
buffer but is a view starting at byte_offset.
Sourceimpl Float16Array
impl Float16Array
Sourcepub fn new_with_byte_offset_and_length(
buffer: &JsValue,
byte_offset: u32,
length: u32,
) -> Float16Array
pub fn new_with_byte_offset_and_length( buffer: &JsValue, byte_offset: u32, length: u32, ) -> Float16Array
The Float16Array() constructor creates an array with the given
buffer but is a view starting at byte_offset for length elements.
Sourceimpl Float16Array
impl Float16Array
Sourcepub fn fill_with_f32(&self, value: f32, start: u32, end: u32) -> Float16Array
pub fn fill_with_f32(&self, value: f32, start: u32, end: u32) -> Float16Array
The fill() method fills all elements from a start index to an end
index with a static f32 value.
Sourceimpl Float16Array
impl Float16Array
Sourcepub fn buffer(&self) -> ArrayBuffer
pub fn buffer(&self) -> ArrayBuffer
The buffer accessor property represents the ArrayBuffer referenced
by a TypedArray at construction time.
Sourceimpl Float16Array
impl Float16Array
Sourcepub fn subarray(&self, begin: u32, end: u32) -> Float16Array
pub fn subarray(&self, begin: u32, end: u32) -> Float16Array
The subarray() method returns a new TypedArray on the same
ArrayBuffer store and with the same element types as this array.
Sourceimpl Float16Array
impl Float16Array
Sourcepub fn slice(&self, begin: u32, end: u32) -> Float16Array
pub fn slice(&self, begin: u32, end: u32) -> Float16Array
The slice() method returns a shallow copy of a portion of a typed
array into a new typed array object.
Sourceimpl Float16Array
impl Float16Array
Sourcepub fn for_each_as_f32(&self, callback: &mut dyn FnMut(f32, u32, Float16Array))
pub fn for_each_as_f32(&self, callback: &mut dyn FnMut(f32, u32, Float16Array))
The forEach() method executes a provided function once per array
element, passing values as f32.
Sourceimpl Float16Array
impl Float16Array
Sourceimpl Float16Array
impl Float16Array
Sourceimpl Float16Array
impl Float16Array
Sourcepub fn byte_length(&self) -> u32
pub fn byte_length(&self) -> u32
The byteLength accessor property represents the length (in bytes) of a typed array.
Sourceimpl Float16Array
impl Float16Array
Sourcepub fn byte_offset(&self) -> u32
pub fn byte_offset(&self) -> u32
The byteOffset accessor property represents the offset (in bytes) of a
typed array from the start of its ArrayBuffer.
Sourceimpl Float16Array
impl Float16Array
Sourceimpl Float16Array
impl Float16Array
Sourceimpl Float16Array
impl Float16Array
Sourcepub fn copy_within(&self, target: i32, start: i32, end: i32) -> Float16Array
pub fn copy_within(&self, target: i32, start: i32, end: i32) -> Float16Array
The copyWithin() method shallow copies part of a typed array to another
location in the same typed array and returns it, without modifying its size.
Sourceimpl Float16Array
impl Float16Array
Sourcepub fn get_index_as_f32(&self, idx: u32) -> f32
pub fn get_index_as_f32(&self, idx: u32) -> f32
Gets the value at idx as an f32, equivalent to JavaScript
arr[idx].
Sourceimpl Float16Array
impl Float16Array
Sourcepub fn set_index_from_f32(&self, idx: u32, value: f32)
pub fn set_index_from_f32(&self, idx: u32, value: f32)
Sets the value at idx from an f32, equivalent to JavaScript
arr[idx] = value.
Sourceimpl Float16Array
impl Float16Array
Sourcepub fn new_from_u16_slice(slice: &[u16]) -> Float16Array
pub fn new_from_u16_slice(slice: &[u16]) -> Float16Array
Creates an array from raw IEEE 754 binary16 bit patterns.
This pairs naturally with the optional half crate:
use half::f16;
use js_sys::Float16Array;
let values = [f16::from_f32(1.0), f16::from_f32(-2.0)];
let bits = values.map(f16::to_bits);
let array = Float16Array::new_from_u16_slice(&bits);Sourcepub fn copy_to_u16_slice(&self, dst: &mut [u16])
pub fn copy_to_u16_slice(&self, dst: &mut [u16])
Copy the raw IEEE 754 binary16 bit patterns from this JS typed array into the destination Rust slice.
Panics
This function will panic if this typed array’s length is different than
the length of the provided dst array.
Values copied into dst can be converted back into half::f16 with
half::f16::from_bits.
Sourcepub fn copy_from_u16_slice(&self, src: &[u16])
pub fn copy_from_u16_slice(&self, src: &[u16])
Copy raw IEEE 754 binary16 bit patterns from the source Rust slice into this JS typed array.
Panics
This function will panic if this typed array’s length is different than
the length of the provided src array.
When using the optional half crate, populate src with
half::f16::to_bits().
Sourcepub fn to_u16_vec(&self) -> Vec<u16>
pub fn to_u16_vec(&self) -> Vec<u16>
Efficiently copies the contents of this JS typed array into a new Vec of raw IEEE 754 binary16 bit patterns.
This makes it easy to round-trip through the optional half crate:
use half::f16;
let bits = array.to_u16_vec();
let values: Vec<f16> = bits.into_iter().map(f16::from_bits).collect();Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
👎Deprecated: Use Object::hasOwn instead.
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Sourcepub fn to_js_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.