[][src]Struct js_sys::Float32Array

#[repr(transparent)]
pub struct Float32Array { /* fields omitted */ }

Methods

impl Float32Array
[src]

pub fn new(constructor_arg: &JsValue) -> Float32Array
[src]

The Float32Array() constructor creates an array of 32-bit floats.

MDN documentation

impl Float32Array
[src]

pub fn new_with_length(length: u32) -> Float32Array
[src]

An Float32Array() which creates an array with an intenral buffer large enough for length elements.

MDN documentation

impl Float32Array
[src]

pub fn new_with_byte_offset(buffer: &JsValue, byte_offset: u32) -> Float32Array
[src]

An Float32Array() which creates an array with the given buffer but is a view starting at byte_offset.

MDN documentation

impl Float32Array
[src]

pub fn new_with_byte_offset_and_length(
    buffer: &JsValue,
    byte_offset: u32,
    length: u32
) -> Float32Array
[src]

An Float32Array() which creates an array with the given buffer but is a view starting at byte_offset for length elements.

MDN documentation

impl Float32Array
[src]

pub fn fill(&self, value: f32, start: u32, end: u32) -> Float32Array
[src]

The fill() method fills all the elements of an array from a start index to an end index with a static value. The end index is not included.

MDN documentation

impl Float32Array
[src]

pub fn buffer(&self) -> ArrayBuffer
[src]

The buffer accessor property represents the ArrayBuffer referenced by a TypedArray at construction time.

impl Float32Array
[src]

pub fn subarray(&self, begin: u32, end: u32) -> Float32Array
[src]

The subarray() method stores multiple values in the typed array, reading input values from a specified array.

impl Float32Array
[src]

pub fn slice(&self, begin: u32, end: u32) -> Uint8ClampedArray
[src]

The slice() method returns a shallow copy of a portion of a typed array into a new typed array object. This method has the same algorithm as Array.prototype.slice().

impl Float32Array
[src]

pub fn for_each(&self, callback: &mut dyn FnMut(f32, u32, Float32Array))
[src]

The forEach() method executes a provided function once per array element. This method has the same algorithm as Array.prototype.forEach(). TypedArray is one of the typed array types here.

impl Float32Array
[src]

pub fn length(&self) -> u32
[src]

The length accessor property represents the length (in elements) of a typed array.

impl Float32Array
[src]

pub fn byte_length(&self) -> u32
[src]

The byteLength accessor property represents the length (in bytes) of a typed array.

impl Float32Array
[src]

pub fn byte_offset(&self) -> u32
[src]

The byteOffset accessor property represents the offset (in bytes) of a typed array from the start of its ArrayBuffer.

Methods from Deref<Target = Object>

pub fn has_own_property(&self, property: &JsValue) -> bool
[src]

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

pub fn is_prototype_of(&self, value: &JsValue) -> bool
[src]

The isPrototypeOf() method checks if an object exists in another object's prototype chain.

MDN documentation

pub fn property_is_enumerable(&self, property: &JsValue) -> bool
[src]

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

pub fn to_locale_string(&self) -> JsString
[src]

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

pub fn to_string(&self) -> JsString
[src]

The toString() method returns a string representing the object.

MDN documentation

pub fn value_of(&self) -> Object
[src]

The valueOf() method returns the primitive value of the specified object.

MDN documentation