Function

Struct Function 

#[repr(transparent)]
pub struct Function<T: JsFunction = fn(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue) -> JsValue> { pub obj: Object, pub generics: PhantomData<fn() -> (T,)>, }
Function represents any generic Function in JS, by treating all arguments as JsValue.

It takes a generic parameter of phantom type fn (Arg1, ..., Argn) -> Ret which is used to type the JS function. For example, Function<fn () -> Number> represents a function taking no arguments that returns a number.

The 8 generic argument parameters (Arg1 through Arg8) are the argument types. Arguments not provided enable strict arity checking at compile time.

A void function is represented by fn (Arg) -> Undefined, and not the () unit type. This is because generics must be based on JS values in the JS generic type system.

The default without any parameters is as a void function - no arguments, Undefined return.

The default generic for Function is fn (JsValue, JsValue, ...) -> JsValue, representing any function, since all functions safely upcast into this function.

Arity Enforcement

It is not possible to use call4 or bind4 on a function that does not have at least 4 arguments — the compiler will reject this because only arguments that are not None support the trait bound for ErasableGeneric.

Examples

// A function taking no args, returning Number
let f: Function<Number> = get_some_fn();

// A function taking (String, Number) and returning Boolean
let f: Function<Boolean, String, Number> = get_some_fn();

## Upcasting

To pass a typed `Function` where a different generic Function is expected, `upcast()` may be used
to convert into any generic `Function` at zero cost with type-safety.

MDN documentation (https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Function)

Fields

obj: Objectgenerics: PhantomData<fn() -> (T,)>

Implementations

Source

impl Function

pub fn new_with_args(args: &str, body: &str) -> Function

The Function constructor creates a new Function object. Calling the constructor directly can create functions dynamically, but suffers from security and similar (but far less significant) performance issues similar to eval. However, unlike eval, the Function constructor allows executing code in the global scope, prompting better programming habits and allowing for more efficient code minification.

MDN documentation

Source

impl Function

pub fn new_with_args_typed<T: JsFunction>(args: &str, body: &str) -> Function<T>
where Function<T>: ErasableGenericOwn<Function<fn() -> JsValue>> + EncodeTypeDef + BatchableResult,

The Function constructor creates a new Function object. Calling the constructor directly can create functions dynamically, but suffers from security and similar (but far less significant) performance issues similar to eval. However, unlike eval, the Function constructor allows executing code in the global scope, prompting better programming habits and allowing for more efficient code minification.

MDN documentation

Source

impl Function

pub fn new_no_args(body: &str) -> Function

The Function constructor creates a new Function object. Calling the constructor directly can create functions dynamically, but suffers from security and similar (but far less significant) performance issues similar to eval. However, unlike eval, the Function constructor allows executing code in the global scope, prompting better programming habits and allowing for more efficient code minification.

MDN documentation

Source

impl Function

pub fn new_no_args_typed<T: JsFunction>(body: &str) -> Function<T>
where Function<T>: ErasableGenericOwn<Function<fn() -> JsValue>> + EncodeTypeDef + BatchableResult,

The Function constructor creates a new Function object.

MDN documentation

Source

impl<T: JsFunction> Function<T>

pub fn apply( &self, context: &JsValue, args: &Array, ) -> Result<<T as JsFunction>::Ret, JsValue>
where Result<<T as JsFunction>::Ret, JsValue>: ErasableGenericOwn<Result<<fn() -> JsValue as JsFunction>::Ret, JsValue>> + EncodeTypeDef + BatchableResult,

The apply() method calls a function with a given this value, and arguments provided as an array (or an array-like object).

MDN documentation

Source

impl<Ret: JsGeneric, F: JsFunction<Ret = Ret>> Function<F>

pub fn call0(&self, context: &JsValue) -> Result<Ret, JsValue>
where Result<Ret, JsValue>: ErasableGenericOwn<Result<JsValue, JsValue>> + EncodeTypeDef + BatchableResult,

The call() method calls a function with a given this value and arguments provided individually.

Note: Use call() to get exact arity and also checked generic type casting.

MDN documentation

Source

impl<Ret: JsGeneric, Arg1: JsGeneric, F: JsFunction<Ret = Ret> + JsFunction1<Arg1 = Arg1>> Function<F>

pub fn call1(&self, context: &JsValue, arg1: &Arg1) -> Result<Ret, JsValue>
where Arg1: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg1: BinaryEncode, Result<Ret, JsValue>: ErasableGenericOwn<Result<JsValue, JsValue>> + EncodeTypeDef + BatchableResult,

The call() method calls a function with a given this value and arguments provided individually.

Note: Use call() to get exact arity and also checked generic type casting.

MDN documentation

Source

impl<Ret: JsGeneric, Arg1: JsGeneric, Arg2: JsGeneric, F: JsFunction<Ret = Ret> + JsFunction1<Arg1 = Arg1> + JsFunction2<Arg2 = Arg2>> Function<F>

pub fn call2( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, ) -> Result<Ret, JsValue>
where Arg1: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg1: BinaryEncode, Arg2: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg2: BinaryEncode, Result<Ret, JsValue>: ErasableGenericOwn<Result<JsValue, JsValue>> + EncodeTypeDef + BatchableResult,

The call() method calls a function with a given this value and arguments provided individually.

Note: Use call() to get exact arity and also checked generic type casting.

MDN documentation

Source

impl<Ret: JsGeneric, Arg1: JsGeneric, Arg2: JsGeneric, Arg3: JsGeneric, F: JsFunction<Ret = Ret> + JsFunction3<Arg1 = Arg1, Arg2 = Arg2, Arg3 = Arg3>> Function<F>

pub fn call3( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, ) -> Result<Ret, JsValue>
where Arg1: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg1: BinaryEncode, Arg2: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg2: BinaryEncode, Arg3: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg3: BinaryEncode, Result<Ret, JsValue>: ErasableGenericOwn<Result<JsValue, JsValue>> + EncodeTypeDef + BatchableResult,

The call() method calls a function with a given this value and arguments provided individually.

Note: Use call() to get exact arity and also checked generic type casting.

MDN documentation

Source

impl<Ret: JsGeneric, Arg1: JsGeneric, Arg2: JsGeneric, Arg3: JsGeneric, Arg4: JsGeneric, F: JsFunction<Ret = Ret> + JsFunction4<Arg1 = Arg1, Arg2 = Arg2, Arg3 = Arg3, Arg4 = Arg4>> Function<F>

pub fn call4( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, arg4: &Arg4, ) -> Result<Ret, JsValue>
where Arg1: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg1: BinaryEncode, Arg2: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg2: BinaryEncode, Arg3: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg3: BinaryEncode, Arg4: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg4: BinaryEncode, Result<Ret, JsValue>: ErasableGenericOwn<Result<JsValue, JsValue>> + EncodeTypeDef + BatchableResult,

The call() method calls a function with a given this value and arguments provided individually.

Note: Use call() to get exact arity and also checked generic type casting.

MDN documentation

Source

impl<Ret: JsGeneric, Arg1: JsGeneric, Arg2: JsGeneric, Arg3: JsGeneric, Arg4: JsGeneric, Arg5: JsGeneric, F: JsFunction<Ret = Ret> + JsFunction5<Arg1 = Arg1, Arg2 = Arg2, Arg3 = Arg3, Arg4 = Arg4, Arg5 = Arg5>> Function<F>

pub fn call5( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, arg4: &Arg4, arg5: &Arg5, ) -> Result<Ret, JsValue>
where Arg1: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg1: BinaryEncode, Arg2: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg2: BinaryEncode, Arg3: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg3: BinaryEncode, Arg4: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg4: BinaryEncode, Arg5: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg5: BinaryEncode, Result<Ret, JsValue>: ErasableGenericOwn<Result<JsValue, JsValue>> + EncodeTypeDef + BatchableResult,

The call() method calls a function with a given this value and arguments provided individually.

Note: Use call() to get exact arity and also checked generic type casting.

MDN documentation

Source

impl<Ret: JsGeneric, Arg1: JsGeneric, Arg2: JsGeneric, Arg3: JsGeneric, Arg4: JsGeneric, Arg5: JsGeneric, Arg6: JsGeneric, F: JsFunction<Ret = Ret> + JsFunction6<Arg1 = Arg1, Arg2 = Arg2, Arg3 = Arg3, Arg4 = Arg4, Arg5 = Arg5, Arg6 = Arg6>> Function<F>

pub fn call6( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, arg4: &Arg4, arg5: &Arg5, arg6: &Arg6, ) -> Result<Ret, JsValue>
where Arg1: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg1: BinaryEncode, Arg2: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg2: BinaryEncode, Arg3: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg3: BinaryEncode, Arg4: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg4: BinaryEncode, Arg5: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg5: BinaryEncode, Arg6: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg6: BinaryEncode, Result<Ret, JsValue>: ErasableGenericOwn<Result<JsValue, JsValue>> + EncodeTypeDef + BatchableResult,

The call() method calls a function with a given this value and arguments provided individually.

Note: Use call() to get exact arity and also checked generic type casting.

MDN documentation

Source

impl<Ret: JsGeneric, Arg1: JsGeneric, Arg2: JsGeneric, Arg3: JsGeneric, Arg4: JsGeneric, Arg5: JsGeneric, Arg6: JsGeneric, Arg7: JsGeneric, F: JsFunction<Ret = Ret> + JsFunction7<Arg1 = Arg1, Arg2 = Arg2, Arg3 = Arg3, Arg4 = Arg4, Arg5 = Arg5, Arg6 = Arg6, Arg7 = Arg7>> Function<F>

pub fn call7( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, arg4: &Arg4, arg5: &Arg5, arg6: &Arg6, arg7: &Arg7, ) -> Result<Ret, JsValue>
where Arg1: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg1: BinaryEncode, Arg2: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg2: BinaryEncode, Arg3: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg3: BinaryEncode, Arg4: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg4: BinaryEncode, Arg5: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg5: BinaryEncode, Arg6: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg6: BinaryEncode, Arg7: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg7: BinaryEncode, Result<Ret, JsValue>: ErasableGenericOwn<Result<JsValue, JsValue>> + EncodeTypeDef + BatchableResult,

The call() method calls a function with a given this value and arguments provided individually.

Note: Use call() to get exact arity and also checked generic type casting.

MDN documentation

Source

impl<Ret: JsGeneric, Arg1: JsGeneric, Arg2: JsGeneric, Arg3: JsGeneric, Arg4: JsGeneric, Arg5: JsGeneric, Arg6: JsGeneric, Arg7: JsGeneric, Arg8: JsGeneric, F: JsFunction8<Ret = Ret, Arg1 = Arg1, Arg2 = Arg2, Arg3 = Arg3, Arg4 = Arg4, Arg5 = Arg5, Arg6 = Arg6, Arg7 = Arg7, Arg8 = Arg8>> Function<F>

pub fn call8( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, arg4: &Arg4, arg5: &Arg5, arg6: &Arg6, arg7: &Arg7, arg8: &Arg8, ) -> Result<Ret, JsValue>
where Arg1: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg1: BinaryEncode, Arg2: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg2: BinaryEncode, Arg3: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg3: BinaryEncode, Arg4: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg4: BinaryEncode, Arg5: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg5: BinaryEncode, Arg6: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg6: BinaryEncode, Arg7: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg7: BinaryEncode, Arg8: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg8: BinaryEncode, Result<Ret, JsValue>: ErasableGenericOwn<Result<JsValue, JsValue>> + EncodeTypeDef + BatchableResult,

The call() method calls a function with a given this value and arguments provided individually.

Note: Use call() to get exact arity and also checked generic type casting.

MDN documentation

Source

impl<Ret: JsGeneric, Arg1: JsGeneric, Arg2: JsGeneric, Arg3: JsGeneric, Arg4: JsGeneric, Arg5: JsGeneric, Arg6: JsGeneric, Arg7: JsGeneric, Arg8: JsGeneric, F: JsFunction8<Ret = Ret, Arg1 = Arg1, Arg2 = Arg2, Arg3 = Arg3, Arg4 = Arg4, Arg5 = Arg5, Arg6 = Arg6, Arg7 = Arg7, Arg8 = Arg8>> Function<F>

pub fn call9( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, arg4: &Arg4, arg5: &Arg5, arg6: &Arg6, arg7: &Arg7, arg8: &Arg8, arg9: &JsValue, ) -> Result<Ret, JsValue>
where Arg1: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg1: BinaryEncode, Arg2: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg2: BinaryEncode, Arg3: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg3: BinaryEncode, Arg4: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg4: BinaryEncode, Arg5: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg5: BinaryEncode, Arg6: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg6: BinaryEncode, Arg7: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg7: BinaryEncode, Arg8: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg8: BinaryEncode, Result<Ret, JsValue>: ErasableGenericOwn<Result<JsValue, JsValue>> + EncodeTypeDef + BatchableResult,

👎Deprecated

The call() method calls a function with a given this value and arguments provided individually.

Note: Use call() to get exact arity and also checked generic type casting.

MDN documentation

Source

impl<T: JsFunction> Function<T>

pub fn bind(&self, context: &JsValue) -> Function<T>
where Function<T>: ErasableGenericOwn<Function<fn() -> JsValue>> + EncodeTypeDef + BatchableResult,

👎Deprecated:

Use Function::bind0 instead.

The bind() method creates a new function that, when called, has its this keyword set to the provided value, with a given sequence of arguments preceding any provided when the new function is called.

MDN documentation

Source

impl<T: JsFunction> Function<T>

pub fn bind0(&self, context: &JsValue) -> Function<T>
where Function<T>: ErasableGenericOwn<Function<fn() -> JsValue>> + EncodeTypeDef + BatchableResult,

The bind() method creates a new function that, when called, has its this keyword set to the provided value, with a given sequence of arguments preceding any provided when the new function is called.

Note: See Function::bindn for arbitrary binding with function arity checking.

MDN documentation

Source

impl<Ret: JsGeneric, Arg1: JsGeneric, F: JsFunction1<Ret = Ret, Arg1 = Arg1>> Function<F>

pub fn bind1( &self, context: &JsValue, arg1: &Arg1, ) -> Function<<F as JsFunction1>::Bind1>
where Arg1: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg1: BinaryEncode, Function<<F as JsFunction1>::Bind1>: ErasableGenericOwn<Function<<fn(JsValue) -> JsValue as JsFunction1>::Bind1>> + EncodeTypeDef + BatchableResult,

The bind() method creates a new function that, when called, has its this keyword set to the provided value, with a given sequence of arguments preceding any provided when the new function is called.

Note: See Function::bindn for arbitrary binding with function arity checking.

MDN documentation

Source

impl<Ret: JsGeneric, Arg1: JsGeneric, Arg2: JsGeneric, F: JsFunction2<Ret = Ret, Arg1 = Arg1, Arg2 = Arg2>> Function<F>

pub fn bind2( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, ) -> Function<<F as JsFunction2>::Bind2>
where Arg1: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg1: BinaryEncode, Arg2: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg2: BinaryEncode, Function<<F as JsFunction2>::Bind2>: ErasableGenericOwn<Function<<fn(JsValue, JsValue) -> JsValue as JsFunction2>::Bind2>> + EncodeTypeDef + BatchableResult,

The bind() method creates a new function that, when called, has its this keyword set to the provided value, with a given sequence of arguments preceding any provided when the new function is called.

Note: See Function::bindn for arbitrary binding with function arity checking.

MDN documentation

Source

impl<Ret: JsGeneric, Arg1: JsGeneric, Arg2: JsGeneric, Arg3: JsGeneric, F: JsFunction3<Ret = Ret, Arg1 = Arg1, Arg2 = Arg2, Arg3 = Arg3>> Function<F>

pub fn bind3( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, ) -> Function<<F as JsFunction3>::Bind3>
where Arg1: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg1: BinaryEncode, Arg2: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg2: BinaryEncode, Arg3: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg3: BinaryEncode, Function<<F as JsFunction3>::Bind3>: ErasableGenericOwn<Function<<fn(JsValue, JsValue, JsValue) -> JsValue as JsFunction3>::Bind3>> + EncodeTypeDef + BatchableResult,

The bind() method creates a new function that, when called, has its this keyword set to the provided value, with a given sequence of arguments preceding any provided when the new function is called.

Note: See Function::bindn for arbitrary binding with function arity checking.

MDN documentation

Source

impl<Ret: JsGeneric, Arg1: JsGeneric, Arg2: JsGeneric, Arg3: JsGeneric, Arg4: JsGeneric, F: JsFunction4<Ret = Ret, Arg1 = Arg1, Arg2 = Arg2, Arg3 = Arg3, Arg4 = Arg4>> Function<F>

pub fn bind4( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, arg4: &Arg4, ) -> Function<<F as JsFunction4>::Bind4>
where Arg1: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg1: BinaryEncode, Arg2: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg2: BinaryEncode, Arg3: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg3: BinaryEncode, Arg4: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg4: BinaryEncode, Function<<F as JsFunction4>::Bind4>: ErasableGenericOwn<Function<<fn(JsValue, JsValue, JsValue, JsValue) -> JsValue as JsFunction4>::Bind4>> + EncodeTypeDef + BatchableResult,

The bind() method creates a new function that, when called, has its this keyword set to the provided value, with a given sequence of arguments preceding any provided when the new function is called.

Note: See Function::bindn for arbitrary binding with function arity checking.

MDN documentation

Source

impl<Ret: JsGeneric, Arg1: JsGeneric, Arg2: JsGeneric, Arg3: JsGeneric, Arg4: JsGeneric, Arg5: JsGeneric, F: JsFunction5<Ret = Ret, Arg1 = Arg1, Arg2 = Arg2, Arg3 = Arg3, Arg4 = Arg4, Arg5 = Arg5>> Function<F>

pub fn bind5( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, arg4: &Arg4, arg5: &Arg5, ) -> Function<<F as JsFunction5>::Bind5>
where Arg1: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg1: BinaryEncode, Arg2: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg2: BinaryEncode, Arg3: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg3: BinaryEncode, Arg4: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg4: BinaryEncode, Arg5: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg5: BinaryEncode, Function<<F as JsFunction5>::Bind5>: ErasableGenericOwn<Function<<fn(JsValue, JsValue, JsValue, JsValue, JsValue) -> JsValue as JsFunction5>::Bind5>> + EncodeTypeDef + BatchableResult,

The bind() method creates a new function that, when called, has its this keyword set to the provided value, with a given sequence of arguments preceding any provided when the new function is called.

Note: See Function::bindn for arbitrary binding with function arity checking.

MDN documentation

Source

impl<Ret: JsGeneric, Arg1: JsGeneric, Arg2: JsGeneric, Arg3: JsGeneric, Arg4: JsGeneric, Arg5: JsGeneric, Arg6: JsGeneric, F: JsFunction6<Ret = Ret, Arg1 = Arg1, Arg2 = Arg2, Arg3 = Arg3, Arg4 = Arg4, Arg5 = Arg5, Arg6 = Arg6>> Function<F>

pub fn bind6( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, arg4: &Arg4, arg5: &Arg5, arg6: &Arg6, ) -> Function<<F as JsFunction6>::Bind6>
where Arg1: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg1: BinaryEncode, Arg2: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg2: BinaryEncode, Arg3: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg3: BinaryEncode, Arg4: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg4: BinaryEncode, Arg5: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg5: BinaryEncode, Arg6: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg6: BinaryEncode, Function<<F as JsFunction6>::Bind6>: ErasableGenericOwn<Function<<fn(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue) -> JsValue as JsFunction6>::Bind6>> + EncodeTypeDef + BatchableResult,

The bind() method creates a new function that, when called, has its this keyword set to the provided value, with a given sequence of arguments preceding any provided when the new function is called.

Note: See Function::bindn for arbitrary binding with function arity checking.

MDN documentation

Source

impl<Ret: JsGeneric, Arg1: JsGeneric, Arg2: JsGeneric, Arg3: JsGeneric, Arg4: JsGeneric, Arg5: JsGeneric, Arg6: JsGeneric, Arg7: JsGeneric, F: JsFunction7<Ret = Ret, Arg1 = Arg1, Arg2 = Arg2, Arg3 = Arg3, Arg4 = Arg4, Arg5 = Arg5, Arg6 = Arg6, Arg7 = Arg7>> Function<F>

pub fn bind7( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, arg4: &Arg4, arg5: &Arg5, arg6: &Arg6, arg7: &Arg7, ) -> Function<<F as JsFunction7>::Bind7>
where Arg1: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg1: BinaryEncode, Arg2: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg2: BinaryEncode, Arg3: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg3: BinaryEncode, Arg4: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg4: BinaryEncode, Arg5: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg5: BinaryEncode, Arg6: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg6: BinaryEncode, Arg7: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg7: BinaryEncode, Function<<F as JsFunction7>::Bind7>: ErasableGenericOwn<Function<<fn(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue) -> JsValue as JsFunction7>::Bind7>> + EncodeTypeDef + BatchableResult,

The bind() method creates a new function that, when called, has its this keyword set to the provided value, with a given sequence of arguments preceding any provided when the new function is called.

Note: See Function::bindn for arbitrary binding with function arity checking.

MDN documentation

Source

impl<Ret: JsGeneric, Arg1: JsGeneric, Arg2: JsGeneric, Arg3: JsGeneric, Arg4: JsGeneric, Arg5: JsGeneric, Arg6: JsGeneric, Arg7: JsGeneric, Arg8: JsGeneric, F: JsFunction8<Ret = Ret, Arg1 = Arg1, Arg2 = Arg2, Arg3 = Arg3, Arg4 = Arg4, Arg5 = Arg5, Arg6 = Arg6, Arg7 = Arg7, Arg8 = Arg8>> Function<F>

pub fn bind8( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, arg4: &Arg4, arg5: &Arg5, arg6: &Arg6, arg7: &Arg7, arg8: &Arg8, ) -> Function<<F as JsFunction8>::Bind8>
where Arg1: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg1: BinaryEncode, Arg2: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg2: BinaryEncode, Arg3: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg3: BinaryEncode, Arg4: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg4: BinaryEncode, Arg5: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg5: BinaryEncode, Arg6: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg6: BinaryEncode, Arg7: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg7: BinaryEncode, Arg8: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg8: BinaryEncode, Function<<F as JsFunction8>::Bind8>: ErasableGenericOwn<Function<<fn(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue) -> JsValue as JsFunction8>::Bind8>> + EncodeTypeDef + BatchableResult,

The bind() method creates a new function that, when called, has its this keyword set to the provided value, with a given sequence of arguments preceding any provided when the new function is called.

Note: See Function::bindn for arbitrary binding with function arity checking.

MDN documentation

Source

impl<Ret: JsGeneric, Arg1: JsGeneric, Arg2: JsGeneric, Arg3: JsGeneric, Arg4: JsGeneric, Arg5: JsGeneric, Arg6: JsGeneric, Arg7: JsGeneric, Arg8: JsGeneric, F: JsFunction8<Ret = Ret, Arg1 = Arg1, Arg2 = Arg2, Arg3 = Arg3, Arg4 = Arg4, Arg5 = Arg5, Arg6 = Arg6, Arg7 = Arg7, Arg8 = Arg8>> Function<F>

pub fn bind9( &self, context: &JsValue, arg1: &Arg1, arg2: &Arg2, arg3: &Arg3, arg4: &Arg4, arg5: &Arg5, arg6: &Arg6, arg7: &Arg7, arg8: &Arg8, arg9: &JsValue, ) -> Function<fn() -> Ret>
where Arg1: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg1: BinaryEncode, Arg2: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg2: BinaryEncode, Arg3: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg3: BinaryEncode, Arg4: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg4: BinaryEncode, Arg5: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg5: BinaryEncode, Arg6: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg6: BinaryEncode, Arg7: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg7: BinaryEncode, Arg8: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Arg8: BinaryEncode, Function<fn() -> Ret>: ErasableGenericOwn<Function<fn() -> JsValue>> + EncodeTypeDef + BatchableResult,

👎Deprecated

The bind() method creates a new function that, when called, has its this keyword set to the provided value, with a given sequence of arguments preceding any provided when the new function is called.

Note: See Function::bindn for arbitrary binding with function arity checking.

MDN documentation

Source

impl<T: JsFunction> Function<T>

pub fn length(&self) -> u32

The length property indicates the number of arguments expected by the function.

MDN documentation

Source

impl<T: JsFunction> Function<T>

pub fn name(&self) -> JsString

A Function object’s read-only name property indicates the function’s name as specified when it was created or “anonymous” for functions created anonymously.

MDN documentation

Source

impl<T: JsFunction> Function<T>

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the source code of the function.

MDN documentation

Source

impl<T: JsFunction> Function<T>

pub fn len(&self) -> usize

Get the static arity of this function type.

pub fn is_empty(&self) -> bool

Returns true if this is a zero-argument function.

Source

impl<T: JsFunction> Function<T>

pub fn call<Args: JsArgs<T>>( &self, context: &JsValue, args: Args, ) -> Result<T::Ret, JsValue>

The call() method calls a function with a given this value and arguments provided as a tuple.

This method accepts a tuple of references matching the function’s argument types.

Example
// 0-arg function
let f: Function<fn() -> Number> = get_fn();
let result = f.call(&JsValue::NULL, ())?;

// 1-arg function (note trailing comma for 1-tuple)
let f: Function<fn(JsString) -> Number> = get_fn();
let result = f.call(&JsValue::NULL, (&name,))?;

// 2-arg function
let f: Function<fn(JsString, Boolean) -> Number> = get_fn();
let result = f.call(&JsValue::NULL, (&name, &flag))?;

MDN documentation

pub fn bindn<Args: JsArgs<T>>( &self, context: &JsValue, args: Args, ) -> Args::BindOutput

The bind() method creates a new function that, when called, has its this keyword set to the provided value, with a given sequence of arguments preceding any provided when the new function is called.

This method accepts a tuple of references to bind.

Example
let f: Function<fn(JsString, Boolean) -> Number> = get_fn();

// Bind no args - same signature
let bound: Function<fn(JsString, Boolean) -> Number> = f.bind(&ctx, ());

// Bind one arg (use 1-tuple of references)
let bound: Function<fn(Boolean) -> Number> = f.bind(&ctx, (&my_string,));

// Bind two args - becomes 0-arg function
let bound: Function<fn() -> Number> = f.bind(&ctx, (&my_string, &my_bool));

MDN documentation

Source

impl<F: JsFunction> Function<F>

pub fn closure_ref<'a, C>(closure: &'a ScopedClosure<'_, C>) -> &'a Self
where F: FunctionIntoClosure, C: WasmClosure + ?Sized, <F as FunctionIntoClosure>::ClosureTypeMut: UpcastFrom<<C as WasmClosure>::AsMut>,

Convert a borrowed ScopedClosure into a typed JavaScript Function reference.

The conversion is a direct type-safe conversion and upcast of a closure into its corresponding typed JavaScript Function, based on covariance and contravariance Upcast trait hierarchy.

For transferring ownership to JS, use Function::from_closure.

pub fn from_closure<C>(closure: ScopedClosure<'static, C>) -> Self
where F: FunctionIntoClosure, C: WasmClosure + ?Sized, <F as FunctionIntoClosure>::ClosureTypeMut: UpcastFrom<<C as WasmClosure>::AsMut>,

Convert a Rust closure into a typed JavaScript Function.

This function releases ownership of the closure to JS, and provides an owned function handle for the same closure.

The conversion is a direct type-safe conversion and upcast of a closure into its corresponding typed JavaScript Function, based on covariance and contravariance Upcast trait hierarchy.

This method is only supported for static closures which do not have borrowed lifetime data, and thus can be released into JS.

For borrowed closures, which cannot cede ownership to JS, instead use Function::closure_ref.

Source

impl Function

pub fn try_from(val: &JsValue) -> Option<&Function>

👎Deprecated:

recommended to use dyn_ref instead which is now equivalent

Returns the Function value of this JS value if it’s an instance of a function.

If this JS value is not an instance of a function then this returns None.

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

The constructor property returns a reference to the Object constructor function that created the instance object.

MDN documentation

pub fn has_own_property(&self, property: &JsValue) -> bool

👎Deprecated:

Use Object::hasOwn instead.

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

pub fn is_prototype_of(&self, value: &JsValue) -> bool

The isPrototypeOf() method checks if an object exists in another object’s prototype chain.

MDN documentation

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

pub fn to_locale_string(&self) -> JsString

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn to_js_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn value_of(&self) -> Object

The valueOf() method returns the primitive value of the specified object.

MDN documentation

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn id(&self) -> u64

Get the heap ID for this value.

This is used internally for encoding values to send to JS.

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, other: &JsValue) -> bool

Less than comparison.

pub fn le(&self, other: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, other: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, other: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, other: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_array(&self) -> bool

Check if this value is an Array.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn is_null_or_undefined(&self) -> bool

Check if this value is null or undefined.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.