JsString

Struct JsString 

pub struct JsString { /* private fields */ }

Implementations

Source

impl JsString

pub fn length(&self) -> u32

Source

impl JsString

pub fn at(&self, index: i32) -> Option<JsString>

Source

impl JsString

pub fn char_at(&self, index: u32) -> JsString

Source

impl JsString

pub fn char_code_at(&self, index: u32) -> f64

Source

impl JsString

pub fn code_point_at(&self, pos: u32) -> JsValue

Source

impl JsString

pub fn try_code_point_at(&self, pos: u32) -> Option<u16>

Source

impl JsString

pub fn concat(&self, string_2: &JsValue) -> JsString

Source

impl JsString

pub fn concat_many(&self, strings: &[JsString]) -> JsString

Source

impl JsString

pub fn ends_with(&self, search_string: &str, length: i32) -> bool

Source

impl JsString

pub fn from_char_code(char_codes: &[u16]) -> JsString

Source

impl JsString

Source

impl JsString

Source

impl JsString

pub fn from_char_code3(a: u32, b: u32, c: u32) -> JsString

Source

impl JsString

pub fn from_char_code4(a: u32, b: u32, c: u32, d: u32) -> JsString

Source

impl JsString

pub fn from_char_code5(a: u32, b: u32, c: u32, d: u32, e: u32) -> JsString

Source

impl JsString

pub fn from_code_point(code_points: &[u32]) -> Result<JsString, JsValue>

Source

impl JsString

Source

impl JsString

Source

impl JsString

Source

impl JsString

pub fn from_code_point4( a: u32, b: u32, c: u32, d: u32, ) -> Result<JsString, JsValue>

Source

impl JsString

pub fn from_code_point5( a: u32, b: u32, c: u32, d: u32, e: u32, ) -> Result<JsString, JsValue>

Source

impl JsString

pub fn includes(&self, search_string: &str, position: i32) -> bool

Source

impl JsString

pub fn index_of(&self, search_value: &str, from_index: i32) -> i32

Source

impl JsString

pub fn last_index_of(&self, search_value: &str, from_index: i32) -> i32

Source

impl JsString

pub fn locale_compare( &self, compare_string: &str, locales: &Array, options: &Object, ) -> i32

Source

impl JsString

pub fn match_(&self, pattern: &RegExp) -> Option<Object>

Source

impl JsString

pub fn match_all(&self, pattern: &RegExp) -> Iterator

Source

impl JsString

pub fn normalize(&self, form: &str) -> JsString

Source

impl JsString

pub fn pad_end(&self, target_length: u32, pad_string: &str) -> JsString

Source

impl JsString

pub fn pad_start(&self, target_length: u32, pad_string: &str) -> JsString

Source

impl JsString

pub fn repeat(&self, count: i32) -> JsString

Source

impl JsString

pub fn replace(&self, pattern: &str, replacement: &str) -> JsString

Source

impl JsString

pub fn replace_with_function( &self, pattern: &str, replacement: &Function, ) -> JsString

Source

impl JsString

pub fn replace_by_pattern( &self, pattern: &RegExp, replacement: &str, ) -> JsString

Source

impl JsString

pub fn replace_by_pattern_with_function( &self, pattern: &RegExp, replacement: &Function, ) -> JsString

Source

impl JsString

pub fn replace_all(&self, pattern: &str, replacement: &str) -> JsString

Source

impl JsString

pub fn replace_all_with_function( &self, pattern: &str, replacement: &Function, ) -> JsString

Source

impl JsString

pub fn replace_all_by_pattern( &self, pattern: &RegExp, replacement: &str, ) -> JsString

Source

impl JsString

pub fn replace_all_by_pattern_with_function( &self, pattern: &RegExp, replacement: &Function, ) -> JsString

Source

impl JsString

pub fn search(&self, pattern: &RegExp) -> i32

Source

impl JsString

pub fn slice(&self, start: u32, end: u32) -> JsString

Source

impl JsString

pub fn split(&self, separator: &str) -> Array

Source

impl JsString

pub fn split_limit(&self, separator: &str, limit: u32) -> Array

Source

impl JsString

pub fn split_by_pattern(&self, pattern: &RegExp) -> Array

Source

impl JsString

pub fn split_by_pattern_limit(&self, pattern: &RegExp, limit: u32) -> Array

Source

impl JsString

pub fn starts_with(&self, search_string: &str, position: u32) -> bool

Source

impl JsString

pub fn substring(&self, index_start: u32, index_end: u32) -> JsString

Source

impl JsString

pub fn substr(&self, start: i32, length: i32) -> JsString

Source

impl JsString

pub fn to_locale_lower_case(&self, locale: Option<&str>) -> JsString

Source

impl JsString

pub fn to_locale_upper_case(&self, locale: Option<&str>) -> JsString

Source

impl JsString

pub fn to_lower_case(&self) -> JsString

Source

impl JsString

pub fn to_string(&self) -> JsString

Source

impl JsString

pub fn to_upper_case(&self) -> JsString

Source

impl JsString

pub fn trim(&self) -> JsString

Source

impl JsString

pub fn trim_end(&self) -> JsString

Source

impl JsString

pub fn trim_right(&self) -> JsString

Source

impl JsString

pub fn trim_start(&self) -> JsString

Source

impl JsString

pub fn trim_left(&self) -> JsString

Source

impl JsString

pub fn value_of(&self) -> JsString

Source

impl JsString

pub fn raw( call_site: &Object, substitutions: &Array, ) -> Result<JsString, JsValue>

Source

impl JsString

pub fn raw_0(call_site: &Object) -> Result<JsString, JsValue>

Source

impl JsString

pub fn raw_1( call_site: &Object, substitutions_1: &str, ) -> Result<JsString, JsValue>

Source

impl JsString

pub fn raw_2( call_site: &Object, substitutions1: &str, substitutions2: &str, ) -> Result<JsString, JsValue>

Source

impl JsString

pub fn raw_3( call_site: &Object, substitutions1: &str, substitutions2: &str, substitutions3: &str, ) -> Result<JsString, JsValue>

Source

impl JsString

pub fn raw_4( call_site: &Object, substitutions1: &str, substitutions2: &str, substitutions3: &str, substitutions4: &str, ) -> Result<JsString, JsValue>

Source

impl JsString

pub fn raw_5( call_site: &Object, substitutions1: &str, substitutions2: &str, substitutions3: &str, substitutions4: &str, substitutions5: &str, ) -> Result<JsString, JsValue>

Source

impl JsString

pub fn raw_6( call_site: &Object, substitutions1: &str, substitutions2: &str, substitutions3: &str, substitutions4: &str, substitutions5: &str, substitutions6: &str, ) -> Result<JsString, JsValue>

Source

impl JsString

pub fn raw_7( call_site: &Object, substitutions1: &str, substitutions2: &str, substitutions3: &str, substitutions4: &str, substitutions5: &str, substitutions6: &str, substitutions7: &str, ) -> Result<JsString, JsValue>

Source

impl JsString

pub fn try_from(val: &JsValue) -> Option<&JsString>

👎Deprecated:

recommended to use dyn_ref instead which is now equivalent

Returns the JsString value of this JS value if it’s an instance of a string.

If this JS value is not an instance of a string then this returns None.

pub fn is_valid_utf16(&self) -> bool

Returns whether this string is a valid UTF-16 string.

This is useful for learning whether String::from(..) will return a lossless representation of the JS string. If this string contains unpaired surrogates then String::from will succeed but it will be a lossy representation of the JS string because unpaired surrogates will become replacement characters.

If this function returns false then to get a lossless representation of the string you’ll need to manually use the iter method (or the char_code_at accessor) to view the raw character codes.

For more information, see the documentation on JS strings vs Rust strings

pub fn iter( &self, ) -> impl ExactSizeIterator<Item = u16> + DoubleEndedIterator<Item = u16> + '_

Returns an iterator over the u16 character codes that make up this JS string.

This method will call char_code_at for each code in this JS string, returning an iterator of the codes in sequence.

pub fn as_char(&self) -> Option<char>

If this string consists of a single Unicode code point, then this method converts it into a Rust char without doing any allocations.

If this JS value is not a valid UTF-8 or consists of more than a single codepoint, then this returns None.

Note that a single Unicode code point might be represented as more than one code unit on the JavaScript side. For example, a JavaScript string "\uD801\uDC37" is actually a single Unicode code point U+10437 which corresponds to a character ‘𐐷’.

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

pub fn has_own_property(&self, property: &JsValue) -> bool

👎Deprecated:

Use Object::hasOwn instead.

pub fn is_prototype_of(&self, value: &JsValue) -> bool

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

pub fn to_locale_string(&self) -> JsString

pub fn to_string(&self) -> JsString

pub fn to_js_string(&self) -> JsString

pub fn value_of(&self) -> Object

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, other: &JsValue) -> bool

Less than comparison.

pub fn le(&self, other: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, other: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, other: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, other: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_array(&self) -> bool

Check if this value is an Array.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn is_null_or_undefined(&self) -> bool

Check if this value is null or undefined.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.