pub struct JsString { /* private fields */ }Implementations
Sourceimpl JsString
impl JsString
pub fn replace_with_function( &self, pattern: &str, replacement: &Function, ) -> JsString
Sourceimpl JsString
impl JsString
pub fn replace_by_pattern( &self, pattern: &RegExp, replacement: &str, ) -> JsString
Sourceimpl JsString
impl JsString
pub fn replace_by_pattern_with_function( &self, pattern: &RegExp, replacement: &Function, ) -> JsString
Sourceimpl JsString
impl JsString
pub fn replace_all_with_function( &self, pattern: &str, replacement: &Function, ) -> JsString
Sourceimpl JsString
impl JsString
pub fn replace_all_by_pattern( &self, pattern: &RegExp, replacement: &str, ) -> JsString
Sourceimpl JsString
impl JsString
pub fn replace_all_by_pattern_with_function( &self, pattern: &RegExp, replacement: &Function, ) -> JsString
Sourceimpl JsString
impl JsString
pub fn split_by_pattern_limit(&self, pattern: &RegExp, limit: u32) -> Array
Sourceimpl JsString
impl JsString
Sourcepub fn try_from(val: &JsValue) -> Option<&JsString>
👎Deprecated: recommended to use dyn_ref instead which is now equivalent
pub fn try_from(val: &JsValue) -> Option<&JsString>
recommended to use dyn_ref instead which is now equivalent
Returns the JsString value of this JS value if it’s an instance of a
string.
If this JS value is not an instance of a string then this returns
None.
Sourcepub fn is_valid_utf16(&self) -> bool
pub fn is_valid_utf16(&self) -> bool
Returns whether this string is a valid UTF-16 string.
This is useful for learning whether String::from(..) will return a
lossless representation of the JS string. If this string contains
unpaired surrogates then String::from will succeed but it will be a
lossy representation of the JS string because unpaired surrogates will
become replacement characters.
If this function returns false then to get a lossless representation
of the string you’ll need to manually use the iter method (or the
char_code_at accessor) to view the raw character codes.
For more information, see the documentation on JS strings vs Rust strings
Sourcepub fn iter(
&self,
) -> impl ExactSizeIterator<Item = u16> + DoubleEndedIterator<Item = u16> + '_
pub fn iter( &self, ) -> impl ExactSizeIterator<Item = u16> + DoubleEndedIterator<Item = u16> + '_
Returns an iterator over the u16 character codes that make up this JS
string.
This method will call char_code_at for each code in this JS string,
returning an iterator of the codes in sequence.
Sourcepub fn as_char(&self) -> Option<char>
pub fn as_char(&self) -> Option<char>
If this string consists of a single Unicode code point, then this method
converts it into a Rust char without doing any allocations.
If this JS value is not a valid UTF-8 or consists of more than a single
codepoint, then this returns None.
Note that a single Unicode code point might be represented as more than
one code unit on the JavaScript side. For example, a JavaScript string
"\uD801\uDC37" is actually a single Unicode code point U+10437 which
corresponds to a character ‘𐐷’.
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.