pub struct Number { /* private fields */ }Implementations
Sourceimpl Number
impl Number
Sourcepub const MAX_SAFE_INTEGER: f64 = 9007199254740991.0
pub const MAX_SAFE_INTEGER: f64 = 9007199254740991.0
The maximum safe integer in JavaScript (2^53 - 1).
Sourcepub const MIN_SAFE_INTEGER: f64 = -9007199254740991.0
pub const MIN_SAFE_INTEGER: f64 = -9007199254740991.0
The minimum safe integer in JavaScript (-(2^53 - 1)).
Sourcepub const MIN_VALUE: f64 = 5E-324
pub const MIN_VALUE: f64 = 5E-324
The smallest positive representable number—that is, the positive number closest to zero (without actually being zero).
Sourcepub const NEGATIVE_INFINITY: f64 = f64::NEG_INFINITY
pub const NEGATIVE_INFINITY: f64 = f64::NEG_INFINITY
Special value representing negative infinity. Returned on overflow.
Sourcepub const POSITIVE_INFINITY: f64 = f64::INFINITY
pub const POSITIVE_INFINITY: f64 = f64::INFINITY
Special value representing infinity. Returned on overflow.
Sourcepub fn unsigned_shr(&self, rhs: &Self) -> Self
pub fn unsigned_shr(&self, rhs: &Self) -> Self
Applies the binary >>> JS operator on the two Numbers.
Methods from Deref<Target = Object>
pub fn constructor(&self) -> Function
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
pub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn to_locale_string(&self) -> JsString
pub fn to_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
pub fn value_of(&self) -> Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.