pub struct Object<T = JsValue> { /* private fields */ }Implementations
Sourceimpl Object
impl Object
pub fn assign<T>(target: &Object<T>, source: &Object<T>) -> Object<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Object<JsValue>> + BatchableResult,
for<'__wry_bindgen, '__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Sourceimpl Object
impl Object
pub fn try_assign<T>(
target: &Object<T>,
source: &Object<T>,
) -> Result<Object<T>, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen, '__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Result<Object<T>, JsValue>: ErasableGenericOwn<Result<Object<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl Object
impl Object
pub fn assign2<T>(
target: &Object<T>,
source1: &Object<T>,
source2: &Object<T>,
) -> Object<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Object<JsValue>> + BatchableResult,
for<'__wry_bindgen, '__wry_bindgen, '__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
👎Deprecated:
use assign_many for arbitrary assign arguments instead
Sourceimpl Object
impl Object
pub fn assign3<T>(
target: &Object<T>,
source1: &Object<T>,
source2: &Object<T>,
source3: &Object<T>,
) -> Object<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Object<JsValue>> + BatchableResult,
for<'__wry_bindgen, '__wry_bindgen, '__wry_bindgen, '__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
👎Deprecated:
use assign_many for arbitrary assign arguments instead
Sourceimpl Object
impl Object
pub fn assign_many<T>(
target: &Object<T>,
sources: &[Object<T>],
) -> Result<Object<T>, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + JsGeneric,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
[Object<T>]: ErasableGenericBorrow<[Object<JsValue>]>,
Result<Object<T>, JsValue>: ErasableGenericOwn<Result<Object<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl Object
impl Object
pub fn create<T>(prototype: &Object<T>) -> Object<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Object<JsValue>> + BatchableResult,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Sourceimpl Object
impl Object
pub fn define_property<T>(
obj: &Object<T>,
prop: &JsValue,
descriptor: &Object,
) -> Object<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Object<JsValue>> + BatchableResult,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Sourceimpl Object
impl Object
pub fn define_property_str<T>(
obj: &Object<T>,
prop: &JsString,
descriptor: &PropertyDescriptor<T>,
) -> Result<Object<T>, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
PropertyDescriptor<T>: ErasableGenericBorrow<PropertyDescriptor<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen PropertyDescriptor<T>: BinaryEncode,
Result<Object<T>, JsValue>: ErasableGenericOwn<Result<Object<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl Object
impl Object
pub fn define_property_symbol<T>(
obj: &Object<T>,
prop: &Symbol,
descriptor: &PropertyDescriptor<JsValue>,
) -> Result<Object<T>, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Result<Object<T>, JsValue>: ErasableGenericOwn<Result<Object<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl Object
impl Object
pub fn define_properties<T>(obj: &Object<T>, props: &Object) -> Object<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Object<JsValue>> + BatchableResult,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Sourceimpl Object
impl Object
pub fn entries_typed<T: JsGeneric>(
object: &Object<T>,
) -> Result<Array<ArrayTuple<(JsString, T)>>, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Result<Array<ArrayTuple<(JsString, T)>>, JsValue>: ErasableGenericOwn<Result<Array<ArrayTuple<(JsString, JsValue)>>, JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl Object
impl Object
pub fn freeze<T>(value: &Object<T>) -> Object<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Object<JsValue>> + BatchableResult,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Sourceimpl Object
impl Object
pub fn from_entries_typed<T: JsGeneric, I>(
entries: &I,
) -> Result<Object<T>, JsValue>where
I: ErasableGenericBorrow<JsValue> + EncodeTypeDef + Iterable<Item = ArrayTuple<(JsString, T)>>,
for<'__wry_bindgen> &'__wry_bindgen I: BinaryEncode,
Result<Object<T>, JsValue>: ErasableGenericOwn<Result<Object<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl Object
impl Object
pub fn get_own_property_descriptor<T>(
obj: &Object<T>,
prop: &JsValue,
) -> JsValuewhere
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Sourceimpl Object
impl Object
pub fn get_own_property_descriptor_str<T>(
obj: &Object<T>,
prop: &JsString,
) -> Result<PropertyDescriptor<T>, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Result<PropertyDescriptor<T>, JsValue>: ErasableGenericOwn<Result<PropertyDescriptor<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl Object
impl Object
pub fn get_own_property_descriptor_symbol<T>(
obj: &Object<T>,
prop: &Symbol,
) -> Result<PropertyDescriptor<JsValue>, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Sourceimpl Object
impl Object
pub fn get_own_property_descriptors<T>(obj: &Object<T>) -> JsValuewhere
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Sourceimpl Object
impl Object
pub fn get_own_property_names<T>(obj: &Object<T>) -> Arraywhere
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Sourceimpl Object
impl Object
pub fn get_own_property_symbols<T>(obj: &Object<T>) -> Arraywhere
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Sourceimpl<T> Object<T>
impl<T> Object<T>
pub fn has_own_property(&self, property: &JsValue) -> bool
👎Deprecated:
Use Object::hasOwn instead.
Sourceimpl Object
impl Object
pub fn has_own_str<T>(
instance: &Object<T>,
property: &JsString,
) -> Result<bool, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Sourceimpl Object
impl Object
pub fn has_own_symbol<T>(
instance: &Object<T>,
property: &Symbol,
) -> Result<bool, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Sourceimpl Object
impl Object
pub fn is_extensible<T>(object: &Object<T>) -> boolwhere
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Sourceimpl Object
impl Object
pub fn is_frozen<T>(object: &Object<T>) -> boolwhere
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Sourceimpl Object
impl Object
pub fn is_sealed<T>(object: &Object<T>) -> boolwhere
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Sourceimpl Object
impl Object
pub fn keys<T>(object: &Object<T>) -> Arraywhere
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Sourceimpl Object
impl Object
pub fn prevent_extensions<T>(object: &Object<T>)where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Sourceimpl Object
impl Object
pub fn seal<T>(value: &Object<T>) -> Object<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Object<JsValue>> + BatchableResult,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Sourceimpl Object
impl Object
pub fn set_prototype_of<T>(object: &Object<T>, prototype: &Object) -> Object<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Object<JsValue>> + BatchableResult,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Sourceimpl Object
impl Object
pub fn try_set_prototype_of<T>(
object: &Object<T>,
prototype: &Object,
) -> Result<Object<T>, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Result<Object<T>, JsValue>: ErasableGenericOwn<Result<Object<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl Object
impl Object
pub fn values<T>(object: &Object<T>) -> Array<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,
Sourceimpl Object
impl Object
pub fn try_values<T>(object: &Object<T>) -> Result<Array<T>, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Result<Array<T>, JsValue>: ErasableGenericOwn<Result<Array<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.