#[repr(transparent)]pub struct Object<T = JsValue> {
pub obj: JsValue,
pub generics: PhantomData<fn() -> (T,)>,
}Fields
obj: JsValuegenerics: PhantomData<fn() -> (T,)>Implementations
Sourceimpl<T> Object<T>
impl<T> Object<T>
Sourcepub fn assign(target: &Object<T>, source: &Object<T>) -> Object<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Object<JsValue>> + BatchableResult,
for<'__wry_bindgen, '__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
pub fn assign(target: &Object<T>, source: &Object<T>) -> Object<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Object<JsValue>> + BatchableResult,
for<'__wry_bindgen, '__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
The Object.assign() method is used to copy the values of all enumerable
own properties from one or more source objects to a target object. It
will return the target object.
Note: Consider using Object::try_assign to support error handling.
Sourceimpl<T> Object<T>
impl<T> Object<T>
Sourcepub fn try_assign(
target: &Object<T>,
source: &Object<T>,
) -> Result<Object<T>, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen, '__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Result<Object<T>, JsValue>: ErasableGenericOwn<Result<Object<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
pub fn try_assign(
target: &Object<T>,
source: &Object<T>,
) -> Result<Object<T>, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen, '__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Result<Object<T>, JsValue>: ErasableGenericOwn<Result<Object<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
The Object.assign() method is used to copy the values of all enumerable
own properties from one or more source objects to a target object. It
will return the target object.
Note: Consider using Object::try_assign to support error handling.
Sourceimpl<T> Object<T>
impl<T> Object<T>
Sourcepub fn assign2(
target: &Object<T>,
source1: &Object<T>,
source2: &Object<T>,
) -> Object<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Object<JsValue>> + BatchableResult,
for<'__wry_bindgen, '__wry_bindgen, '__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
👎Deprecated: use assign_many for arbitrary assign arguments instead
pub fn assign2(
target: &Object<T>,
source1: &Object<T>,
source2: &Object<T>,
) -> Object<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Object<JsValue>> + BatchableResult,
for<'__wry_bindgen, '__wry_bindgen, '__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
use assign_many for arbitrary assign arguments instead
The Object.assign() method is used to copy the values of all enumerable
own properties from one or more source objects to a target object. It
will return the target object.
Sourceimpl<T> Object<T>
impl<T> Object<T>
Sourcepub fn assign3(
target: &Object<T>,
source1: &Object<T>,
source2: &Object<T>,
source3: &Object<T>,
) -> Object<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Object<JsValue>> + BatchableResult,
for<'__wry_bindgen, '__wry_bindgen, '__wry_bindgen, '__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
👎Deprecated: use assign_many for arbitrary assign arguments instead
pub fn assign3(
target: &Object<T>,
source1: &Object<T>,
source2: &Object<T>,
source3: &Object<T>,
) -> Object<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Object<JsValue>> + BatchableResult,
for<'__wry_bindgen, '__wry_bindgen, '__wry_bindgen, '__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
use assign_many for arbitrary assign arguments instead
The Object.assign() method is used to copy the values of all enumerable
own properties from one or more source objects to a target object. It
will return the target object.
Sourceimpl<T> Object<T>
impl<T> Object<T>
Sourcepub fn assign_many(
target: &Object<T>,
sources: &[Object<T>],
) -> Result<Object<T>, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + JsGeneric,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
[Object<T>]: ErasableGenericBorrow<[Object<JsValue>]>,
Result<Object<T>, JsValue>: ErasableGenericOwn<Result<Object<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
pub fn assign_many(
target: &Object<T>,
sources: &[Object<T>],
) -> Result<Object<T>, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + JsGeneric,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
[Object<T>]: ErasableGenericBorrow<[Object<JsValue>]>,
Result<Object<T>, JsValue>: ErasableGenericOwn<Result<Object<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
The Object.assign() method is used to copy the values of all enumerable
own properties from one or more source objects to a target object. It
will return the target object.
Sourceimpl<T> Object<T>
impl<T> Object<T>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourceimpl<T> Object<T>
impl<T> Object<T>
Sourcepub fn create(prototype: &Object<T>) -> Object<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Object<JsValue>> + BatchableResult,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
pub fn create(prototype: &Object<T>) -> Object<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Object<JsValue>> + BatchableResult,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
The Object.create() method creates a new object, using an existing
object to provide the newly created object’s prototype.
Sourceimpl<T> Object<T>
impl<T> Object<T>
Sourcepub fn define_property(
obj: &Object<T>,
prop: &JsValue,
descriptor: &Object,
) -> Object<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Object<JsValue>> + BatchableResult,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
pub fn define_property(
obj: &Object<T>,
prop: &JsValue,
descriptor: &Object,
) -> Object<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Object<JsValue>> + BatchableResult,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
The static method Object.defineProperty() defines a new
property directly on an object, or modifies an existing
property on an object, and returns the object.
Note: Consider using Object::define_property_str to support typing and error handling.
Sourceimpl<T> Object<T>
impl<T> Object<T>
Sourcepub fn define_property_str(
obj: &Object<T>,
prop: &JsString,
descriptor: &PropertyDescriptor<T>,
) -> Result<Object<T>, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
PropertyDescriptor<T>: ErasableGenericBorrow<PropertyDescriptor<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen PropertyDescriptor<T>: BinaryEncode,
Result<Object<T>, JsValue>: ErasableGenericOwn<Result<Object<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
pub fn define_property_str(
obj: &Object<T>,
prop: &JsString,
descriptor: &PropertyDescriptor<T>,
) -> Result<Object<T>, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
PropertyDescriptor<T>: ErasableGenericBorrow<PropertyDescriptor<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen PropertyDescriptor<T>: BinaryEncode,
Result<Object<T>, JsValue>: ErasableGenericOwn<Result<Object<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
The static method Object.defineProperty() defines a new
property directly on an object, or modifies an existing
property on an object, and returns the object.
Sourceimpl<T> Object<T>
impl<T> Object<T>
Sourcepub fn define_property_symbol(
obj: &Object<T>,
prop: &Symbol,
descriptor: &PropertyDescriptor<JsValue>,
) -> Result<Object<T>, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Result<Object<T>, JsValue>: ErasableGenericOwn<Result<Object<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
pub fn define_property_symbol(
obj: &Object<T>,
prop: &Symbol,
descriptor: &PropertyDescriptor<JsValue>,
) -> Result<Object<T>, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Result<Object<T>, JsValue>: ErasableGenericOwn<Result<Object<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
The static method Object.defineProperty() defines a new
property directly on an object, or modifies an existing
property on an object, and returns the object.
Sourceimpl<T> Object<T>
impl<T> Object<T>
Sourcepub fn define_properties(obj: &Object<T>, props: &Object) -> Object<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Object<JsValue>> + BatchableResult,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
pub fn define_properties(obj: &Object<T>, props: &Object) -> Object<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Object<JsValue>> + BatchableResult,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
The Object.defineProperties() method defines new or modifies
existing properties directly on an object, returning the
object.
Note: Consider using [Object::try_define_properties] to support typing and error handling.
Sourceimpl Object
impl Object
Sourcepub fn entries(object: &Object) -> Array
pub fn entries(object: &Object) -> Array
The Object.entries() method returns an array of a given
object’s own enumerable property [key, value] pairs, in the
same order as that provided by a for…in loop (the difference
being that a for-in loop enumerates properties in the
prototype chain as well).
Note: Consider using Object::entries_typed to support typing and error handling.
Sourceimpl Object
impl Object
Sourcepub fn entries_typed<T: JsGeneric>(
object: &Object<T>,
) -> Result<Array<ArrayTuple<(JsString, T)>>, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Result<Array<ArrayTuple<(JsString, T)>>, JsValue>: ErasableGenericOwn<Result<Array<ArrayTuple<(JsString, JsValue)>>, JsValue>> + EncodeTypeDef + BatchableResult,
pub fn entries_typed<T: JsGeneric>(
object: &Object<T>,
) -> Result<Array<ArrayTuple<(JsString, T)>>, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Result<Array<ArrayTuple<(JsString, T)>>, JsValue>: ErasableGenericOwn<Result<Array<ArrayTuple<(JsString, JsValue)>>, JsValue>> + EncodeTypeDef + BatchableResult,
The Object.entries() method returns an array of a given
object’s own enumerable property [key, value] pairs, in the
same order as that provided by a for…in loop (the difference
being that a for-in loop enumerates properties in the
prototype chain as well).
Sourceimpl<T> Object<T>
impl<T> Object<T>
Sourcepub fn freeze(value: &Object<T>) -> Object<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Object<JsValue>> + BatchableResult,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
pub fn freeze(value: &Object<T>) -> Object<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Object<JsValue>> + BatchableResult,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
The Object.freeze() method freezes an object: that is, prevents new
properties from being added to it; prevents existing properties from
being removed; and prevents existing properties, or their enumerability,
configurability, or writability, from being changed, it also prevents
the prototype from being changed. The method returns the passed object.
Sourceimpl Object
impl Object
Sourcepub fn from_entries(entries: &JsValue) -> Result<Object, JsValue>
pub fn from_entries(entries: &JsValue) -> Result<Object, JsValue>
The Object.fromEntries() method transforms a list of key-value pairs
into an object.
Note: Consider using Object::from_entries_typed to support typing and error handling.
Sourceimpl<T: JsGeneric> Object<T>
impl<T: JsGeneric> Object<T>
Sourcepub fn from_entries_typed<I>(entries: &I) -> Result<Object<T>, JsValue>where
I: ErasableGenericBorrow<JsValue> + EncodeTypeDef + Iterable<Item = ArrayTuple<(JsString, T)>>,
for<'__wry_bindgen> &'__wry_bindgen I: BinaryEncode,
Result<Object<T>, JsValue>: ErasableGenericOwn<Result<Object<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
pub fn from_entries_typed<I>(entries: &I) -> Result<Object<T>, JsValue>where
I: ErasableGenericBorrow<JsValue> + EncodeTypeDef + Iterable<Item = ArrayTuple<(JsString, T)>>,
for<'__wry_bindgen> &'__wry_bindgen I: BinaryEncode,
Result<Object<T>, JsValue>: ErasableGenericOwn<Result<Object<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
The Object.fromEntries() method transforms a list of key-value pairs
into an object.
Sourceimpl Object
impl Object
Sourcepub fn get_own_property_descriptor<T>(
obj: &Object<T>,
prop: &JsValue,
) -> JsValuewhere
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
pub fn get_own_property_descriptor<T>(
obj: &Object<T>,
prop: &JsValue,
) -> JsValuewhere
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
The Object.getOwnPropertyDescriptor() method returns a
property descriptor for an own property (that is, one directly
present on an object and not in the object’s prototype chain)
of a given object.
Sourceimpl Object
impl Object
Sourcepub fn get_own_property_descriptor_str<T>(
obj: &Object<T>,
prop: &JsString,
) -> Result<PropertyDescriptor<T>, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Result<PropertyDescriptor<T>, JsValue>: ErasableGenericOwn<Result<PropertyDescriptor<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
pub fn get_own_property_descriptor_str<T>(
obj: &Object<T>,
prop: &JsString,
) -> Result<PropertyDescriptor<T>, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Result<PropertyDescriptor<T>, JsValue>: ErasableGenericOwn<Result<PropertyDescriptor<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
The Object.getOwnPropertyDescriptor() method returns a
property descriptor for an own property (that is, one directly
present on an object and not in the object’s prototype chain)
of a given object.
Sourceimpl Object
impl Object
Sourcepub fn get_own_property_descriptor_symbol<T>(
obj: &Object<T>,
prop: &Symbol,
) -> Result<PropertyDescriptor<JsValue>, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
pub fn get_own_property_descriptor_symbol<T>(
obj: &Object<T>,
prop: &Symbol,
) -> Result<PropertyDescriptor<JsValue>, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
The Object.getOwnPropertyDescriptor() method returns a
property descriptor for an own property (that is, one directly
present on an object and not in the object’s prototype chain)
of a given object.
Sourceimpl Object
impl Object
Sourcepub fn get_own_property_descriptors<T>(obj: &Object<T>) -> JsValuewhere
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
pub fn get_own_property_descriptors<T>(obj: &Object<T>) -> JsValuewhere
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
The Object.getOwnPropertyDescriptors() method returns all own
property descriptors of a given object.
Sourceimpl Object
impl Object
Sourcepub fn get_own_property_names<T>(obj: &Object<T>) -> Arraywhere
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
pub fn get_own_property_names<T>(obj: &Object<T>) -> Arraywhere
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
The Object.getOwnPropertyNames() method returns an array of
all properties (including non-enumerable properties except for
those which use Symbol) found directly upon a given object.
Sourceimpl Object
impl Object
Sourcepub fn get_own_property_symbols<T>(obj: &Object<T>) -> Arraywhere
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
pub fn get_own_property_symbols<T>(obj: &Object<T>) -> Arraywhere
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
The Object.getOwnPropertySymbols() method returns an array of
all symbol properties found directly upon a given object.
Sourceimpl Object
impl Object
Sourcepub fn get_prototype_of(obj: &JsValue) -> Object
pub fn get_prototype_of(obj: &JsValue) -> Object
The Object.getPrototypeOf() method returns the prototype
(i.e. the value of the internal [[Prototype]] property) of the
specified object.
Sourceimpl<T> Object<T>
impl<T> Object<T>
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
👎Deprecated: Use Object::hasOwn instead.
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourceimpl Object
impl Object
Sourcepub fn has_own<T>(instance: &Object<T>, property: &JsValue) -> boolwhere
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
pub fn has_own<T>(instance: &Object<T>, property: &JsValue) -> boolwhere
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
The Object.hasOwn() method returns a boolean indicating whether the
object passed in has the specified property as its own property (as
opposed to inheriting it).
Sourceimpl Object
impl Object
Sourcepub fn has_own_str<T>(
instance: &Object<T>,
property: &JsString,
) -> Result<bool, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
pub fn has_own_str<T>(
instance: &Object<T>,
property: &JsString,
) -> Result<bool, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
The Object.hasOwn() method returns a boolean indicating whether the
object passed in has the specified property as its own property (as
opposed to inheriting it).
Sourceimpl Object
impl Object
Sourcepub fn has_own_symbol<T>(
instance: &Object<T>,
property: &Symbol,
) -> Result<bool, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
pub fn has_own_symbol<T>(
instance: &Object<T>,
property: &Symbol,
) -> Result<bool, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
The Object.hasOwn() method returns a boolean indicating whether the
object passed in has the specified property as its own property (as
opposed to inheriting it).
Sourceimpl Object
impl Object
Sourcepub fn is_extensible<T>(object: &Object<T>) -> boolwhere
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
pub fn is_extensible<T>(object: &Object<T>) -> boolwhere
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
The Object.isExtensible() method determines if an object is extensible
(whether it can have new properties added to it).
Sourceimpl Object
impl Object
Sourcepub fn is_frozen<T>(object: &Object<T>) -> boolwhere
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
pub fn is_frozen<T>(object: &Object<T>) -> boolwhere
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
The Object.isFrozen() determines if an object is frozen.
Sourceimpl Object
impl Object
Sourcepub fn is_sealed<T>(object: &Object<T>) -> boolwhere
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
pub fn is_sealed<T>(object: &Object<T>) -> boolwhere
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
The Object.isSealed() method determines if an object is sealed.
Sourceimpl<T> Object<T>
impl<T> Object<T>
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourceimpl Object
impl Object
Sourcepub fn keys<T>(object: &Object<T>) -> Arraywhere
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
pub fn keys<T>(object: &Object<T>) -> Arraywhere
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
The Object.keys() method returns an array of a given object’s property
names, in the same order as we get with a normal loop.
Sourceimpl Object
impl Object
Sourcepub fn new() -> Object
pub fn new() -> Object
The Object constructor creates an object wrapper.
Note: Consider using Object::new_typed for typed object records.
Sourceimpl<T> Object<T>
impl<T> Object<T>
Sourceimpl Object
impl Object
Sourcepub fn prevent_extensions<T>(object: &Object<T>)where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
pub fn prevent_extensions<T>(object: &Object<T>)where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
The Object.preventExtensions() method prevents new properties from
ever being added to an object (i.e. prevents future extensions to the
object).
Sourceimpl<T> Object<T>
impl<T> Object<T>
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourceimpl<T> Object<T>
impl<T> Object<T>
Sourcepub fn seal(value: &Object<T>) -> Object<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Object<JsValue>> + BatchableResult,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
pub fn seal(value: &Object<T>) -> Object<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Object<JsValue>> + BatchableResult,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
The Object.seal() method seals an object, preventing new properties
from being added to it and marking all existing properties as
non-configurable. Values of present properties can still be changed as
long as they are writable.
Sourceimpl<T> Object<T>
impl<T> Object<T>
Sourcepub fn set_prototype_of(object: &Object<T>, prototype: &Object) -> Object<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Object<JsValue>> + BatchableResult,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
pub fn set_prototype_of(object: &Object<T>, prototype: &Object) -> Object<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Object<JsValue>> + BatchableResult,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
The Object.setPrototypeOf() method sets the prototype (i.e., the
internal [[Prototype]] property) of a specified object to another
object or null.
Note: Consider using Object::try_set_prototype_of to support errors.
Sourceimpl<T> Object<T>
impl<T> Object<T>
Sourcepub fn try_set_prototype_of(
object: &Object<T>,
prototype: &Object,
) -> Result<Object<T>, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Result<Object<T>, JsValue>: ErasableGenericOwn<Result<Object<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
pub fn try_set_prototype_of(
object: &Object<T>,
prototype: &Object,
) -> Result<Object<T>, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Result<Object<T>, JsValue>: ErasableGenericOwn<Result<Object<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
The Object.setPrototypeOf() method sets the prototype (i.e., the
internal [[Prototype]] property) of a specified object to another
object or null.
Sourceimpl<T> Object<T>
impl<T> Object<T>
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourceimpl<T> Object<T>
impl<T> Object<T>
Sourceimpl<T> Object<T>
impl<T> Object<T>
Sourcepub fn to_js_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
The toString() method returns a string representing the object.
Sourceimpl<T> Object<T>
impl<T> Object<T>
Sourceimpl Object
impl Object
Sourcepub fn values<T>(object: &Object<T>) -> Array<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,
pub fn values<T>(object: &Object<T>) -> Array<T>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Array<T>: ErasableGenericOwn<Array<JsValue>> + EncodeTypeDef + BatchableResult,
The Object.values() method returns an array of a given object’s own
enumerable property values, in the same order as that provided by a
for...in loop (the difference being that a for-in loop enumerates
properties in the prototype chain as well).
Note: Consider using Object::try_values to support errors.
Sourceimpl Object
impl Object
Sourcepub fn try_values<T>(object: &Object<T>) -> Result<Array<T>, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Result<Array<T>, JsValue>: ErasableGenericOwn<Result<Array<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
pub fn try_values<T>(object: &Object<T>) -> Result<Array<T>, JsValue>where
Object<T>: ErasableGenericBorrow<Object<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Object<T>: BinaryEncode,
Result<Array<T>, JsValue>: ErasableGenericOwn<Result<Array<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
The Object.values() method returns an array of a given object’s own
enumerable property values, in the same order as that provided by a
for...in loop (the difference being that a for-in loop enumerates
properties in the prototype chain as well).
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.