#[repr(transparent)]pub struct Set<T = JsValue> {
pub obj: Object,
pub generics: PhantomData<fn() -> (T,)>,
}Fields
obj: Objectgenerics: PhantomData<fn() -> (T,)>Implementations
Sourceimpl Set
impl Set
Sourceimpl<T> Set<T>
impl<T> Set<T>
Sourceimpl<T> Set<T>
impl<T> Set<T>
Sourceimpl<T> Set<T>
impl<T> Set<T>
Sourcepub fn new_from_items(items: &[T]) -> Set<T>where
[T]: ErasableGenericBorrow<[JsValue]>,
T: EncodeTypeDef + JsGeneric,
Set<T>: ErasableGenericOwn<Set<JsValue>> + EncodeTypeDef + BatchableResult,
pub fn new_from_items(items: &[T]) -> Set<T>where
[T]: ErasableGenericBorrow<[JsValue]>,
T: EncodeTypeDef + JsGeneric,
Set<T>: ErasableGenericOwn<Set<JsValue>> + EncodeTypeDef + BatchableResult,
The Set object lets you store unique values of any type, whether
primitive values or object references.
Sourceimpl<T> Set<T>
impl<T> Set<T>
Sourcepub fn new_from_iterable<I>(iterable: I) -> Result<Set<T>, JsValue>where
I: ErasableGenericOwn<JsValue> + EncodeTypeDef + BinaryEncode + Iterable<Item = T>,
Result<Set<T>, JsValue>: ErasableGenericOwn<Result<Set<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
pub fn new_from_iterable<I>(iterable: I) -> Result<Set<T>, JsValue>where
I: ErasableGenericOwn<JsValue> + EncodeTypeDef + BinaryEncode + Iterable<Item = T>,
Result<Set<T>, JsValue>: ErasableGenericOwn<Result<Set<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,
The Set object lets you store unique values of any type, whether
primitive values or object references.
Sourceimpl<T> Set<T>
impl<T> Set<T>
Sourcepub fn add(&self, value: &T) -> Set<T>where
T: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,
Set<T>: ErasableGenericOwn<Set<JsValue>> + EncodeTypeDef + BatchableResult,
pub fn add(&self, value: &T) -> Set<T>where
T: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,
Set<T>: ErasableGenericOwn<Set<JsValue>> + EncodeTypeDef + BatchableResult,
The add() method appends a new element with a specified value to the
end of a Set object.
Sourceimpl<T> Set<T>
impl<T> Set<T>
Sourceimpl<T> Set<T>
impl<T> Set<T>
Sourcepub fn delete(&self, value: &T) -> boolwhere
T: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,
pub fn delete(&self, value: &T) -> boolwhere
T: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,
The delete() method removes the specified element from a Set
object.
Sourceimpl<T> Set<T>
impl<T> Set<T>
Sourceimpl<T> Set<T>
impl<T> Set<T>
Sourceimpl<T> Set<T>
impl<T> Set<T>
Sourcepub fn has(&self, value: &T) -> boolwhere
T: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,
pub fn has(&self, value: &T) -> boolwhere
T: ErasableGenericBorrow<JsValue> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,
The has() method returns a boolean indicating whether an element with
the specified value exists in a Set object or not.
Sourceimpl<T> Set<T>
impl<T> Set<T>
Sourceimpl<T> Set<T>
impl<T> Set<T>
Sourcepub fn union(&self, other: &Set<T>) -> Set<T>where
Set<T>: ErasableGenericBorrow<Set<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Set<JsValue>> + BatchableResult,
for<'__wry_bindgen> &'__wry_bindgen Set<T>: BinaryEncode,
pub fn union(&self, other: &Set<T>) -> Set<T>where
Set<T>: ErasableGenericBorrow<Set<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Set<JsValue>> + BatchableResult,
for<'__wry_bindgen> &'__wry_bindgen Set<T>: BinaryEncode,
The union() method returns a new set containing elements which are in
either or both of this set and the given set.
Sourceimpl<T> Set<T>
impl<T> Set<T>
Sourcepub fn intersection(&self, other: &Set<T>) -> Set<T>where
Set<T>: ErasableGenericBorrow<Set<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Set<JsValue>> + BatchableResult,
for<'__wry_bindgen> &'__wry_bindgen Set<T>: BinaryEncode,
pub fn intersection(&self, other: &Set<T>) -> Set<T>where
Set<T>: ErasableGenericBorrow<Set<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Set<JsValue>> + BatchableResult,
for<'__wry_bindgen> &'__wry_bindgen Set<T>: BinaryEncode,
The intersection() method returns a new set containing elements which are
in both this set and the given set.
Sourceimpl<T> Set<T>
impl<T> Set<T>
Sourcepub fn difference(&self, other: &Set<T>) -> Set<T>where
Set<T>: ErasableGenericBorrow<Set<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Set<JsValue>> + BatchableResult,
for<'__wry_bindgen> &'__wry_bindgen Set<T>: BinaryEncode,
pub fn difference(&self, other: &Set<T>) -> Set<T>where
Set<T>: ErasableGenericBorrow<Set<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Set<JsValue>> + BatchableResult,
for<'__wry_bindgen> &'__wry_bindgen Set<T>: BinaryEncode,
The difference() method returns a new set containing elements which are
in this set but not in the given set.
Sourceimpl<T> Set<T>
impl<T> Set<T>
Sourcepub fn symmetric_difference(&self, other: &Set<T>) -> Set<T>where
Set<T>: ErasableGenericBorrow<Set<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Set<JsValue>> + BatchableResult,
for<'__wry_bindgen> &'__wry_bindgen Set<T>: BinaryEncode,
pub fn symmetric_difference(&self, other: &Set<T>) -> Set<T>where
Set<T>: ErasableGenericBorrow<Set<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Set<JsValue>> + BatchableResult,
for<'__wry_bindgen> &'__wry_bindgen Set<T>: BinaryEncode,
The symmetricDifference() method returns a new set containing elements
which are in either this set or the given set, but not in both.
Sourceimpl<T> Set<T>
impl<T> Set<T>
Sourcepub fn is_subset_of(&self, other: &Set<T>) -> boolwhere
Set<T>: ErasableGenericBorrow<Set<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Set<T>: BinaryEncode,
pub fn is_subset_of(&self, other: &Set<T>) -> boolwhere
Set<T>: ErasableGenericBorrow<Set<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Set<T>: BinaryEncode,
The isSubsetOf() method returns a boolean indicating whether all elements
of this set are in the given set.
Sourceimpl<T> Set<T>
impl<T> Set<T>
Sourcepub fn is_superset_of(&self, other: &Set<T>) -> boolwhere
Set<T>: ErasableGenericBorrow<Set<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Set<T>: BinaryEncode,
pub fn is_superset_of(&self, other: &Set<T>) -> boolwhere
Set<T>: ErasableGenericBorrow<Set<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Set<T>: BinaryEncode,
The isSupersetOf() method returns a boolean indicating whether all elements
of the given set are in this set.
Sourceimpl<T> Set<T>
impl<T> Set<T>
Sourcepub fn is_disjoint_from(&self, other: &Set<T>) -> boolwhere
Set<T>: ErasableGenericBorrow<Set<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Set<T>: BinaryEncode,
pub fn is_disjoint_from(&self, other: &Set<T>) -> boolwhere
Set<T>: ErasableGenericBorrow<Set<JsValue>> + EncodeTypeDef,
for<'__wry_bindgen> &'__wry_bindgen Set<T>: BinaryEncode,
The isDisjointFrom() method returns a boolean indicating whether this set
has no elements in common with the given set.
Sourceimpl<T> Set<T>
impl<T> Set<T>
Sourcepub fn entries(&self) -> Iterator
pub fn entries(&self) -> Iterator
The entries() method returns a new Iterator object that contains an
array of [value, value] for each element in the Set object, in insertion
order. For Set objects there is no key like in Map objects. However, to
keep the API similar to the Map object, each entry has the same value
for its key and value here, so that an array [value, value] is returned.
Sourceimpl<T: JsGeneric> Set<T>
impl<T: JsGeneric> Set<T>
Sourcepub fn entries_typed(&self) -> Iterator<ArrayTuple<(T, T)>>where
Iterator<ArrayTuple<(T, T)>>: ErasableGenericOwn<Iterator<ArrayTuple<(JsValue, JsValue)>>> + EncodeTypeDef + BatchableResult,
pub fn entries_typed(&self) -> Iterator<ArrayTuple<(T, T)>>where
Iterator<ArrayTuple<(T, T)>>: ErasableGenericOwn<Iterator<ArrayTuple<(JsValue, JsValue)>>> + EncodeTypeDef + BatchableResult,
The entries() method returns a new Iterator object that contains an
array of [value, value] for each element in the Set object, in insertion
order. For Set objects there is no key like in Map objects. However, to
keep the API similar to the Map object, each entry has the same value
for its key and value here, so that an array [value, value] is returned.
Sourceimpl<T> Set<T>
impl<T> Set<T>
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
👎Deprecated: Use Object::hasOwn instead.
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Sourcepub fn to_js_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.