Set

Struct Set 

#[repr(transparent)]
pub struct Set<T = JsValue> { pub obj: Object, pub generics: PhantomData<fn() -> (T,)>, }

Fields

obj: Objectgenerics: PhantomData<fn() -> (T,)>

Implementations

Source

impl Set

pub fn new(init: &JsValue) -> Set

The Set object lets you store unique values of any type, whether primitive values or object references.

Note: Consider using Set::new_typed to support typing.

MDN documentation

Source

impl<T> Set<T>

pub fn new_typed() -> Set<T>
where Set<T>: ErasableGenericOwn<Set<JsValue>> + EncodeTypeDef + BatchableResult,

The Set object lets you store unique values of any type, whether primitive values or object references.

MDN documentation

Source

impl<T> Set<T>

pub fn new_empty() -> Set<T>
where Set<T>: ErasableGenericOwn<Set<JsValue>> + EncodeTypeDef + BatchableResult,

The Set object lets you store unique values of any type, whether primitive values or object references.

MDN documentation

Source

impl<T> Set<T>

pub fn new_from_items(items: &[T]) -> Set<T>
where [T]: ErasableGenericBorrow<[JsValue]>, T: EncodeTypeDef + JsGeneric, Set<T>: ErasableGenericOwn<Set<JsValue>> + EncodeTypeDef + BatchableResult,

The Set object lets you store unique values of any type, whether primitive values or object references.

MDN documentation

Source

impl<T> Set<T>

pub fn new_from_iterable<I>(iterable: I) -> Result<Set<T>, JsValue>
where I: ErasableGenericOwn<JsValue> + EncodeTypeDef + BinaryEncode + Iterable<Item = T>, Result<Set<T>, JsValue>: ErasableGenericOwn<Result<Set<JsValue>, JsValue>> + EncodeTypeDef + BatchableResult,

The Set object lets you store unique values of any type, whether primitive values or object references.

MDN documentation

Source

impl<T> Set<T>

pub fn add(&self, value: &T) -> Set<T>
where T: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode, Set<T>: ErasableGenericOwn<Set<JsValue>> + EncodeTypeDef + BatchableResult,

The add() method appends a new element with a specified value to the end of a Set object.

MDN documentation

Source

impl<T> Set<T>

pub fn clear(&self)

The clear() method removes all elements from a Set object.

MDN documentation

Source

impl<T> Set<T>

pub fn delete(&self, value: &T) -> bool
where T: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,

The delete() method removes the specified element from a Set object.

MDN documentation

Source

impl<T> Set<T>

pub fn for_each(&self, callback: &mut dyn FnMut(T, T, Set<T>))
where dyn FnMut(T, T, Set<T>): ErasableGenericBorrowMut<dyn FnMut(JsValue, JsValue, Set<JsValue>)>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T, T, Set<T>): EncodeTypeDef + BinaryEncode,

The forEach() method executes a provided function once for each value in the Set object, in insertion order.

MDN documentation

Source

impl<T> Set<T>

pub fn try_for_each( &self, callback: &mut dyn FnMut(T) -> Result<(), JsError>, ) -> Result<(), JsValue>
where dyn FnMut(T) -> Result<(), JsError>: ErasableGenericBorrowMut<dyn FnMut(JsValue) -> Result<(), JsError>>, for<'__wry_bindgen> &'__wry_bindgen mut dyn FnMut(T) -> Result<(), JsError>: EncodeTypeDef + BinaryEncode,

The forEach() method executes a provided function once for each value in the Set object, in insertion order.

MDN documentation

Source

impl<T> Set<T>

pub fn has(&self, value: &T) -> bool
where T: ErasableGenericBorrow<JsValue> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen T: BinaryEncode,

The has() method returns a boolean indicating whether an element with the specified value exists in a Set object or not.

MDN documentation

Source

impl<T> Set<T>

pub fn size(&self) -> u32

The size accessor property returns the number of elements in a Set object.

MDN documentation

Source

impl<T> Set<T>

pub fn union(&self, other: &Set<T>) -> Set<T>
where Set<T>: ErasableGenericBorrow<Set<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Set<JsValue>> + BatchableResult, for<'__wry_bindgen> &'__wry_bindgen Set<T>: BinaryEncode,

The union() method returns a new set containing elements which are in either or both of this set and the given set.

MDN documentation

Source

impl<T> Set<T>

pub fn intersection(&self, other: &Set<T>) -> Set<T>
where Set<T>: ErasableGenericBorrow<Set<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Set<JsValue>> + BatchableResult, for<'__wry_bindgen> &'__wry_bindgen Set<T>: BinaryEncode,

The intersection() method returns a new set containing elements which are in both this set and the given set.

MDN documentation

Source

impl<T> Set<T>

pub fn difference(&self, other: &Set<T>) -> Set<T>
where Set<T>: ErasableGenericBorrow<Set<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Set<JsValue>> + BatchableResult, for<'__wry_bindgen> &'__wry_bindgen Set<T>: BinaryEncode,

The difference() method returns a new set containing elements which are in this set but not in the given set.

MDN documentation

Source

impl<T> Set<T>

pub fn symmetric_difference(&self, other: &Set<T>) -> Set<T>
where Set<T>: ErasableGenericBorrow<Set<JsValue>> + EncodeTypeDef + ErasableGenericOwn<Set<JsValue>> + BatchableResult, for<'__wry_bindgen> &'__wry_bindgen Set<T>: BinaryEncode,

The symmetricDifference() method returns a new set containing elements which are in either this set or the given set, but not in both.

MDN documentation

Source

impl<T> Set<T>

pub fn is_subset_of(&self, other: &Set<T>) -> bool
where Set<T>: ErasableGenericBorrow<Set<JsValue>> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Set<T>: BinaryEncode,

The isSubsetOf() method returns a boolean indicating whether all elements of this set are in the given set.

MDN documentation

Source

impl<T> Set<T>

pub fn is_superset_of(&self, other: &Set<T>) -> bool
where Set<T>: ErasableGenericBorrow<Set<JsValue>> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Set<T>: BinaryEncode,

The isSupersetOf() method returns a boolean indicating whether all elements of the given set are in this set.

MDN documentation

Source

impl<T> Set<T>

pub fn is_disjoint_from(&self, other: &Set<T>) -> bool
where Set<T>: ErasableGenericBorrow<Set<JsValue>> + EncodeTypeDef, for<'__wry_bindgen> &'__wry_bindgen Set<T>: BinaryEncode,

The isDisjointFrom() method returns a boolean indicating whether this set has no elements in common with the given set.

MDN documentation

Source

impl<T> Set<T>

pub fn entries(&self) -> Iterator

The entries() method returns a new Iterator object that contains an array of [value, value] for each element in the Set object, in insertion order. For Set objects there is no key like in Map objects. However, to keep the API similar to the Map object, each entry has the same value for its key and value here, so that an array [value, value] is returned.

MDN documentation

Source

impl<T: JsGeneric> Set<T>

pub fn entries_typed(&self) -> Iterator<ArrayTuple<(T, T)>>

The entries() method returns a new Iterator object that contains an array of [value, value] for each element in the Set object, in insertion order. For Set objects there is no key like in Map objects. However, to keep the API similar to the Map object, each entry has the same value for its key and value here, so that an array [value, value] is returned.

MDN documentation

Source

impl<T> Set<T>

pub fn keys(&self) -> Iterator<T>
where Iterator<T>: ErasableGenericOwn<Iterator<JsValue>> + EncodeTypeDef + BatchableResult,

The keys() method is an alias for this method (for similarity with Map objects); it behaves exactly the same and returns values of Set elements.

MDN documentation

Source

impl<T> Set<T>

pub fn values(&self) -> Iterator<T>
where Iterator<T>: ErasableGenericOwn<Iterator<JsValue>> + EncodeTypeDef + BatchableResult,

The values() method returns a new Iterator object that contains the values for each element in the Set object in insertion order.

MDN documentation

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

The constructor property returns a reference to the Object constructor function that created the instance object.

MDN documentation

pub fn has_own_property(&self, property: &JsValue) -> bool

👎Deprecated:

Use Object::hasOwn instead.

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

pub fn is_prototype_of(&self, value: &JsValue) -> bool

The isPrototypeOf() method checks if an object exists in another object’s prototype chain.

MDN documentation

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

pub fn to_locale_string(&self) -> JsString

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn to_js_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn value_of(&self) -> Object

The valueOf() method returns the primitive value of the specified object.

MDN documentation

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn id(&self) -> u64

Get the heap ID for this value.

This is used internally for encoding values to send to JS.

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, other: &JsValue) -> bool

Less than comparison.

pub fn le(&self, other: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, other: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, other: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, other: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_array(&self) -> bool

Check if this value is an Array.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn is_null_or_undefined(&self) -> bool

Check if this value is null or undefined.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.