Symbol

Struct Symbol 

#[repr(transparent)]
pub struct Symbol { pub obj: JsValue, }

Fields

obj: JsValue

Implementations

Source

impl Symbol

pub fn has_instance() -> Symbol

The Symbol.hasInstance well-known symbol is used to determine if a constructor object recognizes an object as its instance. The instanceof operator’s behavior can be customized by this symbol.

MDN documentation

Source

impl Symbol

pub fn is_concat_spreadable() -> Symbol

The Symbol.isConcatSpreadable well-known symbol is used to configure if an object should be flattened to its array elements when using the Array.prototype.concat() method.

MDN documentation

Source

impl Symbol

pub fn async_iterator() -> Symbol

The Symbol.asyncIterator well-known symbol specifies the default AsyncIterator for an object. If this property is set on an object, it is an async iterable and can be used in a for await...of loop.

MDN documentation

Source

impl Symbol

pub fn iterator() -> Symbol

The Symbol.iterator well-known symbol specifies the default iterator for an object. Used by for...of.

MDN documentation

Source

impl Symbol

pub fn match_() -> Symbol

The Symbol.match well-known symbol specifies the matching of a regular expression against a string. This function is called by the String.prototype.match() method.

MDN documentation

Source

impl Symbol

pub fn replace() -> Symbol

The Symbol.replace well-known symbol specifies the method that replaces matched substrings of a string. This function is called by the String.prototype.replace() method.

For more information, see RegExp.prototype[@@replace]() and String.prototype.replace().

MDN documentation

Source

impl Symbol

pub fn search() -> Symbol

The Symbol.search well-known symbol specifies the method that returns the index within a string that matches the regular expression. This function is called by the String.prototype.search() method.

For more information, see RegExp.prototype[@@search]() and String.prototype.search().

MDN documentation

Source

impl Symbol

pub fn species() -> Symbol

The well-known symbol Symbol.species specifies a function-valued property that the constructor function uses to create derived objects.

MDN documentation

Source

impl Symbol

pub fn split() -> Symbol

The Symbol.split well-known symbol specifies the method that splits a string at the indices that match a regular expression. This function is called by the String.prototype.split() method.

For more information, see RegExp.prototype[@@split]() and String.prototype.split(). MDN documentation

Source

impl Symbol

pub fn to_primitive() -> Symbol

The Symbol.toPrimitive is a symbol that specifies a function valued property that is called to convert an object to a corresponding primitive value.

MDN documentation

Source

impl Symbol

pub fn to_string_tag() -> Symbol

The Symbol.toStringTag well-known symbol is a string valued property that is used in the creation of the default string description of an object. It is accessed internally by the Object.prototype.toString() method.

MDN documentation

Source

impl Symbol

pub fn for_(key: &str) -> Symbol

The Symbol.for(key) method searches for existing symbols in a runtime-wide symbol registry with the given key and returns it if found. Otherwise a new symbol gets created in the global symbol registry with this key.

MDN documentation

Source

impl Symbol

pub fn key_for(sym: &Symbol) -> JsValue

The Symbol.keyFor(sym) method retrieves a shared symbol key from the global symbol registry for the given symbol.

MDN documentation

Source

impl Symbol

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the specified Symbol object.

MDN documentation

Source

impl Symbol

pub fn to_js_string(&self) -> JsString

The toString() method returns a string representing the specified Symbol object.

MDN documentation

Source

impl Symbol

pub fn unscopables() -> Symbol

The Symbol.unscopables well-known symbol is used to specify an object value of whose own and inherited property names are excluded from the with environment bindings of the associated object.

MDN documentation

Source

impl Symbol

pub fn value_of(&self) -> Symbol

The valueOf() method returns the primitive value of a Symbol object.

MDN documentation

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn id(&self) -> u64

Get the heap ID for this value.

This is used internally for encoding values to send to JS.

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, other: &JsValue) -> bool

Less than comparison.

pub fn le(&self, other: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, other: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, other: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, other: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_array(&self) -> bool

Check if this value is an Array.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn is_null_or_undefined(&self) -> bool

Check if this value is null or undefined.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.