#[repr(transparent)]pub struct Symbol {
pub obj: JsValue,
}Fields
obj: JsValueImplementations
Sourceimpl Symbol
impl Symbol
Sourcepub fn has_instance() -> Symbol
pub fn has_instance() -> Symbol
The Symbol.hasInstance well-known symbol is used to determine
if a constructor object recognizes an object as its instance.
The instanceof operator’s behavior can be customized by this symbol.
Sourceimpl Symbol
impl Symbol
Sourcepub fn is_concat_spreadable() -> Symbol
pub fn is_concat_spreadable() -> Symbol
The Symbol.isConcatSpreadable well-known symbol is used to configure
if an object should be flattened to its array elements when using the
Array.prototype.concat() method.
Sourceimpl Symbol
impl Symbol
Sourcepub fn async_iterator() -> Symbol
pub fn async_iterator() -> Symbol
The Symbol.asyncIterator well-known symbol specifies the default AsyncIterator for an object.
If this property is set on an object, it is an async iterable and can be used in a for await...of loop.
Sourceimpl Symbol
impl Symbol
Sourceimpl Symbol
impl Symbol
Sourceimpl Symbol
impl Symbol
Sourceimpl Symbol
impl Symbol
Sourcepub fn search() -> Symbol
pub fn search() -> Symbol
The Symbol.search well-known symbol specifies the method that returns
the index within a string that matches the regular expression. This
function is called by the String.prototype.search() method.
For more information, see RegExp.prototype[@@search]() and
String.prototype.search().
Sourceimpl Symbol
impl Symbol
Sourceimpl Symbol
impl Symbol
Sourcepub fn split() -> Symbol
pub fn split() -> Symbol
The Symbol.split well-known symbol specifies the method that splits a
string at the indices that match a regular expression. This function is
called by the String.prototype.split() method.
For more information, see RegExp.prototype[@@split]() and
String.prototype.split().
MDN documentation
Sourceimpl Symbol
impl Symbol
Sourcepub fn to_primitive() -> Symbol
pub fn to_primitive() -> Symbol
The Symbol.toPrimitive is a symbol that specifies a function valued
property that is called to convert an object to a corresponding
primitive value.
Sourceimpl Symbol
impl Symbol
Sourcepub fn to_string_tag() -> Symbol
pub fn to_string_tag() -> Symbol
The Symbol.toStringTag well-known symbol is a string valued property
that is used in the creation of the default string description of an
object. It is accessed internally by the Object.prototype.toString()
method.
Sourceimpl Symbol
impl Symbol
Sourceimpl Symbol
impl Symbol
Sourceimpl Symbol
impl Symbol
Sourceimpl Symbol
impl Symbol
Sourcepub fn to_js_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
The toString() method returns a string representing the specified Symbol object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Check if this value is null or undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.